function mesh_collection ( num ) 

%*****************************************************************************80
%
%  MESH_COLLECTION: Collection of meshing examples from MESH2D users. 
%
%  mesh_collection(n) will run the nth example.
%
%  1. Simple square domain. Used for "driven cavity" CFD studies.
%
%  2. Rectangular domain with circular hole. Used in thermally coupled CFD
%     studies to examine the flow around a heated pipe.
%
%  3. Rectangular domain with circular hole and user defined size
%     functions. Used in a CFD study to examine vortex shedding about
%     cylinders.
%
%  4. Rectangular domain with 2 circular holes and user defined size
%     functions. Used in a CFD study to examine the unsteady flow between
%     cylinders.
%
%  5. Rectangular domain with square hole and user defined size functions.
%     Used in a CFD study to examine vortex shedding about square prisms.
%
%  6. 3 element airfoil with user defined size functions and boundary layer
%     size functions. Used in a CFD study to examin the lift/drag
%     characteristics.
%
%  7. U shaped domain.
%
%  8. Rectangular domain with step. Used for "backward facing step" CFD
%     studies.
%
%  9. NACA airfoil with boundary layer size functions. Used in a CFD study
%     to examine the lift/drag vs. alpha characteristics.
%
%  10. Wavy channel from Kong Zour. Used in a CFD study to examine unsteady
%      behaviour.
%
%  11. Tray of glass beads from Falk Hebe. Used in a CFD study to examine the flow
%      through past a collection of beads.
%
%  12. "Kidney" shape from Andrew Hanna
%
%  13. Crack geometry from Christoph Ortner.
%
%  14. Africa + Europe + Asia coastline extracted via CONTOUR.m
%
%  15. Simple geometric face.
%
%  16. River system geometry.
%
%  17. Coastline data from Francisco Garcia. PLEASE NOTE! This is a very
%      complex example and takes a bit of processing time (50 sec on my 
%      machine).
%
% I am always looking for new meshes to add to the collection, if you would
% like to contribute please send me an email with an m-file description of
% the NODE, EDGE, HDATA and OPTIONS used to setup the mesh.
%
%  Author:
%
%    Darren Engwirda
%


switch(num)
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 1

      node  = [0,0; 10,0; 10,1; 0,1];
      
      node = rotate(node,45);

      hdata.hmax = 0.02;

      [p,t] = mesh2d(node,[],[]);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 2

      theta = 0:pi/50:(2*pi-pi/50);
      x = cos(theta)/2;
      y = sin(theta)/2;

      node = [ x',y'; -5,-5; 5,-5; 5,15; -5,15];

      n = size(node,1)-4;
      edge = [(1:n-1)' (2:n)'; n,1; n+1,n+2; n+2,n+3; n+3,n+4; n+4,n+1];

      hdata.hmax = 0.175;
      [p,t] = mesh2d(node,edge,hdata);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 3

      theta = 0:pi/50:(2*pi-pi/50);
      x = cos(theta)/2;
      y = sin(theta)/2;

      node = [ x',y'; -5,-10; 25,-10; 25,10; -5,10];

      n = size(node,1)-4;
      edge = [(1:n-1)' (2:n)'; n,1; n+1,n+2; n+2,n+3; n+3,n+4; n+4,n+1];

      hdata.fun = @const_h;
      hdata.args = {-1,25,-3,3,0.1};
      options.dhmax = 0.2;

      %dmesh2d(node);
      [p,t] = mesh2d(node,edge,hdata,options);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 4

      theta = 0:pi/36:(2*pi-pi/36);
      x = cos(theta)/2;
      y = sin(theta)/2;

      cyL1 = [x' y'+1];
      cyL2 = [x' y'-1];
      box  = [-5,-10; 25,-10; 25,10; -5,10];

      n1 = size(cyL1,1);
      n2 = size(cyL2,1);
      c1 = [(1:n1-1)',(2:n1)'; n1,1];
      c2 = [(1:n2-1)',(2:n2)'; n2,1];
      c3 = [1,2; 2,3; 3,4; 4,1];

      node = [cyL1; cyL2; box];
      edge = [c1; c2+n1; c3+n1+n2];

      hdata.fun = @const_h;
      hdata.args = {-1,25,-4,4,0.2};

      [p,t] = mesh2d(node,edge,hdata);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 5

      node = [0,-10; 20,-10; 20,10; 0,10; 5,-0.5; 6,-0.5; 6,0.5; 5,0.5];
      edge = [1,2; 2,3; 3,4; 4,1; 5,6; 6,7; 7,8; 8,5];
      
      hdata.fun = @case5;
      hdata.edgeh = [5, 0.05; 6, 0.05; 7, 0.05; 8, 0.05];
      hdata.fun = @const_h;
      hdata.args = {5,20,-3,3,0.1};

      options.dhmax = 0.15;

      [p,t] = mesh2d(node,edge,hdata,options);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 6

      temp = [
         0.027490  0.017991 0.899870  0.017200 0.052890 -0.021420 1.214624 -0.113530
         0.021231  0.013241 0.871260  0.019430 0.048640 -0.021060 1.193291 -0.106968
         0.011552  0.004325 0.835990  0.021190 0.043550 -0.019330 1.150970 -0.093895
         -0.004135 -0.011795 0.802400  0.021820 0.039060 -0.015140 1.123617 -0.085397
         -0.012160 -0.021418 0.766470  0.020920 0.037490 -0.009480 1.097197 -0.077260
         -0.018975 -0.031128 0.753490  0.019960 0.039190 -0.001600 1.058932 -0.065674
         -0.022844 -0.037478 0.735200  0.017900 0.043650  0.006190 1.034620 -0.058528
         -0.027273 -0.046152 0.729540  0.017030 0.048240  0.010880 0.996129 -0.047562
         -0.029451 -0.052343 0.718900  0.015170 0.055920  0.016870 0.967841 -0.039703
         -0.030201 -0.061288 0.709580  0.013210 0.062110  0.020990 0.953663 -0.035852
         -0.028411 -0.069148 0.701600  0.011010 0.072390  0.026910 0.940446 -0.032286
         -0.024596 -0.073614 0.690290  0.007120 0.083730  0.032240 0.926244 -0.028500
         -0.018756 -0.075514 0.682300  0.003430 0.104760  0.040220 0.917211 -0.026096
         -0.017118 -0.075335 0.676980 -0.000170 0.117300  0.044210 0.909167 -0.023871
         -0.016780 -0.076060 0.672990 -0.004160 0.134530  0.047900 0.905108 -0.022393
         -0.025493 -0.079097 0.669990 -0.011380 0.153460  0.050670 0.901391 -0.019944
         -0.035315 -0.082430 0.673320 -0.019060 0.168330  0.052460 0.900339 -0.012133
         -0.042170 -0.084269 0.677310 -0.020330 0.172890  0.052960 0.907722 -0.004509
         -0.049084 -0.085176 0.677310 -0.020960 0.182440  0.054030 0.915378 -0.001953
         -0.055933 -0.084663 0.668660 -0.021720 0.200270  0.055850 0.920255 -0.001185
         -0.059101 -0.083382 0.634730 -0.024850 0.203160  0.056150 0.926453 -0.000706
         -0.062122 -0.081635 0.602130 -0.028010 0.234300  0.058920 0.930333 -0.000745
         -0.066395 -0.076400 0.567860 -0.031570 0.266130  0.061280 0.937713 -0.000877
         -0.067831 -0.070173 0.534930 -0.034700 0.301060  0.063370 0.941848 -0.001212
         -0.067150 -0.063754 0.500670 -0.037820 0.335000  0.064970 0.950351 -0.002146
         -0.066302 -0.060865 0.466730 -0.040350 0.366270  0.066030 0.960400 -0.003718
         -0.063478 -0.055113 0.432470 -0.042250 0.401530  0.066770 0.971630 -0.005932
         -0.059726 -0.049766 0.400200 -0.043450 0.434460  0.067000 0.977522 -0.007257
         -0.053690 -0.043024 0.368260 -0.043910 0.468400  0.066730 0.989221 -0.010143
         -0.046491 -0.036434 0.333670 -0.043750 0.499000  0.066030 0.995344 -0.011797
         -0.034454 -0.026043 0.300070 -0.042880 0.533270  0.064740 1.001430 -0.013554
         -0.019737 -0.014303 0.267800 -0.041420 0.567860  0.062840 1.020150 -0.019516
         -0.006940 -0.004739 0.232870 -0.039160 0.599800  0.060480 1.034272 -0.024486
         0.008486  0.006239 0.202590 -0.036530 0.635400  0.057520 1.063809 -0.035726
         0.013998  0.010012 0.167000 -0.032930 0.668660  0.053560 1.097886 -0.050076
         0.019714  0.013891 0.136730 -0.029770 0.701260  0.049500 1.125638 -0.063296
         0.027025  0.018988 0.101460 -0.026280 0.734530  0.044940 1.155608 -0.079195
         0         0        0.084170 -0.024550 0.765140  0.040450 1.183517 -0.094908
         0         0        0.071120 -0.023250 0.799070  0.035100 1.214740 -0.113210
         0         0        0.067860 -0.022820 0.833330  0.029440 0         0
         0         0        0.061240 -0.022290 0.867930  0.023520 0         0
         0         0        0.054720 -0.021660 0.899870  0.017900 0         0];

      slat = temp(:,1:2);
      wing = temp(:,3:6);
      flap = temp(:,7:8);

      slat = slat(slat(:,1)~=0,:);
      flap = flap(flap(:,1)~=0,:);
      wing = [wing(:,1:2); wing(:,3:4)];
      box  = [-0.75,-1; 2.25,-1; 2.25,1; -0.75,1];

      n1 = size(slat,1);
      n2 = size(wing,1);
      n3 = size(flap,1);
      c1 = [(1:n1-1)',(2:n1)'; n1,1];
      c2 = [(1:n2-1)',(2:n2)'; n2,1];
      c3 = [(1:n3-1)',(2:n3)'; n3,1];
      c4 = [1,2; 2,3; 3,4; 4,1];

      node = [slat; wing; flap; box];
      edge = [c1; c2+n1; c3+n1+n2; c4+n1+n2+n3];

      options.dhmax = 0.15;

      hdata.edgeh(:,1) = [unique(c1(:)); unique(c2(:))+n1; unique(c3(:))+n1+n2];
      hdata.edgeh(:,2) = 0.001;

      [p,t] = mesh2d(node,edge,hdata,options);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 7

      node  = [0,0; 4,0; 4,1; 2,1; 2,2; 4,2; 4,3; 0,3];
      
      node = rotate(node,45);

      hdata.hmax = 0.05;

      [p,t] = mesh2d(node,[],hdata);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 8

      node = [-2,1; 1,1; 1,0; 20,0; 20,2; -2,2];

      hdata.hmax = 0.1;
      hdata.fun = @const_h;
      hdata.args = {-1,5,0,2,0.05};

      options.dhmax = 0.1;

      [p,t] = mesh2d(node,[],hdata,options);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 9

      wing = [
         1.00003  0.00126
         0.99730  0.00170
         0.98914  0.00302
         0.97563  0.00518
         0.95693  0.00812
         0.93324  0.01176
         0.90482  0.01602
         0.87197  0.02079
         0.83506  0.02597
         0.79449  0.03145
         0.75070  0.03712
         0.70417  0.04285
         0.65541  0.04854
         0.60496  0.05405
         0.55335  0.05924
         0.50117  0.06397
         0.44897  0.06811
         0.39733  0.07150
         0.34681  0.07402
         0.29796  0.07554
         0.25131  0.07597
         0.20738  0.07524
         0.16604  0.07320
         0.12732  0.06915
         0.09230  0.06265
         0.06203  0.05382
         0.03730  0.04324
         0.01865  0.03176
         0.00628  0.02030
         0.00015  0.00956
         0.00000  0.00000
         0.00533 -0.00792
         0.01557 -0.01401
         0.03029 -0.01870
         0.04915 -0.02248
         0.07195 -0.02586
         0.09868 -0.02922
         0.12954 -0.03282
         0.16483 -0.03660
         0.20483 -0.04016
         0.24869 -0.04283
         0.29531 -0.04446
         0.34418 -0.04510
         0.39476 -0.04482
         0.44650 -0.04371
         0.49883 -0.04188
         0.55117 -0.03945
         0.60296 -0.03655
         0.65360 -0.03327
         0.70257 -0.02975
         0.74930 -0.02607
         0.79330 -0.02235
         0.83407 -0.01866
         0.87118 -0.01512
         0.90420 -0.01180
         0.93279 -0.00880
         0.95661 -0.00621
         0.97543 -0.00410
         0.98901 -0.00254
         0.99722 -0.00158
         0.99997 -0.00126];

      wing = rotate(wing,2.5);
      wall = [-1,-2; 2,-2; 2,2; -1,2];

      nwing = size(wing,1);
      nwall = size(wall,1);

      cwing = [(1:nwing-1)', (2:nwing)'; nwing, 1];
      cwall = [(1:nwall-1)', (2:nwall)'; nwall, 1];

      edge = [cwing; cwall+nwing];
      node = [wing; wall];

      hdata.edgeh(:,1) = (1:size(cwing,1))';
      hdata.edgeh(:,2) = 0.0025;

      options.dhmax = 0.1;

      [p,t] = mesh2d(node,edge,hdata,options);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 10

      % DEFINE GEOMETRY
      H   = 1;                % Height
      L   = 5;                % Length
      n   = 4;                % Cycles
      k   = 2*pi*n*H/L;
      dx  = 0.05;             % Streamwise spatial increment
      x   = 0:dx:L;
      num = length(x);

      % Wavy channel walls
      ytop = 1+0.1*cos(k*x);

      node = [0,0; L,0; x(num:-1:1)' ytop(num:-1:1)'];

      hdata.hmax = 0.05;

      [p,t] = mesh2d(node,[],hdata);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 11

      % A mesh for an industrial process from an engineer in Germany (for a CFD
      % study invloving fluid transport through a tray of glass beads...) which
      % caused eariler versions of mesh2d big problems...


      Radius  = 2;                    % Radius des Kreises
      xNumber = 15;                    % Anzahl in x-Richtung
      yNumber = 8;                    % Anzahl in y-Richtung
      Anzahl  = xNumber*yNumber;      % Anzahl der Kreise
      Abstand = 2*Radius+1;           % Abstand der Kreise
      dtheta  = 0.1;                 % Schrittweite der Winkelaul"osung

      theta = 0:pi*dtheta:(2*pi-pi*dtheta);

      x = zeros(Anzahl,length(theta));
      y = x;
      Radii = 1.5+rand(Anzahl,1);

      % setzen der Kreise
      for i = 1:Anzahl
         x(i,:) = Radii(i)*cos(theta);
         y(i,:) = Radii(i)*sin(theta);
         dy = floor((i-1)/xNumber);
         dx = (i-1)-dy*xNumber;
         node((i-1)*20+1:i*20,1) = [x(i,:)'+dx*Abstand];
         node((i-1)*20+1:i*20,2)  = [y(i,:)'-dy*Abstand];
      end

      % setzen des begrenzenden Rechtecks
      node = [    node(1:Anzahl*20,1) node(1:Anzahl*20,2)
         -3                  -((yNumber-1)*5+3)
         ((xNumber-1)*5+3)    -((yNumber-1)*5+3)
         ((xNumber-1)*5+3)    3
         -3                  3
         ];


      n = size(node,1)-4;

      cnect = [(1:n-1)' (2:n)'
         n        1
         n+1      n+2
         n+2      n+3
         n+3      n+4
         n+4      n+1
         ];

      for i = 1:Anzahl
         cnect(i*20,2) = 1+(i-1)*20;
      end

      options.dhmax = 0.3;

      %dmesh2d(node);
      [p,t] = mesh2d(node,cnect,[],options);
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 12
      % Kidney shape
      
      pts = 1.0e+003 * ...
         [0.6814    1.2932
         0.7148    1.2004
         0.7574    1.1074
         0.8143    1.0178
         0.8963    0.9360
         0.9825    0.8672
         1.0713    0.8072
         1.1610    0.7660
         1.2482    0.7350
         1.3416    0.7122
         1.4344    0.6954
         1.5202    0.6852
         1.6132    0.6802
         1.7064    0.6802
         1.7994    0.6946
         1.8926    0.7160
         1.9848    0.7412
         2.0780    0.7758
         2.1706    0.8178
         2.2616    0.8718
         2.3498    0.9444
         2.4318    1.0256
         2.5044    1.1130
         2.5600    1.1984
         2.5896    1.2914
         2.6132    1.3848
         2.6294    1.4774
         2.5998    1.5688
         2.5333    1.6370
         2.4400    1.6230
         2.3494    1.5844
         2.2576    1.5308
         2.1664    1.4872
         2.0820    1.4402
         1.9928    1.4052
         1.8996    1.3756
         1.8068    1.3492
         1.7136    1.3342
         1.6208    1.3278
         1.5274    1.3264
         1.4346    1.3384
         1.3414    1.3596
         1.2484    1.3860
         1.1556    1.4258
         1.0634    1.4642
         0.9744    1.5058
         0.8816    1.5464
         0.7882    1.5496
         0.7046    1.4790
         0.6890    1.3860];
      
      hdata.hmax = 20;
      
      [p,t] = mesh2d(pts);
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 13
      % Crack
      
      d = 1e-2;
      %corners = [-1, -1; 1, -1; 1, 1; d, 1; d, 0; -d, 0; -d, 1; -1, 1];
      corners = [-1, -1; 1, -1; 1, 1; d, 1; 0, 0; -d, 1; -1, 1];
      
      [p,t] = mesh2d(corners);
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 14
      % Africa + Europe + Asia coastline
      
      node = [
         0   53.7288
         1.0000   53.3590
         1.3111   53.0000
         1.0000   52.4815
         0.7903   52.0000
         1.0000   51.5357
         2.0000   51.7660
         3.0000   51.9189
         3.5000   52.0000
         4.0000   52.3333
         4.7059   53.0000
         5.0000   53.2381
         6.0000   53.6154
         7.0000   53.9348
         7.6000   54.0000
         8.0000   54.3333
         8.2000   55.0000
         8.0000   55.2500
         7.6667   56.0000
         7.7273   57.0000
         8.0000   57.0585
         9.0000   57.3571
         10.0000   57.1463
         10.2143   57.0000
         11.0000   56.3714
         12.0000   56.2143
         12.0846   57.0000
         12.0000   57.0909
         11.2029   58.0000
         11.0000   58.3836
         10.8375   59.0000
         10.0000   59.7460
         9.0000   59.5265
         8.2265   59.0000
         8.0000   58.6610
         7.0000   58.3291
         6.0000   58.3841
         5.3980   59.0000
         5.0000   59.9070
         4.9351   60.0000
         4.4632   61.0000
         4.3497   62.0000
         5.0000   62.7750
         5.3361   63.0000
         6.0000   63.4103
         7.0000   63.7809
         7.9885   64.0000
         8.0000   64.0082
         9.0000   64.2585
         10.0000   64.8340
         10.2579   65.0000
         11.0000   65.4245
         11.4954   66.0000
         12.0000   66.5191
         12.4070   67.0000
         13.0000   67.5263
         14.0000   67.8368
         14.3384   68.0000
         15.0000   68.9632
         15.1099   69.0000
         16.0000   69.1361
         17.0000   69.9336
         17.2069   70.0000
         18.0000   70.3859
         19.0000   70.7048
         20.0000   70.7764
         21.0000   70.7933
         21.7760   71.0000
         22.0000   71.1059
         23.0000   71.1910
         24.0000   71.3965
         25.0000   71.2825
         26.0000   71.3790
         27.0000   71.4104
         28.0000   71.2416
         29.0000   71.2285
         29.5075   71.0000
         30.0000   70.5484
         31.0000   70.2500
         32.0000   70.1901
         32.3624   70.0000
         33.0000   69.7022
         34.0000   69.7425
         35.0000   69.6513
         36.0000   69.5816
         37.0000   69.4146
         37.9444   69.0000
         38.0000   68.9721
         39.0000   68.7829
         40.0000   68.6142
         40.8643   68.0000
         40.8706   67.0000
         41.0000   66.9000
         41.7333   67.0000
         42.0000   67.1250
         42.3636   67.0000
         43.0000   66.8108
         43.3043   67.0000
         43.3636   68.0000
         43.6000   69.0000
         44.0000   69.1739
         45.0000   69.2577
         45.4167   69.0000
         45.5500   68.0000
         46.0000   67.7750
         47.0000   67.6379
         47.2308   68.0000
         48.0000   68.7527
         49.0000   68.7857
         50.0000   68.7949
         50.5517   69.0000
         51.0000   69.1625
         52.0000   69.2466
         53.0000   69.2609
         54.0000   69.0208
         55.0000   69.4444
         56.0000   69.6076
         57.0000   69.6098
         58.0000   69.7961
         58.8750   70.0000
         59.0000   70.0385
         60.0000   70.1739
         61.0000   70.3880
         62.0000   70.4052
         63.0000   70.3636
         64.0000   70.1628
         64.4828   70.0000
         65.0000   69.9527
         66.0000   69.9585
         66.5833   70.0000
         66.1667   71.0000
         67.0000   71.8696
         67.1176   72.0000
         68.0000   72.7377
         68.2623   73.0000
         69.0000   73.7500
         69.9375   74.0000
         70.0000   74.0233
         70.1250   74.0000
         71.0000   73.8679
         72.0000   73.5135
         72.5758   73.0000
         73.0000   72.5172
         74.0000   72.9273
         74.4000   73.0000
         75.0000   73.3529
         75.4000   73.0000
         76.0000   72.7000
         76.7500   73.0000
         77.0000   73.1579
         78.0000   73.4848
         79.0000   73.4412
         79.7500   73.0000
         80.0000   72.8077
         80.0617   73.0000
         80.0000   73.3846
         79.7037   74.0000
         80.0000   74.4444
         81.0000   74.9059
         82.0000   74.9231
         83.0000   74.9140
         84.0000   74.9011
         85.0000   74.9286
         85.3333   75.0000
         86.0000   75.3810
         87.0000   75.8710
         87.5714   76.0000
         88.0000   76.1579
         89.0000   76.6508
         90.0000   76.7419
         91.0000   76.8425
         92.0000   76.8750
         93.0000   76.9279
         94.0000   76.9904
         94.1818   77.0000
         95.0000   77.1837
         95.6000   77.0000
         96.0000   76.9464
         97.0000   76.9690
         97.5714   77.0000
         98.0000   77.0330
         98.1875   77.0000
         99.0000   76.8434
         99.5200   77.0000
         100.0000   77.1667
         101.0000   77.4857
         102.0000   77.9175
         102.2424   78.0000
         102.0000   78.0319
         101.0000   78.1475
         100.0000   78.6000
         99.0244   79.0000
         99.0000   79.0053
         98.8571   79.0000
         98.0000   78.9362
         97.9077   79.0000
         97.0000   79.2226
         96.0000   79.1977
         95.0000   79.1343
         94.0000   79.3850
         93.0873   80.0000
         93.0000   80.0466
         92.0000   80.5652
         91.8592   81.0000
         92.0000   81.0413
         93.0000   81.4989
         94.0000   81.5131
         95.0000   81.3629
         96.0000   81.1980
         96.8115   81.0000
         97.0000   80.7774
         98.0000   80.6031
         99.0000   80.3727
         99.7500   80.0000
         100.0000   79.3922
         101.0000   79.7564
         102.0000   79.6263
         103.0000   79.4498
         104.0000   79.3253
         104.7485   79.0000
         104.3404   78.0000
         105.0000   77.8869
         106.0000   77.7734
         107.0000   77.7990
         108.0000   77.6047
         109.0000   77.5420
         110.0000   77.3321
         111.0000   77.1592
         111.8478   77.0000
         112.0000   76.9421
         113.0000   76.2000
         113.2000   76.0000
         113.0000   75.7500
         112.5000   75.0000
         113.0000   74.4375
         114.0000   74.4516
         115.0000   74.5532
         116.0000   74.6190
         117.0000   74.5273
         117.9355   74.0000
         118.0000   73.9574
         119.0000   73.8971
         120.0000   73.8310
         121.0000   73.8588
         122.0000   73.9200
         123.0000   73.9909
         123.0556   74.0000
         124.0000   74.4474
         125.0000   74.2813
         126.0000   74.1111
         127.0000   74.1000
         127.2500   74.0000
         128.0000   73.3077
         128.5000   73.0000
         129.0000   72.8519
         129.6970   72.0000
         130.0000   71.9673
         131.0000   71.8830
         131.4074   72.0000
         132.0000   72.4706
         133.0000   72.3750
         134.0000   72.3043
         135.0000   72.3793
         136.0000   72.2963
         136.6154   72.0000
         137.0000   71.9515
         137.4167   72.0000
         138.0000   72.3182
         139.0000   72.8500
         139.0882   73.0000
         140.0000   73.9688
         140.0385   74.0000
         141.0000   74.9615
         141.5000   75.0000
         141.0000   75.5000
         140.6667   75.0000
         140.0000   74.3333
         139.5000   75.0000
         139.0000   75.0370
         138.7500   75.0000
         138.0000   74.7391
         137.6250   75.0000
         137.0000   75.2273
         136.1053   76.0000
         137.0000   76.6415
         138.0000   76.8315
         139.0000   76.7324
         140.0000   76.2667
         141.0000   76.0476
         142.0000   76.2000
         143.0000   76.5882
         144.0000   76.4103
         144.8000   76.0000
         144.0000   75.2727
         143.0000   75.0909
         142.2500   75.0000
         143.0000   74.5000
         143.3750   74.0000
         144.0000   73.6667
         145.0000   73.3846
         146.0000   73.2308
         147.0000   73.3333
         148.0000   73.2143
         148.4286   73.0000
         149.0000   72.9048
         150.0000   72.6154
         151.0000   72.2778
         151.3571   72.0000
         152.0000   71.9000
         153.0000   71.8197
         154.0000   71.8254
         155.0000   71.8714
         156.0000   71.9118
         157.0000   71.8493
         158.0000   71.7879
         159.0000   71.6591
         159.8286   71.0000
         160.0000   70.8421
         161.0000   70.8500
         162.0000   70.9486
         163.0000   70.9362
         164.0000   70.9112
         165.0000   70.8841
         166.0000   70.6702
         167.0000   70.6067
         168.0000   70.5854
         168.9412   70.0000
         169.0000   69.9867
         169.0652   70.0000
         170.0000   70.6615
         171.0000   70.9162
         172.0000   70.8923
         173.0000   70.8426
         174.0000   70.8446
         175.0000   70.8605
         176.0000   70.8609
         177.0000   70.8166
         178.0000   70.6699
         178.8023   70.0000
         179.0000   69.9708
         180.0000   69.8571
         181.0000   69.5347
         181.7714   69.0000
         182.0000   68.9106
         183.0000   68.6774
         184.0000   68.4842
         184.6667   68.0000
         185.0000   67.7229
         186.0000   67.8458
         187.0000   67.8789
         188.0000   67.7890
         189.0000   67.1607
         189.1731   67.0000
         189.0000   66.0000
         189.0000   66.0000
         188.0000   65.2761
         187.0000   65.0672
         186.9553   65.0000
         186.0000   64.2661
         185.0000   64.7115
         184.4643   65.0000
         184.0000   65.1057
         183.0000   65.4259
         182.0000   65.4311
         181.0000   65.8784
         180.5500   66.0000
         180.0000   66.0378
         179.9035   66.0000
         179.0000   65.0885
         178.8305   65.0000
         178.9143   64.0000
         179.0000   63.5161
         179.1416   63.0000
         179.0000   62.9414
         178.0000   62.8265
         177.0000   62.9462
         176.0000   62.8455
         175.0000   62.6686
         174.0000   62.1991
         173.4224   62.0000
         173.0000   61.9599
         172.0000   61.7849
         171.0000   61.4051
         170.3142   61.0000
         170.0000   60.7140
         169.0000   60.9072
         168.0000   60.9758
         167.0000   60.9224
         166.0000   60.7753
         165.0000   60.6423
         164.0000   60.0392
         163.6552   60.0000
         163.0000   59.8333
         162.1204   59.0000
         162.1081   58.0000
         162.0906   57.0000
         162.0000   56.9376
         161.1257   56.0000
         161.0000   55.5970
         160.3816   55.0000
         160.0000   54.8387
         159.1274   54.0000
         159.0000   53.9036
         158.0000   53.1280
         157.8339   53.0000
         157.1401   52.0000
         157.0000   51.8657
         156.0000   51.6043
         155.8395   52.0000
         155.4953   53.0000
         155.1837   54.0000
         155.0542   55.0000
         155.0000   55.8000
         154.9839   56.0000
         155.0000   56.1042
         155.2161   57.0000
         156.0000   57.7879
         156.1850   58.0000
         157.0000   58.6271
         158.0000   58.8711
         158.1793   59.0000
         159.0000   59.5992
         159.4810   60.0000
         160.0000   60.8934
         161.0000   60.9705
         161.1325   61.0000
         161.0000   61.0581
         160.0000   61.0405
         159.0096   62.0000
         159.0000   62.0050
         158.0000   62.0133
         157.8551   62.0000
         157.0000   61.7217
         156.0000   61.1889
         155.5787   61.0000
         155.0000   60.3585
         154.4685   60.0000
         154.0000   59.7657
         153.0000   59.4079
         152.0000   59.2510
         151.0000   59.2826
         150.0000   59.5972
         149.0000   59.7759
         148.0000   59.5391
         147.0000   59.4918
         146.0000   59.4601
         145.0000   59.4156
         144.0000   59.3981
         143.0000   59.4861
         142.0000   59.3731
         141.3975   59.0000
         141.0000   58.6768
         140.0000   58.1466
         139.8242   58.0000
         139.0000   57.2921
         138.0000   57.0215
         137.9695   57.0000
         137.0000   56.0522
         136.8614   56.0000
         137.0000   55.3636
         137.4000   55.0000
         138.0000   54.8717
         139.0000   54.9375
         140.0000   54.6161
         141.0000   54.0256
         142.0000   54.5301
         142.3284   54.0000
         142.8718   53.0000
         143.0000   52.6429
         143.0719   52.0000
         143.6096   51.0000
         143.4113   50.0000
         143.0000   49.4727
         142.7360   49.0000
         142.6398   48.0000
         142.3167   47.0000
         142.0000   46.4300
         141.8519   47.0000
         141.7404   48.0000
         141.6446   49.0000
         141.4026   50.0000
         141.2533   51.0000
         141.0615   52.0000
         141.0000   52.2821
         140.9474   52.0000
         140.5403   51.0000
         140.2228   50.0000
         140.0000   49.7772
         139.7236   49.0000
         139.0000   48.2827
         138.7374   48.0000
         138.0000   47.3000
         137.7234   47.0000
         137.0000   46.3633
         136.6596   46.0000
         136.0000   45.3434
         135.5880   45.0000
         135.0000   44.7197
         134.2646   44.0000
         134.0000   43.8313
         133.0000   43.6531
         132.0000   43.7053
         131.0000   43.7347
         130.0000   43.0014
         129.9981   43.0000
         129.1573   42.0000
         129.0000   41.6587
         128.4094   41.0000
         128.0000   40.6160
         127.1116   40.0000
         127.5357   39.0000
         128.0000   38.5764
         128.5013   38.0000
         128.8328   37.0000
         128.6885   36.0000
         128.0000   35.2113
         127.1667   35.0000
         127.0000   34.9204
         126.0000   34.5263
         125.6143   35.0000
         125.5851   36.0000
         125.6296   37.0000
         125.3953   38.0000
         125.0000   38.1809
         124.3475   39.0000
         124.0000   39.8200
         123.2500   40.0000
         123.0000   40.0087
         122.9500   40.0000
         122.0000   39.4818
         121.0000   39.6226
         120.5349   40.0000
         120.0000   40.1307
         119.1481   40.0000
         119.0000   39.8400
         118.0000   39.1538
         117.0000   39.0909
         116.5000   39.0000
         117.0000   38.7500
         118.0000   38.3333
         119.0000   38.2222
         120.0000   38.7935
         121.0000   38.7481
         121.9899   38.0000
         121.4348   37.0000
         121.0000   36.6000
         120.0000   36.1250
         119.8625   36.0000
         119.8333   35.0000
         120.0000   34.7714
         120.6750   34.0000
         121.0000   33.1333
         121.1053   33.0000
         121.1538   32.0000
         121.5172   31.0000
         121.8539   30.0000
         121.4904   29.0000
         121.0000   28.4270
         120.7500   28.0000
         120.0000   27.2083
         119.8893   27.0000
         119.3176   26.0000
         119.0000   25.6494
         118.2188   25.0000
         118.0000   24.7455
         117.0000   24.0197
         116.9450   24.0000
         116.0000   23.2590
         115.0000   23.0596
         114.7353   23.0000
         114.0000   22.5575
         113.0000   22.5645
         112.0000   22.0000
         112.0000   22.0000
         111.0000   21.5000
         110.0000   21.1000
         109.0000   21.1837
         108.0000   21.6716
         107.0000   21.1073
         106.5600   21.0000
         106.0000   20.5088
         105.7698   20.0000
         105.9085   19.0000
         106.0000   18.8618
         106.7510   18.0000
         107.0000   17.7855
         107.7617   17.0000
         108.0000   16.6830
         108.3583   16.0000
         108.7595   15.0000
         108.6465   14.0000
         108.7340   13.0000
         108.6468   12.0000
         108.0000   11.0700
         107.4561   11.0000
         107.0000   10.5357
         106.0000   10.7273
         105.7500   10.0000
         105.0000    9.3514
         104.2727   10.0000
         104.0000   10.2000
         103.0000   10.6545
         102.7432   11.0000
         102.0664   12.0000
         102.0000   12.0810
         101.0000   12.8182
         100.5862   13.0000
         100.0333   14.0000
         100.0000   14.0508
         99.9830   14.0000
         99.9464   13.0000
         99.7273   12.0000
         99.0000   11.0345
         98.9540   11.0000
         99.0000   10.8621
         99.4032   10.0000
         99.9202    9.0000
         100.0000    8.1739
         100.0833    8.0000
         101.0000    7.7381
         101.7848    7.0000
         102.0000    6.8447
         102.8150    6.0000
         103.0000    5.1600
         103.1067    5.0000
         103.0794    4.0000
         103.7346    3.0000
         103.4390    2.0000
         103.0000    1.1818
         102.4545    2.0000
         102.0000    2.1190
         101.5000    2.0000
         102.0000    1.0000
         102.0000    1.0000
         102.9107         0
         103.0000   -0.1613
         103.7879   -1.0000
         104.0000   -1.8750
         105.0000   -2.0000
         106.0000   -1.9048
         106.0909   -2.0000
         106.0000   -2.1333
         105.0714   -3.0000
         105.2192   -4.0000
         105.1951   -5.0000
         105.0000   -5.0734
         104.0000   -5.0460
         103.9591   -5.0000
         103.0000   -4.2465
         102.5067   -4.0000
         102.0000   -3.4762
         101.4286   -3.0000
         101.0000   -2.6048
         100.6067   -2.0000
         100.0670   -1.0000
         100.0000   -0.9294
         99.4852         0
         99.0000    0.5083
         98.3030    1.0000
         98.0304    2.0000
         98.0000    2.0145
         97.1119    3.0000
         97.0000    3.1182
         96.2616    4.0000
         96.0000    4.2783
         95.3173    5.0000
         96.0000    5.5565
         97.0000    5.6376
         97.9244    5.0000
         98.0000    4.8806
         98.9548    4.0000
         99.0000    3.9596
         99.9596    3.0000
         100.0000    2.6154
         100.4054    3.0000
         100.1584    4.0000
         100.0000    4.6375
         99.6915    5.0000
         99.2403    6.0000
         99.1270    7.0000
         99.0000    7.1791
         98.3642    8.0000
         98.0000    8.3706
         97.6871    9.0000
         97.5319   10.0000
         97.5951   11.0000
         97.6918   12.0000
         97.5232   13.0000
         97.2075   14.0000
         97.0789   15.0000
         97.0000   15.4000
         96.2222   16.0000
         96.0000   16.8000
         95.0000   16.6071
         94.7609   17.0000
         94.7121   18.0000
         94.0000   18.2454
         93.7093   19.0000
         93.0000   19.9972
         92.9975   20.0000
         92.0000   20.9575
         91.7600   21.0000
         91.0435   22.0000
         91.0000   22.3684
         90.0000   22.3571
         89.0000   22.8571
         88.0000   23.0000
         87.1250   22.0000
         87.0000   21.9888
         86.0000   21.0062
         85.9870   21.0000
         85.0000   20.6530
         84.6416   20.0000
         84.0000   19.4047
         83.5112   19.0000
         83.0000   18.6936
         82.3179   18.0000
         82.0000   17.7826
         81.0000   17.0075
         80.9796   17.0000
         80.0000   16.6873
         79.4073   16.0000
         79.0887   15.0000
         79.1584   14.0000
         79.1036   13.0000
         79.0036   12.0000
         79.0059   11.0000
         79.0000   10.7500
         78.6327   10.0000
         78.0000    9.9532
         77.1719    9.0000
         77.0000    8.6982
         76.7016    9.0000
         76.0000    9.6799
         75.8972   10.0000
         75.6347   11.0000
         75.0000   11.8530
         74.9077   12.0000
         74.3077   13.0000
         74.0000   13.8120
         73.9273   14.0000
         73.4135   15.0000
         73.0539   16.0000
         73.0000   16.1322
         72.5313   17.0000
         72.1478   18.0000
         72.0629   19.0000
         72.0000   19.9688
         71.9907   20.0000
         71.6129   21.0000
         71.0000   21.1418
         70.0000   21.1899
         69.1667   22.0000
         69.0000   22.6444
         68.7460   23.0000
         68.0000   23.7121
         67.8504   24.0000
         67.0000   24.7941
         66.7627   25.0000
         66.0000   25.4206
         65.0000   25.8585
         64.0000   25.8934
         63.0000   25.9091
         62.0000   25.9270
         61.0000   25.9402
         60.0000   25.9585
         59.0000   25.9821
         58.6476   26.0000
         58.0000   26.0760
         57.0000   26.3187
         56.0813   26.0000
         56.1275   25.0000
         57.0000   24.3434
         57.7764   24.0000
         58.0000   23.7681
         58.5927   23.0000
         58.2821   22.0000
         58.0000   21.1757
         57.7011   21.0000
         57.0438   20.0000
         57.0000   19.8670
         56.0188   19.0000
         56.0000   18.9951
         55.0000   18.6769
         54.4856   18.0000
         54.0000   17.7862
         53.0000   17.5834
         52.2038   17.0000
         52.0000   16.8418
         51.1404   16.0000
         51.0000   15.8890
         50.0000   15.6667
         49.0000   15.3723
         48.5008   15.0000
         48.0000   14.6893
         47.0000   14.5353
         46.0000   14.0566
         45.9163   14.0000
         45.0000   13.5732
         44.0000   13.1954
         43.0000   13.0787
         42.8869   13.0000
         42.6500   12.0000
         43.0000   11.6768
         43.6732   11.0000
         44.0000   10.8248
         44.8137   11.0000
         45.0000   11.0370
         46.0000   11.1562
         47.0000   11.4803
         48.0000   11.4807
         49.0000   11.4969
         50.0000   11.8258
         50.3743   11.0000
         50.1134   10.0000
         50.0000    9.8328
         49.3301    9.0000
         49.0155    8.0000
         49.0000    7.9455
         48.1809    7.0000
         48.0000    6.2159
         47.8208    6.0000
         47.0735    5.0000
         47.0000    4.9473
         46.0787    4.0000
         46.0000    3.9353
         45.0236    3.0000
         45.0000    2.9841
         44.0000    2.6639
         43.1719    2.0000
         43.0000    1.8834
         42.0040    1.0000
         42.0000    0.9938
         41.1260         0
         41.0000   -0.2170
         40.2315   -1.0000
         40.0000   -1.5814
         39.7844   -2.0000
         39.1873   -3.0000
         39.0000   -3.4825
         38.8078   -4.0000
         38.3607   -5.0000
         38.2681   -6.0000
         38.6694   -7.0000
         38.5025   -8.0000
         38.6844   -9.0000
         39.0000   -9.4545
         39.2872  -10.0000
         39.5670  -11.0000
         39.4639  -12.0000
         39.4953  -13.0000
         39.7367  -14.0000
         39.3616  -15.0000
         39.0000  -15.6212
         38.4980  -16.0000
         38.0000  -16.1689
         37.0000  -16.9132
         36.7857  -17.0000
         36.0000  -17.8556
         35.8194  -18.0000
         35.0000  -18.7108
         34.6923  -19.0000
         34.1384  -20.0000
         34.2210  -21.0000
         34.4255  -22.0000
         34.5694  -23.0000
         34.1357  -24.0000
         34.0000  -24.1588
         33.0000  -24.2049
         32.1733  -25.0000
         32.0403  -26.0000
         32.0000  -26.2105
         31.8525  -27.0000
         31.4069  -28.0000
         31.0000  -28.7386
         30.8550  -29.0000
         30.0000  -29.9358
         29.9581  -30.0000
         29.0165  -31.0000
         29.0000  -31.0154
         28.0000  -31.9360
         27.9187  -32.0000
         27.0000  -32.5876
         26.3011  -33.0000
         26.0000  -33.1039
         25.0000  -33.2754
         24.0000  -33.8042
         23.0000  -33.9295
         22.0000  -33.9377
         21.3333  -34.0000
         21.0000  -34.3049
         20.0000  -34.4364
         19.0000  -34.2718
         18.6735  -34.0000
         18.0000  -33.3774
         17.7986  -33.0000
         17.4520  -32.0000
         17.3846  -31.0000
         17.0000  -30.5566
         16.5198  -30.0000
         16.1672  -29.0000
         16.0000  -28.6174
         15.3452  -28.0000
         15.0000  -27.6447
         14.7660  -27.0000
         14.3074  -26.0000
         14.1159  -25.0000
         14.0000  -24.2624
         13.9404  -24.0000
         13.7868  -23.0000
         13.5080  -22.0000
         13.0982  -21.0000
         13.0000  -20.7934
         12.5367  -20.0000
         12.0547  -19.0000
         12.0000  -18.9237
         11.5565  -18.0000
         11.3292  -17.0000
         11.5801  -16.0000
         11.8323  -15.0000
         11.9982  -14.0000
         12.0000  -13.9949
         12.5378  -13.0000
         12.9516  -12.0000
         13.0000  -11.8405
         13.2810  -11.0000
         13.1382  -10.0000
         13.0000   -9.3565
         12.9345   -9.0000
         12.9189   -8.0000
         12.4671   -7.0000
         12.0000   -6.1013
         11.9415   -6.0000
         11.8675   -5.0000
         11.3471   -4.0000
         11.0000   -3.6342
         10.2500   -3.0000
         10.0000   -2.6400
         9.3913   -2.0000
         9.0000   -1.2258
         8.9796   -1.0000
         8.9684         0
         8.9867    1.0000
         9.0000    1.0694
         9.3217    2.0000
         9.6250    3.0000
         9.3627    4.0000
         9.0000    4.4115
         8.0000    4.9159
         7.0000    4.9938
         6.0000    4.9764
         5.8661    5.0000
         5.0000    5.8151
         4.9683    6.0000
         4.0000    6.9711
         3.8165    7.0000
         3.0000    7.3436
         2.0000    7.0800
         1.7931    7.0000
         1.0000    6.9795
         0         6.9003
         0         51.3797
         0.6667   51.0000
         0        50.7059];
      
      edge = [
         1     2
         2     3
         3     4
         4     5
         5     6
         6     7
         7     8
         8     9
         9    10
         10    11
         11    12
         12    13
         13    14
         14    15
         15    16
         16    17
         17    18
         18    19
         19    20
         20    21
         21    22
         22    23
         23    24
         24    25
         25    26
         26    27
         27    28
         28    29
         29    30
         30    31
         31    32
         32    33
         33    34
         34    35
         35    36
         36    37
         37    38
         38    39
         39    40
         40    41
         41    42
         42    43
         43    44
         44    45
         45    46
         46    47
         47    48
         48    49
         49    50
         50    51
         51    52
         52    53
         53    54
         54    55
         55    56
         56    57
         57    58
         58    59
         59    60
         60    61
         61    62
         62    63
         63    64
         64    65
         65    66
         66    67
         67    68
         68    69
         69    70
         70    71
         71    72
         72    73
         73    74
         74    75
         75    76
         76    77
         77    78
         78    79
         79    80
         80    81
         81    82
         82    83
         83    84
         84    85
         85    86
         86    87
         87    88
         88    89
         89    90
         90    91
         91    92
         92    93
         93    94
         94    95
         95    96
         96    97
         97    98
         98    99
         99   100
         100   101
         101   102
         102   103
         103   104
         104   105
         105   106
         106   107
         107   108
         108   109
         109   110
         110   111
         111   112
         112   113
         113   114
         114   115
         115   116
         116   117
         117   118
         118   119
         119   120
         120   121
         121   122
         122   123
         123   124
         124   125
         125   126
         126   127
         127   128
         128   129
         129   130
         130   131
         131   132
         132   133
         133   134
         134   135
         135   136
         136   137
         137   138
         138   139
         139   140
         140   141
         141   142
         142   143
         143   144
         144   145
         145   146
         146   147
         147   148
         148   149
         149   150
         150   151
         151   152
         152   153
         153   154
         154   155
         155   156
         156   157
         157   158
         158   159
         159   160
         160   161
         161   162
         162   163
         163   164
         164   165
         165   166
         166   167
         167   168
         168   169
         169   170
         170   171
         171   172
         172   173
         173   174
         174   175
         175   176
         176   177
         177   178
         178   179
         179   180
         180   181
         181   182
         182   183
         183   184
         184   185
         185   186
         186   187
         187   188
         188   189
         189   190
         190   191
         191   192
         192   193
         193   194
         194   195
         195   196
         196   197
         197   198
         198   199
         199   200
         200   201
         201   202
         202   203
         203   204
         204   205
         205   206
         206   207
         207   208
         208   209
         209   210
         210   211
         211   212
         212   213
         213   214
         214   215
         215   216
         216   217
         217   218
         218   219
         219   220
         220   221
         221   222
         222   223
         223   224
         224   225
         225   226
         226   227
         227   228
         228   229
         229   230
         230   231
         231   232
         232   233
         233   234
         234   235
         235   236
         236   237
         237   238
         238   239
         239   240
         240   241
         241   242
         242   243
         243   244
         244   245
         245   246
         246   247
         247   248
         248   249
         249   250
         250   251
         251   252
         252   253
         253   254
         254   255
         255   256
         256   257
         257   258
         258   259
         259   260
         260   261
         261   262
         262   263
         263   264
         264   265
         265   266
         266   267
         267   268
         268   269
         269   270
         270   271
         271   272
         272   273
         273   274
         274   275
         275   276
         276   277
         277   278
         278   279
         279   280
         280   281
         281   282
         282   283
         283   284
         284   285
         285   286
         286   287
         287   288
         288   289
         289   290
         290   291
         291   292
         292   293
         293   294
         294   295
         295   296
         296   297
         297   298
         298   299
         299   300
         300   301
         301   302
         302   303
         303   304
         304   305
         305   306
         306   307
         307   308
         308   309
         309   310
         310   311
         311   312
         312   313
         313   314
         314   315
         315   316
         316   317
         317   318
         318   319
         319   320
         320   321
         321   322
         322   323
         323   324
         324   325
         325   326
         326   327
         327   328
         328   329
         329   330
         330   331
         331   332
         332   333
         333   334
         334   335
         335   336
         336   337
         337   338
         338   339
         339   340
         340   341
         341   342
         342   343
         343   344
         344   345
         345   346
         346   347
         347   348
         348   349
         349   350
         350   351
         351   352
         352   353
         353   354
         355   356
         356   357
         357   358
         358   359
         359   360
         360   361
         361   362
         362   363
         363   364
         364   365
         365   366
         366   367
         367   368
         368   369
         369   370
         370   371
         371   372
         372   373
         373   374
         374   375
         375   376
         376   377
         377   378
         378   379
         379   380
         380   381
         381   382
         382   383
         383   384
         384   385
         385   386
         386   387
         387   388
         388   389
         389   390
         390   391
         391   392
         392   393
         393   394
         394   395
         395   396
         396   397
         397   398
         398   399
         399   400
         400   401
         401   402
         402   403
         403   404
         404   405
         405   406
         406   407
         407   408
         408   409
         409   410
         410   411
         411   412
         412   413
         413   414
         414   415
         415   416
         416   417
         417   418
         418   419
         419   420
         420   421
         421   422
         422   423
         423   424
         424   425
         425   426
         426   427
         427   428
         428   429
         429   430
         430   431
         431   432
         432   433
         433   434
         434   435
         435   436
         436   437
         437   438
         438   439
         439   440
         440   441
         441   442
         442   443
         443   444
         444   445
         445   446
         446   447
         447   448
         448   449
         449   450
         450   451
         451   452
         452   453
         453   454
         454   455
         455   456
         456   457
         457   458
         458   459
         459   460
         460   461
         461   462
         462   463
         463   464
         464   465
         465   466
         466   467
         467   468
         468   469
         469   470
         470   471
         471   472
         472   473
         473   474
         474   475
         475   476
         476   477
         477   478
         478   479
         479   480
         480   481
         481   482
         482   483
         483   484
         484   485
         485   486
         486   487
         487   488
         488   489
         489   490
         490   491
         491   492
         492   493
         493   494
         494   495
         495   496
         496   497
         497   498
         498   499
         499   500
         500   501
         501   502
         502   503
         503   504
         504   505
         505   506
         506   507
         507   508
         508   509
         509   510
         510   511
         511   512
         512   513
         513   514
         514   515
         515   516
         516   517
         517   518
         518   519
         519   520
         520   521
         521   522
         522   523
         523   524
         524   525
         525   526
         526   527
         527   528
         528   529
         529   530
         530   531
         531   532
         532   533
         533   534
         534   535
         535   536
         536   537
         537   538
         538   539
         539   540
         540   541
         541   542
         542   543
         543   544
         544   545
         545   546
         546   547
         547   548
         548   549
         549   550
         550   551
         551   552
         552   553
         553   554
         554   555
         555   556
         556   557
         557   558
         558   559
         559   560
         560   561
         561   562
         562   563
         563   564
         564   565
         565   566
         566   567
         567   568
         568   569
         569   570
         570   571
         571   572
         572   573
         574   575
         575   576
         576   577
         577   578
         578   579
         579   580
         580   581
         581   582
         582   583
         583   584
         584   585
         585   586
         586   587
         587   588
         588   589
         589   590
         590   591
         591   592
         592   593
         593   594
         594   595
         595   596
         596   597
         597   598
         598   599
         599   600
         600   601
         601   602
         602   603
         603   604
         604   605
         605   606
         606   607
         607   608
         608   609
         609   610
         610   611
         611   612
         612   613
         613   614
         614   615
         615   616
         616   617
         617   618
         618   619
         619   620
         620   621
         621   622
         622   623
         623   624
         624   625
         625   626
         626   627
         627   628
         628   629
         629   630
         630   631
         631   632
         632   633
         634   635
         635   636
         636   637
         637   638
         638   639
         639   640
         640   641
         641   642
         642   643
         643   644
         644   645
         645   646
         646   647
         647   648
         648   649
         649   650
         650   651
         651   652
         652   653
         653   654
         654   655
         655   656
         656   657
         657   658
         658   659
         659   660
         660   661
         661   662
         662   663
         663   664
         664   665
         665   666
         666   667
         667   668
         668   669
         669   670
         670   671
         671   672
         672   673
         673   674
         674   675
         675   676
         676   677
         677   678
         678   679
         679   680
         680   681
         681   682
         682   683
         683   684
         684   685
         685   686
         686   687
         687   688
         688   689
         689   690
         690   691
         691   692
         692   693
         693   694
         694   695
         695   696
         696   697
         697   698
         698   699
         699   700
         700   701
         701   702
         702   703
         703   704
         704   705
         705   706
         706   707
         707   708
         708   709
         709   710
         710   711
         711   712
         712   713
         713   714
         714   715
         715   716
         716   717
         717   718
         718   719
         719   720
         720   721
         721   722
         722   723
         723   724
         724   725
         725   726
         726   727
         727   728
         728   729
         729   730
         730   731
         731   732
         732   733
         733   734
         734   735
         735   736
         736   737
         737   738
         738   739
         739   740
         740   741
         741   742
         742   743
         743   744
         744   745
         745   746
         746   747
         747   748
         748   749
         749   750
         750   751
         751   752
         752   753
         753   754
         754   755
         755   756
         756   757
         757   758
         758   759
         759   760
         760   761
         761   762
         762   763
         763   764
         764   765
         765   766
         766   767
         767   768
         768   769
         769   770
         770   771
         771   772
         772   773
         773   774
         774   775
         775   776
         776   777
         777   778
         778   779
         779   780
         780   781
         781   782
         782   783
         783   784
         784   785
         785   786
         786   787
         787   788
         788   789
         789   790
         790   791
         791   792
         792   793
         793   794
         794   795
         795   796
         796   797
         797   798
         798   799
         799   800
         800   801
         801   802
         802   803
         803   804
         804   805
         805   806
         806   807
         807   808
         808   809
         809   810
         810   811
         811   812
         812   813
         813   814
         814   815
         815   816
         816   817
         817   818
         818   819
         819   820
         820   821
         821   822
         822   823
         823   824
         824   825
         825   826
         826   827
         827   828
         828   829
         829   830
         830   831
         831   832
         832   833
         833   834
         834   835
         835   836
         836   837
         837   838
         838   839
         839   840
         840   841
         841   842
         842   843
         843   844
         844   845
         845   846
         846   847
         847   848
         848   849
         849   850
         850   851
         851   852
         852   853
         853   854
         854   855
         855   856
         856   857
         857   858
         858   859
         859   860
         860   861
         861   862
         862   863
         863   864
         864   865
         865   866
         866   867
         867   868
         868   869
         869   870
         870   871
         871   872
         872   873
         873   874
         874   875
         875   876
         876   877
         877   878
         878   879
         879   880
         880   881
         881   882
         882   883
         883   884
         884   885
         885   886
         886   887
         887   888
         888   889
         889   890
         890   891
         891   892
         892   893
         893   894
         894   895
         895   896
         896   897
         897   898
         898   899
         899   900
         900   901
         901   902
         902   903
         903   904
         904   905
         905   906
         906   907
         907   908
         908   909
         909   910
         910   911
         911   912
         912   913
         913   914
         914   915
         915   916
         916   917
         917   918
         918   919
         919   920
         920   921
         921   922
         922   923
         923   924
         924   925
         925   926
         926   927
         927   928
         928   929
         929   930
         930   931
         931   932
         932   933
         933   934
         934   935
         935   936
         936   937
         937   938
         938   939
         939   940
         940   941
         941   942
         942   943
         943   944
         944   945
         945   946
         946   947
         947   948
         948   949
         949   950
         950   951
         951   952
         952   953
         953   954
         954   955
         955   956
         956   957
         957   958
         958   959
         959   960
         960   961
         961     1
         962   963
         963   964
         964   962];
      
      [p,t] = mesh2d(node,edge);
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 15
      
      node = [0 0; 1 0; 1 1; 0 1; 0.2 0.5; 0.5 0.5; 0.7 0.5; 0.6 0.7];
      edge = [1 2; 2 3; 3 4; 4 5; 5 1; 6 7; 7 8; 8 6];
      hdata.hmax = 0.1;

      [p,t] = mesh2d(node,edge,hdata);
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 16
      
      p1 = [40388958.94	3568824.25
         40389408.97	3568742.25
         40389692.69	3568631.75
         40390153.88	3568354.5
         40390541.16	3568103.25
         40390754.84	3567948
         40390972	3567770.25
         40391300	3567432.75
         40391416.09	3567291.25
         40391583.16	3567037.5
         40391692.88	3566873.25
         40391845.41	3566605.75
         40391936.72	3566417.25
         40392189.81	3565992.25
         40392461.75	3565558.25
         40392562.94	3565290.75
         40392767.97	3564852.25
         40392867.91	3564665
         40393000.97	3564406.25
         40393086.63	3564221.75
         40393205.91	3563958.5
         40393275.56	3563767.75
         40393382.03	3563490.25
         40393416.16	3563308.5
         40393526.88	3563056
         40393831.52	3563001.625
         40393933.06	3562983.5
         40394162.26	3563000.909
         40394216.13	3563005
         40394424	3563015.75
         40394703.38	3563061.75
         40394931.63	3563097
         40395216.03	3563147.5
         40395463.63	3563146.25
         40395738.75	3563163
         40395979.5	3563153.75
         40396262.63	3563124.5
         40396321.91	3563120.653
         40396321.91	3561801.377
         40396062.16	3561859.25
         40395587.53	3561941.25
         40395134.16	3562011.5
         40394698.41	3562037
         40394206.91	3562022.75
         40394017.13	3561996.75
         40393621.03	3561937.75
         40393231.03	3561821.25
         40393084.55	3561788.734
         40393029.44	3561776.5
         40392787.41	3561633.093
         40392680.09	3561569.5
         40392558.53	3561492.25
         40392335.91	3561357.75
         40392002.25	3561114.25
         40391830.69	3561008
         40391592.94	3560874.5
         40391193.22	3560592.5
         40390765.13	3560300.5
         40390564.59	3560166
         40390098.81	3559965.75
         40389615.03	3559809.5
         40389331.25	3559691.5
         40388908.94	3559563.5
         40388451	3559441.5
         40388062.34	3559243.25
         40387893.63	3559170.5
         40387427.78	3558946.5
         40387293.56	3558830.5
         40387100.84	3558659.5
         40386681.81	3558361.25
         40386502.34	3558231.25
         40386131.13	3557972.75
         40385747.5	3557659.25
         40385358.03	3557315
         40385173.66	3557160.75
         40384996.41	3557018.5
         40384780.28	3556850.5
         40384336.47	3556621
         40384277.52	3556597.71
         40383870.91	3556437
         40383535.28	3556243.75
         40383237.95	3556115.306
         40383135.97	3556071.25
         40383005.67	3556011.056
         40382922.48	3555972.628
         40382693.04	3555866.635
         40382677.59	3555859.5
         40382657.27	3555850.988
         40382616.89	3555834.07
         40382556.19	3555808.639
         40382465.09	3555770.469
         40382263.47	3555686
         40381962.15	3555490.101
         40381676.45	3555343.167
         40381581.21	3555294.189
         40381379.83	3555123.419
         40381285	3555043
         40381029.81	3554731
         40380851.38	3554491.5
         40380588.59	3554122.75
         40380327.91	3553680
         40380059.97	3553293.5
         40379945.75	3553070.047
         40379842.59	3552868.25
         40379796.84	3552596
         40379744.78	3552367.25
         40379722.02	3552040.953
         40379707.22	3551828.75
         40379690.56	3551757.25
         40379660.04	3551708.138
         40379523.93	3551776.191
         40379325.59	3551875.365
         40379133.03	3551971.645
         40378890.19	3552093.065
         40378743.19	3552166.563
         40378650.45	3552212.933
         40378618.3	3552229.006
         40378495.39	3552290.462
         40378315.88	3552380.216
         40378171.71	3552452.303
         40378123.65	3552476.332
         40378247.97	3552624.25
         40378587.44	3553038.25
         40378739.44	3553236.25
         40378974.63	3553554.437
         40379053.03	3553660.5
         40379186.34	3553821.5
         40379332.17	3554068.313
         40379449.56	3554267
         40379548.84	3554456
         40379783.66	3554866.5
         40379903.56	3555045.5
         40380221.5	3555441
         40380464.72	3555659.491
         40380580.78	3555763.75
         40380683.84	3555895.25
         40380828.33	3556103.846
         40380964.72	3556300.75
         40381271.02	3556632.923
         40381546.97	3556926.5
         40381902.53	3557309.75
         40381926.39	3557332.637
         40381944.21	3557349.735
         40381985.9	3557389.72
         40382035.57	3557437.367
         40382047.99	3557449.279
         40382051.1	3557452.257
         40382051.87	3557453.002
         40382052.13	3557453.25
         40382161.38	3557541.714
         40382281.84	3557639.25
         40382486.31	3557770.75
         40382749.21	3557976.775
         40383040.34	3558139.904
         40383353.56	3558315.419
         40383520.6	3558409.018
         40383635.37	3558473.328
         40383719.45	3558617.007
         40383786.25	3558731.154
         40383856.91	3558939.325
         40383902.75	3559160.864
         40383897.57	3559460.749
         40383895.11	3559603.942
         40383788.13	3560076.101
         40383673.57	3560581.771
         40383581.9	3561276.945
         40383558.98	3561544.32
         40383536.06	3561765.859
         40383552.19	3562278.25
         40383367.28	3562640.062
         40383300.75	3562770.25
         40383214.78	3562988.5
         40383218.19	3563455.75
         40383148.53	3563701
         40383023.46	3564009.283
         40382984.63	3564105
         40382917.75	3564300.75
         40382866.75	3564510.75
         40382814.88	3564752.75
         40382757.53	3565028.5
         40382787.69	3565249.5
         40382826.53	3565503
         40382958.63	3565680
         40383207.44	3566020.5
         40383479.36	3566261.48
         40383548.78	3566323
         40383672.36	3566464.433
         40383723.53	3566523
         40383881.38	3566665
         40384100.53	3566841
         40384487.81	3567137.5
         40384855.19	3567455
         40385238.38	3567736.25
         40385653.19	3568020.25
         40385813.25	3568126.75
         40385909.59	3568184.75
         40386335.16	3568402.25
         40386773.63	3568696.25
         40386977.93	3568643.188
         40387046.03	3568625.5
         40387120.08	3568645.14
         40387332.56	3568701.5
         40387822.91	3568754.75
         40388029.03	3568791.5
         40388270.28	3568824
         40388520.28	3568818.75];

      p2 = [   40385136.56	3558533.466
         40385531.06	3558738.939
         40385864.18	3558962.219
         40386169.11	3559285.007
         40386297.96	3559403.596
         40386379.54	3559479.002
         40386489.09	3559580.25
         40386635.59	3559714
         40386823.78	3559883.75
         40386963.87	3559993.25
         40387010.56	3560029.75
         40387223.5	3560199.75
         40387411.41	3560310.5
         40387671.25	3560461.75
         40387857.97	3560575.25
         40388173.81	3560681.75
         40388294.34	3560705.25
         40388580.28	3560742
         40388675.59	3560754.25
         40388877.5	3560820.75
         40389365.09	3560882
         40389606.72	3560897.25
         40389746.78	3560908.5
         40390052.29	3560996.494
         40390152.13	3561025.25
         40390371.69	3561155
         40390534.63	3561247
         40390909.72	3561450.25
         40391169.88	3561662.406
         40391279.13	3561751.5
         40391650.13	3562080.25
         40391901.63	3562225
         40392081.97	3562335
         40392305.34	3562457.75
         40392515.63	3562558
         40392740.66	3562711.75
         40392836.07	3562819.756
         40392798.88	3563035.75
         40392707.58	3563211.061
         40392683	3563258.25
         40392572.44	3563446
         40392471.87	3563656.563
         40392438.34	3563726.75
         40392357.59	3563886.75
         40392293.34	3564162.5
         40392233.34	3564382.75
         40392153.69	3564629.75
         40392003.22	3564964.063
         40391953.06	3565075.5
         40391893	3565295
         40391823.88	3565544.5
         40391791.03	3565749.25
         40391688.72	3566038.474
         40391632.56	3566197.25
         40391543.35	3566400.107
         40391448.41	3566616
         40391217.11	3566855.377
         40391115.78	3566960.25
         40390957.91	3567086.75
         40390619.09	3567337
         40390466.28	3567425.75
         40390250.22	3567535.5
         40390112.19	3567642
         40390007.04	3567735.648
         40389926.09	3567807.75
         40389615.75	3567844.903
         40389498	3567859
         40389326.07	3567813.001
         40389280.28	3567800.75
         40389100.05	3567843.125
         40389039.97	3567857.25
         40388990.26	3567860.778
         40388789.3	3567875.042
         40388659.56	3567884.25
         40388461.63	3567917
         40388244.05	3567900.424
         40388084.25	3567888.25
         40387839.53	3567858.25
         40387542.31	3567826.188
         40387410.78	3567812
         40387268.48	3567775.532
         40386970.84	3567699.25
         40386790.06	3567661.75
         40386365.84	3567522.75
         40386137	3567437.75
         40385734.34	3567234.25
         40385541.56	3567107
         40385355.44	3567006.75
         40385231.18	3566931.056
         40385144.5	3566878.25
         40385053.85	3566829.221
         40384715.56	3566646.25
         40384512.13	3566553.25
         40384280.88	3566437.5
         40384110.03	3566326
         40383922.74	3566240.5
         40383860.31	3566212
         40383731.5	3566125.75
         40383553.56	3565973.5
         40383425.21	3565709.543
         40383371.94	3565600
         40383371.84	3565318.25
         40383274.28	3564910.026
         40383245.78	3564790.75
         40383273.06	3564571.75
         40383335.34	3564413.428
         40383428.94	3564175.5
         40383531.16	3563776.25
         40383642.44	3563321.75
         40383810.19	3562821.75
         40383928.86	3562532.133
         40383993.25	3562375
         40384073.5	3562158.25
         40384227.84	3561709.25
         40384321.22	3561416.25
         40384372.13	3561191.5
         40384462.22	3560927
         40384494.16	3560711
         40384531.3	3560487.548
         40384541.53	3560426
         40384596.53	3560224.5
         40384634.59	3559944.5
         40384634.2	3559831.205
         40384634.1	3559802.336
         40384633.85	3559730.603
         40384633.85	3559703.137
         40384633.85	3559667.332
         40384633.85	3559448.881
         40384633.85	3559389.062
         40384618.86	3559231.416
         40384557.12	3558952.631
         40384561.23	3558714.283
         40384585.89	3558586.889
         40384709.17	3558525.248
         40384873.55	3558471.825
         40385009.16	3558492.372];

      e1 = [(1:size(p1,1))', [(2:size(p1,1))'; 1]];
      e2 = [(1:size(p2,1))', [(2:size(p2,1))'; 1]];

      node = [p1; p2];
      edge = [e1; e2+size(p1,1)];

      mesh2d(node,edge);

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 17

      p1=[
         2875871	2394144
         2875959	2394053
         2876044	2394049
         2876132	2393952
         2876228	2393952
         2876312	2393861
         2877032	2393861
         2877121	2393763
         2877474	2393760
         2877573	2393670
         2877928	2393675
         2878015	2393579
         2878111	2393579
         2878200	2393481
         2878380	2393485
         2878462	2393387
         2878645	2393387
         2878734	2393290
         2879005	2393296
         2879095	2393206
         2879178	2393206
         2879585	2392777
         2879585	2392685
         2879675	2392589
         2879675	2392122
         2879582	2392026
         2879582	2391929
         2879453	2391794
         2879364	2391794
         2879316	2391750
         2879316	2391466
         2879540	2391230
         2879633	2391230
         2879717	2391134
         2880885	2391137
         2881112	2390897
         2881109	2390618
         2881246	2390484
         2881335	2390484
         2881599	2390196
         2881691	2390196
         2882278	2389589
         2882278	2389492
         2882366	2389401
         2882366	2389304
         2882674	2388979
         2883663	2388982
         2883752	2388885
         2883934	2388885
         2884024	2388788
         2884195	2388792
         2884290	2388694
         2884741	2388694
         2884825	2388602
         2885097	2388599
         2885186	2388509
         2885457	2388509
         2885542	2388411
         2885904	2388411
         2885993	2388320
         2886175	2388317
         2886259	2388220
         2886445	2388220
         2886528	2388129
         2886622	2388129
         2886707	2388037
         2886983	2388037
         2887072	2387941
         2887245	2387944
         2887335	2387847
         2887962	2387847
         2888052	2387754
         2888235	2387941
         2888505	2387941
         2888595	2387849
         2888771	2387849
         2888860	2387759
         2888951	2387846
         2889395	2387853
         2889484	2387944
         2889932	2387941
         2890249	2388268
         2890252	2388359
         2890289	2388412
         2890386	2388409
         2890563	2388596
         2890653	2388596
         2890742	2388694
         2890835	2388694
         2890924	2388784
         2891008	2388784
         2891190	2388975
         2891281	2388975
         2891369	2389066
         2891457	2389066
         2891546	2389163
         2891642	2389163
         2891729	2389260
         2891907	2389257
         2891997	2389348
         2892090	2389348
         2892173	2389445
         2892267	2389445
         2892355	2389536
         2892445	2389533
         2892534	2389629
         2892621	2389629
         2892711	2389726
         2892809	2389726
         2892892	2389817
         2893072	2389817
         2893165	2389911
         2893254	2389911
         2893338	2390009
         2893427	2390009
         2893520	2390100
         2893610	2390106
         2893702	2390197
         2893787	2390197
         2893875	2390285
         2893965	2390285
         2894057	2390381
         2894147	2390381
         2894239	2390478
         2894329	2390478
         2894418	2390570
         2894595	2390573
         2894684	2390664
         2895312	2390668
         2895401	2390571
         2896119	2390567
         2896211	2390664
         2896746	2390664
         2896835	2390573
         2897018	2390570
         2897102	2390478
         2897287	2390478
         2897374	2390575
         2897909	2390572
         2898007	2390475
         2898270	2390475
         2898670	2390053
         2898670	2389962
         2898856	2389773
         2898856	2389677
         2898901	2389629
         2898994	2389629
         2899164	2389443
         2899257	2389443
         2899347	2389351
         2899436	2389351
         2899525	2389254
         2899619	2389251
         2899792	2389070
         2901315	2389070
         2901407	2389161
         2901677	2389161
         2901770	2389070
         2901859	2389066
         2901943	2388970
         2902032	2388970
         2902301	2388690
         2902395	2388690
         2902663	2388412
         2902756	2388412
         2902793	2388365
         2902798	2388268
         2903025	2388034
         2903114	2388034
         2903198	2387936
         2903381	2387943
         2903694	2387611
         2903694	2387519
         2903783	2387423
         2903783	2387331
         2903918	2387188
         2904100	2387188
         2904318	2386958
         2904318	2386860
         2904408	2386766
         2904413	2386492
         2904548	2386349
         2904637	2386349
         2904721	2386257
         2904993	2386254
         2905262	2385969
         2905438	2385969
         2905534	2385878
         2905623	2385878
         2905707	2385788
         2906517	2385781
         2906606	2385690
         2906873	2385690
         2906969	2385593
         2907058	2385593
         2907327	2385315
         2908400	2385315
         2908537	2385172
         2908533	2385081
         2908850	2384749
         2909110	2384749
         2909202	2384658
         2910012	2384661
         2910417	2384233
         2910417	2384142
         2910462	2384095
         2910551	2384095
         2910644	2383998
         2910817	2383998
         2910906	2383907
         2911003	2383907
         2911083	2383810
         2911268	2383806
         2911358	2383716
         2911540	2383716
         2911628	2383624
         2911720	2383624
         2911802	2383528
         2911985	2383531
         2912074	2383433
         2912343	2383433
         2912435	2383342
         2912608	2383339
         2912654	2383296
         2912654	2383198
         2912744	2383107
         2912749	2382920
         2912839	2382823
         2912839	2382636
         2913108	2382357
         2913108	2382260
         2913242	2382123
         2913326	2382123
         2913416	2382026
         2913514	2382026
         2913594	2381935
         2913687	2381932
         2913777	2381835
         2913956	2381840
         2914049	2381744
         2914227	2381749
         2914311	2381653
         2914582	2381649
         2914671	2381558
         2914943	2381558
         2915027	2381461
         2915123	2381458
         2915213	2381367
         2915300	2381367
         2915387	2381275
         2915479	2381275
         2915614	2381133
         2915614	2380945
         2915702	2380853
         2915700	2380660
         2915927	2380429
         2916017	2380426
         2916196	2380245
         2916285	2380245
         2916372	2380148
         2916467	2380148
         2916512	2380101
         2916509	2379913
         2916603	2379822
         2916600	2379450
         2916823	2379216
         2916913	2379216
         2917005	2379116
         2917089	2379116
         2917185	2379025
         2917450	2379025
         2917540	2378927
         2917630	2378927
         2917943	2378601
         2917943	2378415
         2918078	2378272
         2918168	2378272
         2918341	2378084
         2918439	2378084
         2918881	2377616
         2919243	2377612
         2919336	2377709
         2919598	2377709
         2919688	2377618
         2919780	2377618
         2920184	2377196
         2920184	2377008
         2920274	2376912
         2920274	2376820
         2920498	2376586
         2920586	2376586
         2920677	2376490
         2921038	2376493
         2921122	2376396
         2921215	2376402
         2921311	2376305
         2921395	2376305
         2921663	2376017
         2921754	2376017
         2921799	2375970
         2921799	2375882
         2921888	2375782
         2921884	2375411
         2921977	2375319
         2921983	2375133
         2922063	2375041
         2922063	2374847
         2922153	2374756
         2922153	2374659
         2922245	2374565
         2922249	2374472
         2922654	2374242
         2922739	2374332
         2922828	2374332
         2922918	2374240
         2923727	2374244
         2923811	2374332
         2923996	2374332
         2924084	2374428
         2924172	2374332
         2924352	2374335
         2924397	2374291
         2924397	2374194
         2924442	2374140
         2924535	2374140
         2924580	2374096
         2924580	2372971
         2924669	2372880
         2924669	2372783
         2924847	2372602
         2924845	2372506
         2925027	2372319
         2925024	2372221
         2925161	2372084
         2925250	2372084
         2925519	2371806
         2925606	2371803
         2925743	2371662
         2925743	2371571
         2926015	2371283
         2926012	2371186
         2926146	2371051
         2926233	2371051
         2926285	2371005
         2926285	2370907
         2926320	2370863
         2926419	2370860
         2926502	2370769
         2926681	2370769
         2926771	2370672
         2927215	2370675
         2927305	2370579
         2927487	2370579
         2927577	2370488
         2927666	2370484
         2927755	2370393
         2927848	2370393
         2927893	2370344
         2927893	2370252
         2928072	2370062
         2928075	2369502
         2928345	2369215
         2928345	2369034
         2928425	2368938
         2928430	2368472
         2928338	2368378
         2928338	2368094
         2928425	2368004
         2928425	2367913
         2928518	2367815
         2928514	2367628
         2928786	2367347
         2928783	2367160
         2928872	2367063
         2928878	2366966
         2928965	2366875
         2928965	2366784
         2929013	2366734
         2929186	2366731
         2929374	2366550
         2929457	2366550
         2929636	2366363
         2929726	2366363
         2930087	2365984
         2930177	2365984
         2930222	2365937
         2930222	2365846
         2930401	2365659
         2930395	2365466
         2930936	2364909
         2930936	2364818
         2931115	2364628
         2931115	2364345
         2930933	2364160
         2930936	2363972
         2931029	2363876
         2931029	2363689
         2931118	2363598
         2931115	2363313
         2931204	2363222
         2931204	2363036
         2931382	2362849
         2931382	2362752
         2931742	2362380
         2931742	2362284
         2931831	2362187
         2931828	2361909
         2932186	2361540
         2932186	2361442
         2932365	2361256
         2932365	2361159
         2932551	2360975
         2932551	2360878
         2932724	2360690
         2932727	2360228
         2932820	2360128
         2932817	2360031
         2932727	2359944
         2932727	2359756
         2932640	2359659
         2932640	2359568
         2932724	2359472
         2932729	2359285
         2932865	2359141
         2933043	2359148
         2933127	2359057
         2933398	2359053
         2933488	2358957
         2933667	2358957
         2934029	2358585
         2934118	2358585
         2934207	2358488
         2934380	2358488
         2934471	2358397
         2934742	2358394
         2934831	2358303
         2935103	2358299
         2935192	2358208
         2936444	2358208
         2936531	2358299
         2936717	2358303
         2936806	2358394
         2936895	2358394
         2936985	2358490
         2937875	2358490
         2937968	2358581
         2938240	2358585
         2938329	2358488
         2940205	2358491
         2940294	2358585
         2940923	2358581
         2941011	2358678
         2941110	2358581
         2941194	2358581
         2941283	2358490
         2941553	2358487
         2941642	2358396
         2941824	2358392
         2941913	2358302
         2943164	2358302
         2943252	2358392
         2943527	2358396
         2943572	2358440
         2943572	2358531
         2943611	2358584
         2943704	2358584
         2943793	2358484
         2943971	2358490
         2944109	2358624
         2944109	2358722
         2944246	2358862
         2944508	2358868
         2944599	2358771
         2944691	2358771
         2944780	2358865
         2944870	2358865
         2944959	2358956
         2945043	2358961
         2945090	2359005
         2945090	2359192
         2945184	2359290
         2945184	2359380
         2945087	2359471
         2945087	2359568
         2944824	2359846
         2944824	2359937
         2945318	2360458
         2945400	2360454
         2945538	2360596
         2945538	2360686
         2945631	2360784
         2945631	2360880
         2945542	2360972
         2945538	2361346
         2945500	2361399
         2945312	2361393
         2945177	2361536
         2945177	2361724
         2945090	2361815
         2945090	2361911
         2945045	2361955
         2944959	2361959
         2944862	2362050
         2944773	2362050
         2944689	2362146
         2944504	2362146
         2944241	2362427
         2944147	2362427
         2943969	2362615
         2943880	2362615
         2943832	2362661
         2943832	2362752
         2943656	2362940
         2943659	2363037
         2943612	2363084
         2943433	2363084
         2943343	2363175
         2943251	2363175
         2942846	2363597
         2942851	2363881
         2943027	2364068
         2943027	2364255
         2942982	2364298
         2942891	2364302
         2942809	2364399
         2942718	2364393
         2942629	2364490
         2942540	2364484
         2942495	2364537
         2942495	2364634
         2942402	2364725
         2942402	2364816
         2942315	2364913
         2942315	2365003
         2941911	2365426
         2941823	2365426
         2941732	2365517
         2941640	2365517
         2941550	2365618
         2941461	2365618
         2941372	2365709
         2941283	2365709
         2941193	2365805
         2941103	2365809
         2941011	2365900
         2940921	2365900
         2940832	2365991
         2940748	2365991
         2940255	2366508
         2940255	2366599
         2939891	2366978
         2939891	2367075
         2939755	2367210
         2939672	2367213
         2939448	2367444
         2939448	2367631
         2939350	2367722
         2939350	2367818
         2939269	2367913
         2939269	2368757
         2939359	2368853
         2939359	2368944
         2939263	2369041
         2939266	2369319
         2939355	2369416
         2939359	2369603
         2939442	2369697
         2939442	2369788
         2939718	2370071
         2939718	2370163
         2939891	2370353
         2939891	2370444
         2940165	2370728
         2940165	2370816
         2940342	2371009
         2940342	2371101
         2940607	2371382
         2940607	2371473
         2940655	2371526
         2940745	2371526
         2940790	2371570
         2940790	2371668
         2940837	2371710
         2940927	2371710
         2940965	2371761
         2940965	2371852
         2941013	2371899
         2941102	2371899
         2941414	2372224
         2941414	2372321
         2941468	2372374
         2941551	2372374
         2941733	2372553
         2941823	2372558
         2941911	2372650
         2942090	2372646
         2942271	2372840
         2942360	2372840
         2942537	2373024
         2942626	2373024
         2942985	2373397
         2943074	2373402
         2943164	2373493
         2943525	2373497
         2943612	2373588
         2943701	2373588
         2944150	2374063
         2944239	2374059
         2944505	2374337
         2944596	2374334
         2944687	2374430
         2944777	2374430
         2944870	2374527
         2944953	2374527
         2945049	2374622
         2945141	2374622
         2945222	2374712
         2945314	2374712
         2945409	2374810
         2945497	2374806
         2945674	2374993
         2945763	2374999
         2945856	2375090
         2945945	2375087
         2946034	2375177
         2946118	2375183
         2946301	2375371
         2946390	2375368
         2946483	2375464
         2946566	2375464
         2946749	2375649
         2946837	2375649
         2946932	2375746
         2947110	2375746
         2947202	2375843
         2947376	2375839
         2947468	2375936
         2947558	2375936
         2947647	2376024
         2947730	2376024
         2947913	2376212
         2948812	2376212
         2948857	2376261
         2948857	2376352
         2949343	2376874
         2949437	2376870
         2949526	2376961
         2949798	2376968
         2949881	2377054
         2949980	2377054
         2950153	2377242
         2950690	2377242
         2950736	2377289
         2950738	2377483
         2950829	2377571
         2950823	2377662
         2950960	2377812
         2951049	2377808
         2951139	2377899
         2951401	2377906
         2951542	2378040
         2951542	2378138
         2951451	2378235
         2951451	2378326
         2951497	2378370
         2951679	2378370
         2951769	2378466
         2952397	2378466
         2952434	2378514
         2952434	2378605
         2952528	2378698
         2952531	2379073
         2952666	2379214
         2953466	2379217
         2953559	2379310
         2953741	2379310
         2953914	2379496
         2954275	2379496
         2954369	2379590
         2954548	2379590
         2954586	2379634
         2954590	2379730
         2954679	2379827
         2954682	2380014
         2954412	2380293
         2954412	2380390
         2954504	2380481
         2954504	2380578
         2954591	2380675
         2954594	2381140
         2954683	2381234
         2954678	2381325
         2954770	2381422
         2954770	2381609
         2954815	2381653
         2954908	2381653
         2954953	2381700
         2954953	2381797
         2955040	2381890
         2955040	2382071
         2955133	2382169
         2955133	2382266
         2955178	2382310
         2955268	2382310
         2955351	2382407
         2955533	2382407
         2955625	2382495
         2955798	2382500
         2955895	2382409
         2956878	2382400
         2956968	2382309
         2957057	2382309
         2957415	2381934
         2957506	2381937
         2957598	2381839
         2958313	2381843
         2958404	2381931
         2958489	2381937
         2958581	2382027
         2958668	2382027
         2958761	2382122
         2958943	2382122
         2959031	2382219
         2959208	2382215
         2959517	2382543
         2959522	2382731
         2959704	2382921
         2959698	2383012
         2959788	2383109
         2959791	2383387
         2959884	2383484
         2959884	2383582
         2959974	2383668
         2959968	2383760
         2960057	2383856
         2960057	2383954
         2960105	2383998
         2960287	2383998
         2960690	2383575
         2960690	2383484
         2960781	2383387
         2960776	2383109
         2960418	2382731
         2960418	2382640
         2960373	2382586
         2960286	2382589
         2960235	2382542
         2960235	2382452
         2960151	2382357
         2960148	2382260
         2960055	2382169
         2960055	2381982
         2959972	2381885
         2959972	2381698
         2959879	2381604
         2959879	2381417
         2959741	2381277
         2959659	2381277
         2959568	2381374
         2959479	2381374
         2959387	2381277
         2958852	2381282
         2958715	2381133
         2958715	2380294
         2958449	2380013
         2958445	2379637
         2958535	2379540
         2958538	2379353
         2958577	2379306
         2958666	2379306
         2958758	2379215
         2959204	2379211
         2959651	2379687
         2959741	2379683
         2959834	2379774
         2959923	2379774
         2960016	2379871
         2960105	2379778
         2960637	2379774
         2960823	2379968
         2960912	2379968
         2960999	2380055
         2961088	2380055
         2961134	2380105
         2961134	2380196
         2961355	2380434
         2961447	2380434
         2961492	2380478
         2961492	2380569
         2961537	2380623
         2961630	2380623
         2961714	2380716
         2961803	2380716
         2961848	2380763
         2961852	2380850
         2961941	2380948
         2961941	2381045
         2961854	2381136
         2961854	2381323
         2961758	2381420
         2961761	2381885
         2961943	2382072
         2961938	2382267
         2961893	2382310
         2961803	2382310
         2961765	2382357
         2961765	2383108
         2961848	2383201
         2961852	2383571
         2961989	2383718
         2962098	2383639
         2962250	2383621
         2962347	2383530
         2962613	2383527
         2962706	2383623
         2962975	2383620
         2963105	2383761
         2963105	2383858
         2963243	2383998
         2963327	2383998
         2963416	2384096
         2963509	2384096
         2963596	2383997
         2963958	2383995
         2964136	2384186
         2964225	2384186
         2964318	2384283
         2964407	2384280
         2964497	2384183
         2964586	2384183
         2964945	2383810
         2965029	2383810
         2965080	2383757
         2965080	2383483
         2964987	2383386
         2965076	2383295
         2965076	2383010
         2964856	2382779
         2964766	2382870
         2964495	2382874
         2964363	2382733
         2964360	2382357
         2964315	2382304
         2964049	2382308
         2963640	2381885
         2963642	2381608
         2963736	2381516
         2963642	2381420
         2963645	2380857
         2963416	2380618
         2963333	2380623
         2963282	2380575
         2963282	2380478
         2963195	2380384
         2963195	2380203
         2963374	2380013
         2963374	2379916
         2963416	2379872
         2963597	2379869
         2963688	2379778
         2963953	2379778
         2964138	2379586
         2964222	2379586
         2964312	2379496
         2964495	2379492
         2964583	2379590
         2964765	2379590
         2964855	2379492
         2965300	2379496
         2965386	2379590
         2965572	2379590
         2965838	2379871
         2965926	2379871
         2966103	2380056
         2966196	2380056
         2966378	2380242
         2966468	2380239
         2966552	2380336
         2966644	2380336
         2966776	2380478
         2966776	2380568
         2966955	2380762
         2966958	2381134
         2966776	2381325
         2966776	2381415
         2966688	2381513
         2966691	2381610
         2966736	2381654
         2966909	2381654
         2967000	2381553
         2967092	2381553
         2967316	2381318
         2967313	2381227
         2967403	2381137
         2967406	2380577
         2967494	2380476
         2967494	2380385
         2967809	2380053
         2967898	2380053
         2967988	2379963
         2968797	2379963
         2968887	2380060
         2968971	2380060
         2969199	2380288
         2969202	2380385
         2969338	2380526
         2969422	2380526
         2969511	2380617
         2969601	2380617
         2969732	2380758
         2969735	2381320
         2969646	2381417
         2969649	2381509
         2969467	2381695
         2969470	2381882
         2969381	2381980
         2969375	2382167
         2969157	2382401
         2969061	2382401
         2968798	2382683
         2968709	2382683
         2968574	2382821
         2968574	2382918
         2968395	2383104
         2968395	2383201
         2968349	2383245
         2968261	2383242
         2968126	2383382
         2968123	2383945
         2968436	2384274
         2968526	2384270
         2968573	2384323
         2968573	2384420
         2968619	2384464
         2968792	2384464
         2968884	2384552
         2969157	2384558
         2969239	2384649
         2969602	2384652
         2969691	2384555
         2969872	2384552
         2970137	2384839
         2970673	2384836
         2970765	2384933
         2970855	2384836
         2971127	2384839
         2971216	2384748
         2971390	2384744
         2971614	2384511
         2971619	2384414
         2971709	2384322
         2971709	2384226
         2971754	2384182
         2971843	2384178
         2972062	2383948
         2972065	2383572
         2972154	2383480
         2972154	2383384
         2972424	2383102
         2972421	2382630
         2972516	2382533
         2972516	2382352
         2972603	2382255
         2972603	2382068
         2972693	2381977
         2972693	2381879
         2972827	2381736
         2973100	2381741
         2973188	2381829
         2973454	2381836
         2973544	2381923
         2974443	2381930
         2974527	2382026
         2974616	2382026
         2974711	2381926
         2974888	2381926
         2974978	2381835
         2975067	2381835
         2975157	2381735
         2975512	2381740
         2975601	2381828
         2975784	2381834
         2975876	2381925
         2975966	2381922
         2976049	2382018
         2976145	2382018
         2976324	2382209
         2976503	2382209
         2976635	2382350
         2976635	2382628
         2976589	2382672
         2976327	2382676
         2976228	2382773
         2976054	2382769
         2975966	2382866
         2975876	2382866
         2975742	2383003
         2975737	2383100
         2975787	2383144
         2975963	2383144
         2976234	2383425
         2976315	2383425
         2976456	2383567
         2976459	2383664
         2976589	2383805
         2976686	2383805
         2976770	2383892
         2976857	2383898
         2976997	2384039
         2976997	2384130
         2977036	2384179
         2977398	2384176
         2977487	2384079
         2977580	2384079
         2977663	2384176
         2977851	2384173
         2977935	2384270
         2978207	2384266
         2978252	2384223
         2978249	2383847
         2978383	2383704
         2978745	2383708
         2978784	2383755
         2978787	2384039
         2978697	2384130
         2978787	2384223
         2978790	2384320
         2978919	2384455
         2979018	2384455
         2979100	2384552
         2979463	2384556
         2979547	2384647
         2979729	2384643
         2979821	2384741
         2979995	2384741
         2980083	2384834
         2980538	2384838
         2980808	2384550
         2980896	2384556
         2981166	2384277
         2981249	2384277
         2981386	2384412
         2981297	2384509
         2981297	2384697
         2981028	2384975
         2981031	2385072
         2981120	2385163
         2981117	2385447
         2981162	2385491
         2981524	2385494
         2981569	2385445
         2981569	2385353
         2981839	2385072
         2981836	2384878
         2981879	2384834
         2981973	2384838
         2982062	2384741
         2982152	2384741
         2982197	2384791
         2982191	2385256
         2982242	2385300
         2982332	2385208
         2982510	2385215
         2982594	2385117
         2982686	2385212
         2983311	2385208
         2983535	2384973
         2983541	2384882
         2983630	2384782
         2983630	2384690
         2983585	2384647
         2983493	2384647
         2983359	2384506
         2983362	2384222
         2983496	2384082
         2983585	2384078
         2983672	2384175
         2984214	2384178
         2984306	2384272
         2984390	2384272
         2984479	2384175
         2985103	2384175
         2985197	2384084
         2985286	2384084
         2985375	2383987
         2985646	2383990
         2985777	2383846
         2985777	2383659
         2985913	2383516
         2986091	2383522
         2986139	2383566
         2986139	2383657
         2986223	2383754
         2986228	2384136
         2986317	2384227
         2986317	2384317
         2986267	2384367
         2986090	2384371
         2985959	2384506
         2985959	2384693
         2985863	2384784
         2986000	2384934
         2986445	2384928
         2986499	2384975
         2986493	2385162
         2986405	2385259
         2986541	2385400
         2986896	2385396
         2986987	2385306
         2987075	2385303
         2987257	2385490
         2987341	2385490
         2987434	2385583
         2987521	2385583
         2987568	2385536
         2987572	2384976
         2987706	2384832
         2987796	2384929
         2987879	2384926
         2988016	2385070
         2988016	2385907
         2987928	2386005
         2987930	2386102
         2987840	2386193
         2987837	2386568
         2987755	2386665
         2987748	2386853
         2987885	2386994
         2988020	2386853
         2988016	2386665
         2988106	2386565
         2988106	2386477
         2988195	2386384
         2988195	2386197
         2988291	2386100
         2988288	2386002
         2988506	2385768
         2988778	2385773
         2988823	2385817
         2988734	2385914
         2988738	2386102
         2988783	2386146
         2988828	2386102
         2988828	2386011
         2989051	2385777
         2989140	2385777
         2989224	2385675
         2989496	2385675
         2989584	2385582
         2989675	2385582
         2989809	2385445
         2989809	2385348
         2989896	2385251
         2989896	2385160
         2990031	2385019
         2990120	2385016
         2990488	2384643
         2990750	2384643
         2990840	2384552
         2991285	2384552
         2991374	2384455
         2991472	2384455
         2991556	2384364
         2991646	2384361
         2991780	2384220
         2991783	2383942
         2991874	2383851
         2991874	2383754
         2991829	2383701
         2991646	2383705
         2991509	2383564
         2991512	2383098
         2991291	2382860
         2990929	2382857
         2990434	2382344
         2990436	2382157
         2990347	2382063
         2990351	2381694
         2990261	2381596
         2990258	2381409
         2990169	2381316
         2990172	2381219
         2990076	2381128
         2990079	2381031
         2989990	2380940
         2989987	2380752
         2989896	2380659
         2989899	2380284
         2989990	2380187
         2989990	2380096
         2990124	2379952
         2990214	2379952
         2990301	2380047
         2990758	2380050
         2990839	2379952
         2991110	2379949
         2991202	2380047
         2991382	2380043
         2991513	2380189
         2991513	2380281
         2991605	2380378
         2991600	2380655
         2991737	2380796
         2992272	2380800
         2992320	2380752
         2992317	2380655
         2992405	2380564
         2992411	2380474
         2992450	2380420
         2992539	2380420
         2992638	2380329
         2992990	2380332
         2993083	2380420
         2993618	2380424
         2993712	2380520
         2993885	2380517
         2993973	2380420
         2994243	2380424
         2994522	2380706
         2995235	2380706
         2995322	2380796
         2995411	2380796
         2995505	2380891
         2995593	2380891
         2995633	2380933
         2995633	2381031
         2995686	2381084
         2995770	2381084
         2995946	2381269
         2996042	2381269
         2996135	2381357
         2996308	2381362
         2996400	2381450
         2996664	2381456
         2996756	2381543
         2997118	2381547
         2997206	2381638
         2997655	2381647
         2997745	2381738
         2998399	2381735
         2998546	2381735
         2998638	2381831
         2998907	2381828
         2998931	2381804
         2998994	2381738
         2999979	2381735
         3000076	2381644
         3000252	2381640
         3000653	2381217
         3000656	2380654
         3000745	2380564
         3000745	2380092
         3000965	2379857
         3001595	2379857
         3001687	2379954
         3002134	2379958
         3002223	2379861
         3002493	2379857
         3002582	2379766
         3002764	2379763
         3002848	2379860
         3003300	2379854
         3003392	2379951
         3003565	2379948
         3003654	2379856
         3003925	2379862
         3004150	2379625
         3004105	2379575
         3004021	2379575
         3003968	2379531
         3003968	2379434
         3004107	2379297
         3004370	2379293
         3004417	2379340
         3004417	2379438
         3004462	2379482
         3005715	2379482
         3005807	2379384
         3005986	2379391
         3006079	2379478
         3006252	2379484
         3006346	2379572
         3007059	2379577
         3007157	2379480
         3007241	2379480
         3007330	2379389
         3007420	2379386
         3007509	2379295
         3007599	2379295
         3007686	2379204
         3007781	2379291
         3008045	2379295
         3008137	2379386
         3008226	2379295
         3010292	2379295
         3010375	2379201
         3010826	2379198
         3010919	2379295
         3011363	2379289
         3011453	2379198
         3011632	2379204
         3011721	2379104
         3011815	2379104
         3012080	2378822
         3012172	2378822
         3012262	2378731
         3012351	2378731
         3012440	2378638
         3012885	2378634
         3012975	2378543
         3013153	2378540
         3013244	2378449
         3013425	2378445
         3013515	2378354
         3013688	2378354
         3013784	2378254
         3013864	2378260
         3013966	2378168
         3014051	2378168
         3014227	2377978
         3014325	2377978
         3014405	2377880
         3014498	2377877
         3014676	2377696
         3015482	2377692
         3015573	2377601
         3015752	2377601
         3015930	2377411
         3016468	2377411
         3016564	2377314
         3016737	2377320
         3016826	2377227
         3017361	2377223
         3017457	2377130
         3017813	2377126
         3017903	2377035
         3018084	2377039
         3018174	2376942
         3018263	2376942
         3018352	2376851
         3019067	2376847
         3019154	2376756
         3019605	2376753
         3019693	2376659
         3019963	2376659
         3020053	2376566
         3020324	2376572
         3020414	2376472
         3021131	2376472
         3021220	2376380
         3021573	2376384
         3021666	2376472
         3021844	2376477
         3021938	2376565
         3022293	2376568
         3022382	2376472
         3022472	2376472
         3022565	2376565
         3022827	2376568
         3022923	2376472
         3023100	2376472
         3023196	2376378
         3023279	2376378
         3023369	2376287
         3023731	2376284
         3023818	2376189
         3024979	2376192
         3025069	2376099
         3025432	2376096
         3025520	2376005
         3025702	2376001
         3025786	2376099
         3027671	2376099
         3027764	2376186
         3028117	2376189
         3028385	2376472
         3028483	2376472
         3028568	2376565
         3029285	2376565
         3029374	2376474
         3029464	2376470
         3029554	2376379
         3029643	2376379
         3029688	2376332
         3029688	2376235
         3029777	2376144
         3029774	2376047
         3030182	2375632
         3030289	2375672
         3030379	2375574
         3030462	2375574
         3030552	2375480
         3030641	2375480
         3030731	2375389
         3030824	2375386
         3030909	2375295
         3031092	2375295
         3031182	2375201
         3031361	2375201
         3031449	2375101
         3031904	2375105
         3031984	2375013
         3032438	2375013
         3032525	2374917
         3032796	2374920
         3032887	2374829
         3033152	2374825
         3033241	2374729
         3033420	2374732
         3033507	2374635
         3033689	2374639
         3033868	2374451
         3033958	2374447
         3034047	2374357
         3034492	2374351
         3034581	2374260
         3034943	2374263
         3035035	2374361
         3035660	2374351
         3035750	2374260
         3036825	2374260
         3036913	2374168
         3037184	2374165
         3037274	2374263
         3037363	2374263
         3037631	2373981
         3037811	2373977
         3037901	2373886
         3038166	2373883
         3038262	2373793
         3038436	2373789
         3038524	2373698
         3038707	2373695
         3038794	2373604
         3038976	2373600
         3039066	2373502
         3039337	2373506
         3039421	2373416
         3039606	2373412
         3039687	2373321
         3039780	2373321
         3039876	2373220
         3039959	2373220
         3040055	2373130
         3040149	2373136
         3040228	2373223
         3040322	2373132
         3040411	2373132
         3040589	2372941
         3040768	2372938
         3040947	2372757
         3041037	2372757
         3041126	2372663
         3041305	2372663
         3041394	2372563
         3041577	2372569
         3041666	2372475
         3041750	2372566
         3041842	2372572
         3041932	2372660
         3042021	2372569
         3042112	2372569
         3042380	2372282
         3043098	2372287
         3043186	2372381
         3043452	2372377
         3043545	2372286
         3043638	2372286
         3043721	2372186
         3043908	2372192
         3043990	2372099
         3044081	2372099
         3044178	2372002
         3044262	2371998
         3044349	2371907
         3044711	2371911
         3044800	2371819
         3044973	2371816
         3045072	2371719
         3045245	2371723
         3045338	2371814
         3045962	2371810
         3046055	2371907
         3046145	2371907
         3046365	2372141
         3046365	2372232
         3046459	2372330
         3046461	2372427
         3046507	2372471
         3046949	2372474
         3047041	2372381
         3047576	2372374
         3047666	2372283
         3047848	2372286
         3047935	2372189
         3048024	2372189
         3048299	2371908
         3048476	2371912
         3048565	2371815
         3048834	2371818
         3049103	2371537
         3049728	2371537
         3049821	2371627
         3050086	2371631
         3050183	2371725
         3050269	2371725
         3050360	2371812
         3050448	2371818
         3050533	2371909
         3050630	2371913
         3050723	2372004
         3051437	2372000
         3051521	2371909
         3052509	2371909
         3052598	2372006
         3052778	2372003
         3052871	2372100
         3052954	2372100
         3053140	2372284
         3053229	2372281
         3053420	2372550
         3053447	2373365
         3053584	2373502
         3054124	2373502
         3054209	2373412
         3054390	2373409
         3054480	2373318
         3054749	2373315
         3054837	2373223
         3055283	2373223
         3055379	2373127
         3055734	2373130
         3055824	2373029
         3056003	2373036
         3056092	2372941
         3056899	2372938
         3056987	2373036
         3057082	2373036
         3057212	2373173
         3057209	2373547
         3057125	2373648
         3057122	2373735
         3057077	2373783
         3056894	2373786
         3055864	2374864
         3055867	2375048
         3055957	2375146
         3055959	2375237
         3056318	2375612
         3056318	2375709
         3056719	2376132
         3057082	2376128
         3057170	2376034
         3057523	2376030
         3057621	2375947
         3057705	2375943
         3057750	2375893
         3057754	2375802
         3057888	2375659
         3058155	2375663
         3058240	2375571
         3058420	2375568
         3058516	2375661
         3059050	2375661
         3059141	2375565
         3059319	2375561
         3059498	2375380
         3059587	2375380
         3059678	2375287
         3060128	2375280
         3060212	2375190
         3060391	2375196
         3060484	2375283
         3060573	2375289
         3060662	2375192
         3060752	2375189
         3060845	2375286
         3060928	2375282
         3061021	2375379
         3061289	2375376
         3061377	2375472
         3061556	2375469
         3061604	2375513
         3061604	2375610
         3061828	2375848
         3062007	2375845
         3062099	2375938
         3062362	2375944
         3062541	2375754
         3062628	2375754
         3062726	2375654
         3062903	2375659
         3062992	2375747
         3063258	2375750
         3063347	2375847
         3063530	2375844
         3063619	2375940
         3063801	2375937
         3063885	2376030
         3063977	2376030
         3064067	2376128
         3064512	2376128
         3064604	2376225
         3064694	2376222
         3064786	2376313
         3064960	2376316
         3065053	2376413
         3065324	2376410
         3065413	2376316
         3065587	2376316
         3065678	2376215
         3065945	2376218
         3066041	2376128
         3066125	2376128
         3066218	2376222
         3066935	2376218
         3067024	2376315
         3067117	2376315
         3067293	2376500
         3067565	2376503
         3067653	2376403
         3067834	2376409
         3067927	2376496
         3068100	2376502
         3068189	2376590
         3068281	2376595
         3068371	2376683
         3068454	2376689
         3068634	2376874
         3069176	2376874
         3069267	2376971
         3069349	2376968
         3069446	2376877
         3069536	2376877
         3069624	2376783
         3069709	2376783
         3069806	2376685
         3070340	2376692
         3070429	2376592
         3070519	2376592
         3070699	2376401
         3070787	2376406
         3070877	2376316
         3070966	2376313
         3071055	2376215
         3071144	2376215
         3071238	2376308
         3071503	2376313
         3071593	2376215
         3072045	2376215
         3072134	2376124
         3072669	2376124
         3072758	2376024
         3072847	2376030
         3073119	2375748
         3073296	2375745
         3073385	2375654
         3073565	2375650
         3073653	2375559
         3074105	2375559
         3074192	2375650
         3074281	2375654
         3074371	2375745
         3074815	2375745
         3074905	2375654
         3074997	2375650
         3075309	2375325
         3075314	2375228
         3075445	2375091
         3075628	2375088
         3075711	2375184
         3075894	2375181
         3075986	2375278
         3076076	2375184
         3076165	2375184
         3076341	2374994
         3076434	2374994
         3076607	2374810
         3077061	2374803
         3077148	2374712
         3077235	2374719
         3077420	2374903
         3078316	2374903
         3078400	2374994
         3078579	2374998
         3078764	2375182
         3079030	2375185
         3079119	2375277
         3079213	2375280
         3079258	2375327
         3079252	2375415
         3079437	2375609
         3079428	2376356
         3079525	2376453
         3079525	2377012
         3079483	2377059
         3079300	2377062
         3079121	2377250
         3079032	2377253
         3078901	2377391
         3078901	2377578
         3078760	2377722
         3078408	2377717
         3078184	2377946
         3078180	2378605
         3078270	2378700
         3078270	2379164
         3078093	2379355
         3078093	2379452
         3077914	2379634
         3077909	2380014
         3077824	2380105
         3077829	2380196
         3077730	2380296
         3077733	2380669
         3077822	2380766
         3077822	2380857
         3077999	2381047
         3078002	2381138
         3078047	2381182
         3078136	2381188
         3078316	2381372
         3078405	2381372
         3078495	2381466
         3078676	2381462
         3078760	2381560
         3079394	2381564
         3079481	2381655
         3079932	2381655
         3080912	2380623
         3081008	2380619
         3081226	2380391
         3081232	2380294
         3081497	2380013
         3081497	2379916
         3081540	2379872
         3081633	2379875
         3081722	2379779
         3081991	2379782
         3082080	2379688
         3082435	2379684
         3082528	2379779
         3082980	2379782
         3083068	2379875
         3083245	2379872
         3083332	2379969
         3083518	2379966
         3083602	2380062
         3083694	2380059
         3083784	2380156
         3083966	2380152
         3084050	2380249
         3084321	2380246
         3084456	2380390
         3084456	2380481
         3084545	2380578
         3084549	2380669
         3084594	2380718
         3084764	2380715
         3084860	2380812
         3085312	2380812
         3085581	2380531
         3085665	2380531
         3085760	2380437
         3085847	2380437
         3085940	2380339
         3086293	2380339
         3086386	2380437
         3086651	2380440
         3086834	2380625
         3087189	2380625
         3087372	2380810
         3087550	2380623
         3087729	2380626
         3087816	2380720
         3087905	2380720
         3088001	2380623
         3088629	2380626
         3088719	2380723
         3089250	2380720
         3089340	2380811
         3089438	2380814
         3089522	2380905
         3089705	2380909
         3089788	2380999
         3089970	2381002
         3090058	2381090
         3091133	2381097
         3091229	2380995
         3091946	2380999
         3092029	2380909
         3092215	2380905
         3092299	2381002
         3092663	2381002
         3092752	2381093
         3092929	2381097
         3093018	2381188
         3093200	2381191
         3093284	2381285
         3093646	2381281
         3093739	2381375
         3094808	2381375
         3094901	2381468
         3095083	2381471
         3095259	2381656
         3095441	2381656
         3095531	2381749
         3095975	2381749
         3096068	2381846
         3096693	2381843
         3096780	2381937
         3096958	2381943
         3097048	2381843
         3097141	2381843
         3097230	2381936
         3097681	2381936
         3097860	2381755
         3098123	2381752
         3098216	2381845
         3098398	2381842
         3098481	2381939
         3098750	2381935
         3098933	2381751
         3099291	2381751
         3099384	2381842
         3099560	2381845
         3099650	2381942
         3099739	2381842
         3099916	2381842
         3100009	2381748
         3100101	2381748
         3100191	2381655
         3100543	2381658
         3100636	2381752
         3100723	2381752
         3100819	2381848
         3100903	2381845
         3100996	2381942
         3101265	2381936
         3101354	2381845
         3101805	2381839
         3101889	2381755
         3101979	2381752
         3102075	2381655
         3102251	2381658
         3102344	2381560
         3102610	2381564
         3102699	2381470
         3103323	2381467
         3103416	2381564
         3103503	2381564
         3103596	2381464
         3103777	2381467
         3103865	2381376
         3103959	2381376
         3104402	2380904
         3104492	2380904
         3104677	2380720
         3104850	2380716
         3104940	2380625
         3105564	2380622
         3105657	2380715
         3105836	2380715
         3105923	2380809
         3106112	2380805
         3106194	2380902
         3106285	2380899
         3106371	2380995
         3106550	2380999
         3106642	2381090
         3106732	2380996
         3107183	2380996
         3107271	2381093
         3107539	2381088
         3107632	2381184
         3108612	2381188
         3108708	2381091
         3108884	2381094
         3108973	2381186
         3111035	2381186
         3111128	2381094
         3111304	2381091
         3111393	2381000
         3111482	2380996
         3111570	2380905
         3111663	2380902
         3111752	2380811
         3111931	2380807
         3112020	2380716
         3112110	2380716
         3112289	2380532
         3112378	2380619
         3112733	2380623
         3112825	2380716
         3113367	2380716
         3113451	2380616
         3113638	2380619
         3113720	2380528
         3114263	2380528
         3114352	2380623
         3116231	2380618
         3116318	2380528
         3116411	2380525
         3116501	2380622
         3116588	2380622
         3116677	2380715
         3116859	2380712
         3116946	2380809
         3117576	2380805
         3117621	2380855
         3117618	2380946
         3117669	2380995
         3117753	2380995
         3117845	2381090
         3118389	2381090
         3118473	2381177
         3119107	2381173
         3119190	2381271
         3119459	2381271
         3119546	2381361
         3119817	2381365
         3119911	2381459
         3120177	2381456
         3120266	2381549
         3120627	2381549
         3120715	2381640
         3121610	2381646
         3121698	2381546
         3122235	2381551
         3122328	2381645
         3122684	2381639
         3122773	2381736
         3123400	2381739
         3123583	2381549
         3123765	2381552
         3123854	2381456
         3124206	2381456
         3124301	2381552
         3124928	2381549
         3125019	2381643
         3125289	2381646
         3125377	2381739
         3125648	2381736
         3125737	2381829
         3125821	2381829
         3125914	2381926
         3126184	2381921
         3126269	2382017
         3126542	2382017
         3126634	2382114
         3127707	2382111
         3127794	2382017
         3127977	2382021
         3128062	2381924
         3128421	2382300
         3128514	2382306
         3128601	2382393
         3129235	2382397
         3129500	2382114
         3129590	2382111
         3129678	2382021
         3129772	2382107
         3130127	2382111
         3130309	2381926
         3130576	2381923
         3130621	2381973
         3130621	2382064
         3130755	2382208
         3131290	2382208
         3131379	2382301
         3131471	2382301
         3131559	2382201
         3132004	2382206
         3132366	2381835
         3132548	2381831
         3132637	2381730
         3132907	2381735
         3132996	2381644
         3133179	2381640
         3133399	2381408
         3133402	2381215
         3133492	2381124
         3133488	2380846
         3133846	2380466
         3133846	2380376
         3133937	2380275
         3133940	2380187
         3133849	2380091
         3133937	2379999
         3133937	2379908
         3133982	2379855
         3134162	2379852
         3134207	2379805
         3134207	2379717
         3134247	2379670
         3134520	2379666
         3134699	2379482
         3135057	2379482
         3135145	2379385
         3135237	2379388
         3135326	2379291
         3135419	2379288
         3135595	2379107
         3135684	2379104
         3135775	2379012
         3135953	2379009
         3136043	2378916
         3136132	2378916
         3136222	2378824
         3136312	2378821
         3136400	2378730
         3136490	2378727
         3136579	2378636
         3136758	2378632
         3137028	2378910
         3137120	2378917
         3137341	2379151
         3137337	2379332
         3137568	2379572
         3137650	2379572
         3137753	2379478
         3137842	2379391
         3137926	2379387
         3138015	2379297
         3138114	2379293
         3138514	2378871
         3138508	2378774
         3138601	2378686
         3138604	2378589
         3138825	2378355
         3138915	2378355
         3139093	2378164
         3139183	2378167
         3139276	2378071
         3139545	2378076
         3139632	2377979
         3139810	2377983
         3139903	2377889
         3140076	2377893
         3140166	2377796
         3140440	2377793
         3140528	2377699
         3140886	2377699
         3140974	2377601
         3141335	2377608
         3141428	2377515
         3141781	2377511
         3141873	2377417
         3143126	2377417
         3143218	2377323
         3143489	2377327
         3143574	2377233
         3143845	2377230
         3143938	2377142
         3144117	2377137
         3144204	2377043
         3144383	2377047
         3144475	2376950
         3144654	2376946
         3144741	2376859
         3145371	2376855
         3145634	2376573
         3145727	2376577
         3145815	2376479
         3145910	2376483
         3146178	2376196
         3146267	2376199
         3146668	2375781
         3146668	2375683
         3146844	2375498
         3146847	2375407
         3146940	2375310
         3146935	2374751
         3146983	2374697
         3147427	2374702
         3147516	2374604
         3147788	2374607
         3147964	2374417
         3148063	2374421
         3148147	2374324
         3148239	2374327
         3148553	2373995
         3148556	2373904
         3148732	2373714
         3148732	2373623
         3148819	2373530
         3148819	2373433
         3148951	2373292
         3149313	2373292
         3149401	2373201
         3149495	2373204
         3149582	2373107
         3149761	2373104
         3149853	2373016
         3149943	2373011
         3149981	2372967
         3149985	2372869
         3150168	2372685
         3150163	2372588
         3150300	2372447
         3150390	2372451
         3150474	2372354
         3150835	2372354
         3150929	2372257
         3151018	2372261
         3151105	2372163
         3151194	2372167
         3151370	2371983
         3151469	2371983
         3151507	2371932
         3151507	2371841
         3151824	2371510
         3151907	2371513
         3152001	2371417
         3152090	2371420
         3152311	2371182
         3152314	2370997
         3152407	2370900
         3152403	2370714
         3153031	2370060
         3153034	2369969
         3153071	2369920
         3153163	2369920
         3153211	2369876
         3153211	2369779
         3153480	2369498
         3153483	2369401
         3153797	2369073
         3153881	2369073
         3153973	2368976
         3154335	2368982
         3154873	2368417
         3154962	2368420
         3155231	2368132
         3155321	2368136
         3155583	2367855
         3155679	2367855
         3155718	2367811
         3155721	2367714
         3156080	2367338
         3156083	2367247
         3156390	2366920
         3156481	2366920
         3156573	2366823
         3156662	2366827
         3156799	2366686
         3156796	2366588
         3156978	2366398
         3156978	2366024
         3157061	2365936
         3157066	2365839
         3157242	2365648
         3157245	2365087
         3157154	2364996
         3157159	2364905
         3157069	2364808
         3157063	2364717
         3156983	2364616
         3156974	2364438
         3157025	2364384
         3157114	2364389
         3157421	2364057
         3157424	2363966
         3157561	2363825
         3157653	2363829
         3157736	2363732
         3157822	2363735
         3157919	2363639
         3158009	2363642
         3158233	2363398
         3158233	2363307
         3158364	2363170
         3158456	2363170
         3158905	2362699
         3158997	2362702
         3159174	2362511
         3159262	2362511
         3159356	2362418
         3159439	2362418
         3159532	2362330
         3159622	2362324
         3160341	2361574
         3160431	2361574
         3160785	2361200
         3160876	2361203
         3160968	2361105
         3161058	2361110
         3161234	2360926
         3161324	2360919
         3161416	2360831
         3161507	2360825
         3161592	2360738
         3161683	2360732
         3161775	2360641
         3161864	2360644
         3161948	2360548
         3162041	2360551
         3162130	2360454
         3162220	2360458
         3162399	2360267
         3162488	2360267
         3162978	2359752
         3162981	2359655
         3163075	2359561
         3163075	2359374
         3163205	2359234
         3163298	2359234
         3163385	2359141
         3163496	2359141
         3163561	2359145
         3163652	2359048
         3163830	2359051
         3163917	2358958
         3164007	2358958
         3164100	2358861
         3164371	2358867
         3164461	2358770
         3164816	2358770
         3164908	2358674
         3165267	2358674
         3165354	2358577
         3165533	2358580
         3165622	2358486
         3165714	2358486
         3165891	2358296
         3165984	2358296
         3166163	2358115
         3166250	2358115
         3166295	2358066
         3166299	2357974
         3166657	2357600
         3166660	2357509
         3166836	2357318
         3166839	2357221
         3167194	2356844
         3167194	2356756
         3167593	2356328
         3167689	2356331
         3167782	2356234
         3167866	2356234
         3167959	2356141
         3168137	2356145
         3168314	2355960
         3168676	2355957
         3168721	2355919
         3168853	2355859
         3168898	2355812
         3168901	2355621
         3168940	2355575
         3169038	2355578
         3169122	2355480
         3169214	2355484
         3169299	2355387
         3169484	2355390
         3169663	2355206
         3169842	2355203
         3170018	2355018
         3170107	2355013
         3170469	2354637
         3170559	2354637
         3170735	2354453
         3170828	2354449
         3170917	2354359
         3171010	2354353
         3171095	2354265
         3171183	2354265
         3171497	2353935
         3171500	2353838
         3171814	2353515
         3171896	2353515
         3172755	2352627
         3172755	2352529
         3172931	2352344
         3172931	2352248
         3173019	2352160
         3173021	2352064
         3173111	2351967
         3173114	2351876
         3173383	2351588
         3173377	2351502
         3173470	2351404
         3173470	2351217
         3173557	2351124
         3173557	2351033
         3173650	2350936
         3173650	2350561
         3173739	2350468
         3173736	2350190
         3173828	2350097
         3173831	2350006
         3174008	2349816
         3174008	2349718
         3174101	2349628
         3174095	2349531
         3174278	2349346
         3174281	2349250
         3174374	2349162
         3174368	2349066
         3174461	2348969
         3174461	2348878
         3174553	2348785
         3174550	2348507
         3174630	2348409
         3174639	2348126
         3174723	2348033
         3174726	2347942
         3174637	2347851
         3174640	2347658
         3174499	2347519
         3174234	2347516
         3174146	2347423
         3174058	2347423
         3174013	2347376
         3174013	2347189
         3174054	2347146
         3174506	2347146
         3174632	2347005
         3174548	2346908
         3174548	2346817
         3174459	2346726
         3174456	2346630
         3174371	2346537
         3174368	2346342
         3174278	2346251
         3174278	2346160
         3174192	2346064
         3174192	2345973
         3174098	2345876
         3174098	2345785
         3173920	2345595
         3173923	2345504
         3173872	2345457
         3173071	2345454
         3172979	2345360
         3172886	2345360
         3172575	2345032
         3172578	2344942
         3172490	2344845
         3172483	2344748
         3172669	2344564
         3172663	2344377
         3172755	2344284
         3172755	2344193
         3172803	2344149
         3172892	2344144
         3172976	2344053
         3173069	2344056
         3173335	2343768
         3173428	2343768
         3173516	2343675
         3173606	2343675
         3173699	2343582
         3173783	2343582
         3173876	2343489
         3173965	2343489
         3174058	2343394
         3174146	2343394
         3174323	2343210
         3174414	2343210
         3174632	2342977
         3174637	2342880
         3174819	2342696
         3174813	2342599
         3174999	2342415
         3174999	2342317
         3175092	2342227
         3175086	2342036
         3175178	2341945
         3175173	2341849
         3175266	2341752
         3175266	2341665
         3175359	2341568
         3175352	2341477
         3175444	2341384
         3175448	2341197
         3175532	2341100
         3175535	2341003
         3175624	2340916
         3175629	2340355
         3175714	2340261
         3175714	2340074
         3175809	2339978
         3175809	2339887
         3176567	2339088
         3176656	2339088
         3176788	2338948
         3176792	2338857
         3176973	2338667
         3176967	2338480
         3177060	2338392
         3177060	2338295
         3177147	2338199
         3177147	2338108
         3177240	2338015
         3177243	2337828
         3177327	2337731
         3177327	2337263
         3177419	2337172
         3177419	2336798
         3177509	2336704
         3177509	2335950
         3177419	2335859
         3177419	2335769
         3177332	2335671
         3177332	2335580
         3177147	2335390
         3177147	2335204
         3177060	2335113
         3177057	2335017
         3176877	2334832
         3176882	2334735
         3176615	2334454
         3176615	2334363
         3176386	2334130
         3176027	2334124
         3175942	2334033
         3175854	2334033
         3175758	2334126
         3175492	2334123
         3175316	2334312
         3175138	2334309
         3175089	2334363
         3175089	2334460
         3175050	2334503
         3174863	2334500
         3174731	2334363
         3174735	2334079
         3174636	2333988
         3174641	2333705
         3174556	2333614
         3174556	2333143
         3174459	2333052
         3174459	2332484
         3174371	2332394
         3174371	2332206
         3174286	2332115
         3174279	2332019
         3174103	2331835
         3174103	2331738
         3174013	2331647
         3174017	2331551
         3173743	2331270
         3173746	2331179
         3173428	2330845
         3173345	2330850
         3173075	2330570
         3172986	2330570
         3172891	2330470
         3172806	2330475
         3172714	2330382
         3172179	2330382
         3172083	2330286
         3171909	2330289
         3171814	2330198
         3171730	2330195
         3171640	2330098
         3171369	2330101
         3171282	2330002
         3171010	2330005
         3170879	2329861
         3170873	2329770
         3171010	2329630
         3171100	2329633
         3171192	2329537
         3171370	2329540
         3171458	2329447
         3171814	2329444
         3172130	2329119
         3172133	2329023
         3172623	2328508
         3173343	2328504
         3173431	2328417
         3173609	2328413
         3173791	2328229
         3174153	2328226
         3174234	2328317
         3176118	2328320
         3176208	2328411
         3176297	2328411
         3176386	2328511
         3176476	2328511
         3176565	2328604
         3176744	2328604
         3176834	2328697
         3177105	2328694
         3177192	2328792
         3177374	2328788
         3177461	2328885
         3177732	2328881
         3177822	2328975
         3178001	2328978
         3178091	2329069
         3178269	2329072
         3178360	2329163
         3178712	2329163
         3178808	2329260
         3179611	2329256
         3179701	2329349
         3180146	2329344
         3180241	2329446
         3181317	2329443
         3181401	2329352
         3183196	2329352
         3183286	2329443
         3183737	2329443
         3183826	2329346
         3184895	2329349
         3184988	2329258
         3185439	2329253
         3185529	2329165
         3185702	2329160
         3185795	2329072
         3186065	2329069
         3186246	2328885
         3186333	2328878
         3186422	2328792
         3186512	2328785
         3186605	2328697
         3186868	2328694
         3186960	2328597
         3187049	2328601
         3187139	2328510
         3187320	2328506
         3187411	2328410
         3187493	2328410
         3187588	2328322
         3187676	2328317
         3187766	2328229
         3187858	2328224
         3188079	2327996
         3188082	2327899
         3188173	2327802
         3188169	2327621
         3188389	2327387
         3188571	2327384
         3188661	2327288
         3188750	2327288
         3188843	2327200
         3189016	2327197
         3189109	2327100
         3189196	2327100
         3189289	2327013
         3189381	2327007
         3189647	2326735
         3189737	2326729
         3189829	2326642
         3189914	2326642
         3191489	2325002
         3191482	2324905
         3191664	2324721
         3191667	2324535
         3191752	2324438
         3191755	2324347
         3191844	2324254
         3191847	2324157
         3191937	2324066
         3191932	2323970
         3192024	2323876
         3192027	2323785
         3192116	2323688
         3192110	2323597
         3192203	2323504
         3192206	2323318
         3192290	2323222
         3192293	2323124
         3192383	2323038
         3192386	2322850
         3192559	2322660
         3192565	2322474
         3192747	2322290
         3192741	2322199
         3192835	2322103
         3192835	2322005
         3192920	2321912
         3192920	2321726
         3193014	2321629
         3193011	2321351
         3193100	2321258
         3193100	2320884
         3193193	2320797
         3193190	2320514
         3193279	2320416
         3193276	2320139
         3193368	2320046
         3193365	2319860
         3193454	2319762
         3193457	2319576
         3193551	2319483
         3193548	2319206
         3193637	2319109
         3193640	2319015
         3193724	2318925
         3193727	2318641
         3193820	2318548
         3193820	2318457
         3193907	2318361
         3193907	2318265
         3194083	2318079
         3194083	2317990
         3194269	2317799
         3194263	2317708
         3194673	2317287
         3194765	2317284
         3195025	2317004
         3195115	2317004
         3195517	2316587
         3192655	2239104
         3192655	2145300
         3154747	1977327
         3218072	1885705
         3189464	1736037
         3189302	1736102
         3189157	1736151
         3189061	1736248
         3188964	1736248
         3188868	1736248
         3188723	1736248
         3188626	1736248
         3188530	1736054
         3188288	1736054
         3188046	1736151
         3187853	1736248
         3187611	1736297
         3187419	1736394
         3187322	1736491
         3187273	1736491
         3187080	1736588
         3186935	1736588
         3186742	1736588
         3186742	1736491
         3186646	1736394
         3186500	1736394
         3186404	1736491
         3186307	1736588
         3186211	1736588
         3186211	1736491
         3186066	1736394
         3186066	1736151
         3185969	1736054
         3185727	1735957
         3185535	1735957
         3185292	1736054
         3185196	1736054
         3185051	1736151
         3184858	1736248
         3184762	1736297
         3184713	1736394
         3184616	1736491
         3184424	1736588
         3184181	1736637
         3184085	1736734
         3183989	1736831
         3183989	1736929
         3183747	1737025
         3183843	1736734
         3183940	1736637
         3183940	1736588
         3183843	1736394
         3183747	1736297
         3183747	1736248
         3183554	1736151
         3183409	1736054
         3183167	1736054
         3182926	1736151
         3178191	1736783
         3176259	1737997
         3176211	1738046
         3175969	1738192
         3175680	1738289
         3175535	1738289
         3175293	1738386
         3175100	1738483
         3174858	1738532
         3174762	1738629
         3174569	1738629
         3174424	1738629
         3174085	1738629
         3174037	1738629
         3173458	1738581
         3172636	1738289
         3170221	1737171
         3170075	1737074
         3169787	1736929
         3169545	1736831
         3169303	1736734
         3168965	1736637
         3168772	1736588
         3168675	1736588
         3168530	1736588
         3168240	1736394
         3168192	1736297
         3168095	1736248
         3167806	1736054
         3167661	1735957
         3167565	1735908
         3167468	1735811
         3167274	1735471
         3167130	1735471
         3166984	1735374
         3166984	1735277
         3166984	1735034
         3167080	1734839
         3167080	1734791
         3166984	1734596
         3166791	1734402
         3166646	1734159
         3166453	1733916
         3166308	1733819
         3166308	1733722
         3166356	1733576
         3166453	1733430
         3166453	1733285
         3166453	1733236
         3166646	1733236
         3166791	1733236
         3166888	1733285
         3167080	1733382
         3167080	1733479
         3167226	1733576
         3167274	1733625
         3167419	1733722
         3167661	1733819
         3167806	1733819
         3168095	1733916
         3168337	1734013
         3168530	1734062
         3168772	1734159
         3168965	1734159
         3169207	1734159
         3169255	1734159
         3169352	1734159
         3169352	1734353
         3169303	1734353
         3169303	1734499
         3169352	1734694
         3169545	1734839
         3169641	1734936
         3169641	1735034
         3169641	1735131
         3169545	1735277
         3169545	1735374
         3169545	1735471
         3169545	1735617
         3169545	1735714
         3169641	1735811
         3169787	1736054
         3169979	1736248
         3170125	1736297
         3170318	1736297
         3170414	1736394
         3170463	1736491
         3170656	1736491
         3170752	1736394
         3170849	1736394
         3170994	1736491
         3171187	1736637
         3171332	1736734
         3171574	1736831
         3171767	1737074
         3171863	1737171
         3171960	1737171
         3172009	1737074
         3171960	1736929
         3171960	1736637
         3171960	1736588
         3171960	1736491
         3171960	1736394
         3171960	1736297
         3171960	1736248
         3171912	1736248
         3170897	1735374
         3170897	1735277
         3170897	1735179
         3170752	1735131
         3170559	1735034
         3170318	1734936
         3170221	1734839
         3170125	1734694
         3170075	1734499
         3170075	1734402
         3170125	1734353
         3170221	1734353
         3170414	1734353
         3170656	1734353
         3170849	1734402
         3171090	1734596
         3171187	1734694
         3171187	1734791
         3171429	1734791
         3171622	1734839
         3172444	1735325
         3172636	1735374
         3172878	1735471
         3172974	1735471
         3173120	1735811
         3173313	1735957
         3173409	1735957
         3173409	1735908
         3173409	1735811
         3173216	1735471
         3173120	1735471
         3173071	1735374
         3173216	1735277
         3173409	1735277
         3173651	1735374
         3173747	1735471
         3173892	1735714
         3173989	1735908
         3174182	1735957
         3174327	1735957
         3174520	1736054
         3174666	1736151
         3174762	1736151
         3174954	1736151
         3175100	1736151
         3175196	1736151
         3175196	1736054
         3175293	1736054
         3175535	1736054
         3175680	1736054
         3175777	1735811
         3175631	1735277
         3175631	1735179
         3175442	1734888
         3175293	1734791
         3175100	1734596
         3174762	1734499
         3174569	1734353
         3174424	1734256
         3174520	1734159
         3174520	1734062
         3174520	1733916
         3174182	1733819
         3173989	1733819
         3173747	1733722
         3173554	1733625
         3173458	1733625
         3173409	1733382
         3173120	1733236
         3172878	1733139
         3172685	1732896
         3172636	1732896
         3172685	1732799
         3172878	1732702
         3173071	1732702
         3173120	1732605
         3174520	1732896
         3175342	1733382
         3175728	1733625
         3176211	1733722
         3176308	1733722
         3176549	1733722
         3176646	1733722
         3176742	1733625
         3176839	1733625
         3176984	1733625
         3177177	1733722
         3177226	1733819
         3177322	1733916
         3177515	1733916
         3177757	1733916
         3177853	1733819
         3177853	1733722
         3177950	1733479
         3178095	1733236
         3177950	1733139
         3177757	1732896
         3177515	1732702
         3177322	1732605
         3177080	1732605
         3176839	1732605
         3176646	1732605
         3176453	1732605
         3176404	1732507
         3176404	1732362
         3176453	1732264
         3176453	1732119
         3176308	1732119
         3176115	1732119
         3175873	1732119
         3175631	1732119
         3175439	1732022
         3175196	1731924
         3174954	1731924
         3174666	1731924
         3174424	1731924
         3174182	1731827
         3173989	1731730
         3173844	1731585
         3173747	1731341
         3173458	1731050
         3173313	1731050
         3173071	1731147
         3172926	1731196
         3171380	1731585
         3171332	1731585
         3171187	1731585
         3170994	1731585
         3170752	1731585
         3170559	1731585
         3170318	1731585
         3170075	1731585
         3169979	1731487
         3170125	1731390
         3170414	1731390
         3170656	1731341
         3170752	1731341
         3170994	1731147
         3171187	1731050
         3171332	1731002
         3171429	1731002
         3171429	1730807
         3171332	1730613
         3171187	1730564
         3170897	1730467
         3170656	1730273
         3170656	1730224
         3170559	1730127
         3170559	1729933
         3170656	1729933
         3170849	1729933
         3171090	1729884
         3171187	1729884
         3171235	1729884
         3171525	1729690
         3171574	1729544
         3171622	1729544
         3171863	1729496
         3172009	1729447
         3172105	1729350
         3172298	1729156
         3172347	1729107
         3172347	1729010
         3172347	1728913
         3172298	1728816
         3172105	1728719
         3172105	1728670
         3172105	1728378
         3172105	1728330
         3172009	1728233
         3171767	1728233
         3171574	1728233
         3171525	1728136
         3171429	1728039
         3171429	1727893
         3171187	1727747
         3170994	1727747
         3170752	1727747
         3170656	1727747
         3170366	1728136
         3170414	1728233
         3170656	1728378
         3170849	1728670
         3170849	1728719
         3170704	1728767
         3170656	1728816
         3170752	1729010
         3170656	1729107
         3170559	1729156
         3170414	1729156
         3170414	1729350
         3170221	1729496
         3170075	1729496
         3169834	1729544
         3169690	1729787
         3169545	1729690
         3169352	1729690
         3169303	1729544
         3169158	1729641
         3167757	1729738
         3167565	1729690
         3167565	1729884
         3167661	1729933
         3167661	1730127
         3167661	1730224
         3167468	1730273
         3167468	1730321
         3167565	1730467
         3167565	1730564
         3167468	1730807
         3167468	1730904
         3167661	1731002
         3167757	1731002
         3167806	1731050
         3167806	1731147
         3167902	1731245
         3168192	1731147
         3168337	1731341
         3168530	1731487
         3168772	1731585
         3168868	1731681
         3168965	1731730
         3168965	1731924
         3168965	1732022
         3168772	1732119
         3168965	1732264
         3168965	1732362
         3168868	1732459
         3168578	1732507
         3168434	1732605
         3168530	1732702
         3168530	1732799
         3168530	1732896
         3168578	1732896
         3168772	1732896
         3168868	1732896
         3168868	1733139
         3168868	1733236
         3168772	1733236
         3168434	1733382
         3168337	1733479
         3168192	1733576
         3168095	1733576
         3167806	1733576
         3167757	1733479
         3167130	1733139
         3167130	1732896
         3167130	1732702
         3167130	1732507
         3167080	1732264
         3166888	1732119
         3166839	1732022
         3165052	1730904
         3164811	1730807
         3164569	1730710
         3164424	1730564
         3164134	1730467
         3164085	1730273
         3163941	1730273
         3163699	1730224
         3163651	1730224
         3163651	1730127
         3163699	1730030
         3163893	1730030
         3164134	1730030
         3164328	1729933
         3164328	1729884
         3164473	1729884
         3164473	1730030
         3164569	1730127
         3164666	1730127
         3164714	1730127
         3164908	1730127
         3165101	1730030
         3165342	1729933
         3165439	1729933
         3165583	1729933
         3165680	1729884
         3165873	1729496
         3165970	1729350
         3166018	1729107
         3166115	1728816
         3166115	1728670
         3166115	1728378
         3166115	1728233
         3166115	1727990
         3166115	1727601
         3166115	1727456
         3166018	1727213
         3165970	1727019
         3165052	1725853
         3165004	1725804
         3164714	1725561
         3164473	1725367
         3163313	1724784
         3163120	1724687
         3163023	1724639
         3161477	1724347
         3161381	1724347
         3161139	1724396
         3160995	1724541
         3160898	1724590
         3160801	1724590
         3160560	1724590
         3160366	1724541
         3160125	1724396
         3160028	1724396
         3159979	1724347
         3159883	1724250
         3159787	1724202
         3159690	1724105
         3159690	1723910
         3159594	1723668
         3159545	1723473
         3159449	1723133
         3159449	1722987
         3159449	1722696
         3159545	1722648
         3159449	1722550
         3159449	1722453
         3159352	1722356
         3159352	1722308
         3159255	1722113
         3159207	1722016
         3159110	1721968
         3159014	1721774
         3158917	1721774
         3158820	1721676
         3158772	1721676
         3158482	1721676
         3158338	1721676
         3158241	1721774
         3158144	1721822
         3156646	1723036
         3155149	1724930
         3155005	1725659
         3155005	1725902
         3155005	1726096
         3155101	1726144
         3155149	1726339
         3155246	1726436
         3155439	1726485
         3155584	1726485
         3155825	1726581
         3155922	1726581
         3156115	1726776
         3156260	1726921
         3156453	1726970
         3156598	1727116
         3156695	1727116
         3156695	1727213
         3156695	1727358
         3156937	1727456
         3157227	1727553
         3157371	1727601
         3157661	1727747
         3157661	1727893
         3157806	1727990
         3158096	1728136
         3158241	1728330
         3158338	1728476
         3158434	1728670
         3158482	1728719
         3158579	1728719
         3158482	1728913
         3158482	1729010
         3158338	1729107
         3158241	1729253
         3158144	1729156
         3158096	1729156
         3158000	1729350
         3157903	1729350
         3157806	1729350
         3157565	1729350
         3157227	1729253
         3157033	1729253
         3156937	1729156
         3156888	1729107
         3156792	1728816
         3156695	1728573
         3156598	1728330
         3156550	1728136
         3156453	1728039
         3156260	1727990
         3156115	1727893
         3155825	1727747
         3155584	1727601
         3155439	1727601
         3155246	1727601
         3155149	1727553
         3155005	1727261
         3154908	1727116
         3154811	1727116
         3154570	1727116
         3154376	1727116
         3154231	1727116
         3154135	1727116
         3153941	1727213
         3153893	1727261
         3153796	1727553
         3153603	1727601
         3153361	1727601
         3153217	1727601
         3152927	1727601
         3152782	1727553
         3152782	1727456
         3152492	1727213
         3152348	1726970
         3152298	1726970
         3149256	1723862
         3146116	1721434
         3146019	1721337
         3145826	1721239
         3145681	1721094
         3145584	1721094
         3145487	1720997
         3145343	1720899
         3145246	1720899
         3145149	1720754
         3145053	1720657
         3144956	1720414
         3144956	1720317
         3144956	1720219
         3144762	1720025
         3143797	1718957
         3143459	1718763
         3143265	1718666
         3143024	1718666
         3142734	1718666
         3142589	1718423
         3142589	1718326
         3142686	1718229
         3142686	1718180
         3142734	1718180
         3142830	1718180
         3142927	1718180
         3143072	1718083
         3143072	1717889
         3143024	1717792
         3143072	1717646
         3143265	1717549
         3143459	1717452
         3143700	1717209
         3143700	1717403
         3143700	1717549
         3143603	1717792
         3143603	1717986
         3143603	1718083
         3143700	1718180
         3143845	1718423
         3144135	1718520
         3144280	1718666
         3144377	1718666
         3144570	1718569
         3144812	1718520
         3144956	1718423
         3145053	1718423
         3146695	1718617
         3146792	1718520
         3146937	1718423
         3147130	1718423
         3147227	1718520
         3147469	1718569
         3147710	1718666
         3147903	1718666
         3148144	1718666
         3148338	1718666
         3148579	1718763
         3148724	1718763
         3148917	1718763
         3149352	1718666
         3149545	1718520
         3149594	1718423
         3149594	1718375
         3149787	1718132
         3149932	1718083
         3150029	1718083
         3150126	1717646
         3150029	1717452
         3149884	1717306
         3149835	1717306
         3149691	1717209
         3149545	1717112
         3149497	1717015
         3149497	1716967
         3149691	1716869
         3149787	1716530
         3149787	1716432
         3149787	1716335
         3149691	1716287
         3149594	1716093
         3149497	1715995
         3149449	1715947
         3149449	1715850
         3149691	1715656
         3149787	1715413
         3149787	1715219
         3149787	1715170
         3149691	1714976
         3149641	1714830
         3149641	1714636
         3149691	1714636
         3149787	1714539
         3149932	1714442
         3150126	1714393
         3150367	1714393
         3150463	1714296
         3150608	1714199
         3150705	1714199
         3150946	1714102
         3151043	1713956
         3152540	1712354
         3152589	1712306
         3152686	1712209
         3152782	1711189
         3152782	1711044
         3152782	1710947
         3152782	1710849
         3152782	1710753
         3152927	1710558
         3153072	1710170
         3153217	1709976
         3153361	1709879
         3153361	1709830
         3153361	1709636
         3153361	1709539
         3153217	1709539
         3153024	1709539
         3152830	1709539
         3152782	1709490
         3152348	1709151
         3152251	1709151
         3152106	1709053
         3152106	1708957
         3152009	1708762
         3151913	1708762
         3151816	1708957
         3151816	1709053
         3151671	1709151
         3151574	1709151
         3151478	1709151
         3151139	1709151
         3150946	1709296
         3150608	1709296
         3150463	1709296
         3150126	1709296
         3150029	1709296
         3149932	1709296
         3149787	1709296
         3149691	1709296
         3149449	1709393
         3149352	1709490
         3149303	1709539
         3149159	1709636
         3149062	1709636
         3148821	1709539
         3148579	1709490
         3148579	1709393
         3148579	1709296
         3148579	1709199
         3148482	1709151
         3148434	1709151
         3147372	1708714
         3147275	1708617
         3147275	1708520
         3147227	1708422
         3147130	1708374
         3146840	1708277
         3146599	1708277
         3146357	1708374
         3146164	1708277
         3146019	1708277
         3146019	1708083
         3146164	1707937
         3146164	1707792
         3146646	1706918
         3146695	1706870
         3146792	1706724
         3146792	1706627
         3146937	1706529
         3147130	1706529
         3147227	1706481
         3147227	1706433
         3147275	1706238
         3147227	1706190
         3147130	1706190
         3147081	1706238
         3146889	1706238
         3146357	1705996
         3146019	1705801
         3145922	1705753
         3145681	1705607
         3145681	1705365
         3145681	1705268
         3145584	1705171
         3145391	1705073
         3145343	1705025
         3145149	1705025
         3145101	1705025
         3144859	1705122
         3144715	1705171
         3144666	1705219
         3144570	1705219
         3144473	1705171
         3143459	1705025
         3143507	1705025
         3142927	1704637
         3142830	1704637
         3142734	1704637
         3141913	1704297
         3141720	1704297
         3141623	1704249
         3141575	1704249
         3141381	1704491
         3141140	1704637
         3140899	1704734
         3140850	1704831
         3140802	1704928
         3140705	1705025
         3140608	1705025
         3140512	1704928
         3140512	1704734
         3140464	1704734
         3139932	1704637
         3139835	1704637
         3139594	1704637
         3139401	1704637
         3139353	1704637
         3139401	1704831
         3139401	1705025
         3139353	1705268
         3139256	1705413
         3139063	1705705
         3138966	1705753
         3138966	1705947
         3138966	1706044
         3139063	1706044
         3139256	1706044
         3139691	1706384
         3139835	1706870
         3139835	1707306
         3139835	1707403
         3139739	1707500
         3139594	1707597
         3139497	1707597
         3139401	1707646
         3139401	1707743
         3139353	1708034
         3139256	1708083
         3139159	1708083
         3138966	1707937
         3138724	1708083
         3138628	1708180
         3138628	1708277
         3138628	1708422
         3138580	1708520
         3138483	1708520
         3138290	1708520
         3137807	1708859
         3137807	1708957
         3137855	1709151
         3137855	1709199
         3138048	1709199
         3138145	1709296
         3138193	1709296
         3138290	1709296
         3138290	1709393
         3138193	1709490
         3138145	1709539
         3138193	1709733
         3138290	1709830
         3138338	1710073
         3138386	1710219
         3138531	1710267
         3138580	1710267
         3138724	1710073
         3138821	1709879
         3138918	1709879
         3138966	1709976
         3138966	1710073
         3139063	1710170
         3139063	1710267
         3138966	1710510
         3138966	1710655
         3138966	1710849
         3138966	1710947
         3138966	1711044
         3138966	1711092
         3139159	1711286
         3139353	1711432
         3139401	1711626
         3139497	1711723
         3139739	1711966
         3140173	1712160
         3140367	1712209
         3140802	1712403
         3140850	1712403
         3141043	1712500
         3141140	1712645
         3141237	1712888
         3141285	1713082
         3141381	1713277
         3141478	1713325
         3141623	1713519
         3141720	1713665
         3141816	1713956
         3141816	1714199
         3141816	1714393
         3141816	1714539
         3141864	1714588
         3142106	1714733
         3142154	1714733
         3142251	1714879
         3142251	1715073
         3142251	1715170
         3142251	1715219
         3142251	1715316
         3142251	1715510
         3142396	1715752
         3142396	1715850
         3142348	1715850
         3142202	1715850
         3141961	1716093
         3141913	1716190
         3141816	1716287
         3141816	1716335
         3141913	1716481
         3141913	1716530
         3141720	1716530
         3141623	1716432
         3141575	1716432
         3141381	1716335
         3141140	1716432
         3140899	1716432
         3140705	1716432
         3140512	1716384
         3140222	1716287
         3140029	1716190
         3137372	1715073
         3137082	1714976
         3136647	1714879
         3136599	1714879
         3136357	1714879
         3136164	1714879
         3135585	1714976
         3135391	1714976
         3135053	1714976
         3134859	1714976
         3134618	1714976
         3134377	1714976
         3132541	1714393
         3131188	1714199
         3129933	1714053
         3129836	1714053
         3129595	1714053
         3129401	1714053
         3129207	1714053
         3129160	1714053
         3128869	1713762
         3128869	1713665
         3128822	1713665
         3128725	1713665
         3128725	1713762
         3128725	1713811
         3128725	1714005
         3128628	1714053
         3128387	1714102
         3128193	1714199
         3128048	1714199
         3127710	1714199
         3127565	1714151
         3127034	1713956
         3126841	1713956
         3126696	1714005
         3123314	1714588
         3123169	1714636
         3122734	1714733
         3122203	1714636
         3122252	1714539
         3122396	1714199
         3122396	1714102
         3122300	1714053
         3122203	1714053
         3122059	1714053
         3121768	1714053
         3121527	1713956
         3121430	1713956
         3121141	1713956
         3120995	1713762
         3120851	1713617
         3120609	1713423
         3120030	1712888
         3119981	1712888
         3119981	1712840
         3119981	1712645
         3119546	1712500
         3119402	1712403
         3119111	1712306
         3118870	1712209
         3118725	1712209
         3118532	1712160
         3118532	1712063
         3118532	1711966
         3118629	1711869
         3118629	1711772
         3118629	1711626
         3118532	1711432
         3118435	1711383
         3118338	1711286
         3118338	1711189
         3118629	1711189
         3118725	1711092
         3118773	1711044
         3118870	1710947
         3118967	1710849
         3119111	1710849
         3119305	1710947
         3119546	1711044
         3119836	1711092
         3119884	1711092
         3119981	1711092
         3120222	1711092
         3120512	1711092
         3120657	1711092
         3120851	1711092
         3121092	1711044
         3121333	1710947
         3121624	1710849
         3121721	1710753
         3121768	1710655
         3121865	1710558
         3121962	1710073
         3121962	1709879
         3121962	1709636
         3121962	1709296
         3121962	1709151
         3121962	1708714
         3121962	1708422
         3121962	1708180
         3122106	1707452
         3122106	1707258
         3122300	1706966
         3122396	1706821
         3122493	1706529
         3122493	1706287
         3122541	1706190
         3122541	1706044
         3122493	1705753
         3122493	1705413
         3122396	1705171
         3122396	1704928
         3122396	1704637
         3122396	1704394
         3122396	1704249
         3122493	1704151
         3122541	1703812
         3122734	1703715
         3122734	1703618
         3122734	1703375
         3122734	1703181
         3122638	1703035
         3122638	1702841
         3122541	1702405
         3122493	1702162
         3122493	1701919
         3122493	1701628
         3122541	1701385
         3122638	1701240
         3122687	1700949
         3122638	1698862
         3121817	1696630
         3118967	1691488
         3118435	1690469
         3118387	1690372
         3118242	1689936
         3118194	1689936
         3118097	1689693
         3118000	1689402
         3117662	1687753
         3117614	1687607
         3117517	1687462
         3117373	1687365
         3117179	1687171
         3117083	1686880
         3116745	1686589
         3116407	1686249
         3116310	1686152
         3115682	1684746
         3115489	1684211
         3114860	1681545
         3114763	1681351
         3114522	1680915
         3114329	1680575
         3113991	1680139
         3113846	1679896
         3113556	1679460
         3113315	1679121
         3113121	1678878
         3112880	1678635
         3112735	1678393
         3112638	1678199
         3112591	1678102
         3112494	1677957
         3112300	1677860
         3111962	1677569
         3111672	1677230
         3111527	1676890
         3111431	1676745
         3111527	1676550
         3111527	1676405
         3111672	1676550
         3112107	1676648
         3112300	1676745
         3112494	1676793
         3112591	1676842
         3112783	1677084
         3112976	1677327
         3113025	1677375
         3113460	1677860
         3113653	1677860
         3113653	1677666
         3113556	1677569
         3113460	1677423
         3113411	1677230
         3113218	1676890
         3113218	1676550
         3113218	1676308
         3113073	1676211
         3112735	1676017
         3112203	1675775
         3111865	1675629
         3111527	1675533
         3111334	1675339
         3111189	1675193
         3110996	1674999
         3110899	1674854
         3110851	1674757
         3110754	1674660
         3110561	1674660
         3110465	1674854
         3110175	1674854
         3110078	1674854
         3110078	1674999
         3110126	1675193
         3110175	1675339
         3110561	1675629
         3110899	1676017
         3110996	1676211
         3110996	1676357
         3110948	1676405
         3110899	1676454
         3110851	1676502
         3110851	1676648
         3110851	1676745
         3110754	1676648
         3110561	1676454
         3110319	1676114
         3109884	1675775
         3109546	1675629
         3109208	1675436
         3108774	1675290
         3108436	1674999
         3108339	1674951
         3105779	1672817
         3103170	1671751
         3102977	1671654
         3102783	1671654
         3102542	1671557
         3102542	1671218
         3102445	1671073
         3102252	1670878
         3101914	1670878
         3101866	1670830
         3099499	1669327
         3096987	1668407
         3096552	1668310
         3096359	1668212
         3096214	1668067
         3096166	1668019
         3094571	1666807
         3094282	1666565
         3094233	1666467
         3094233	1666177
         3094040	1665983
         3092687	1665305
         3092398	1665062
         3092253	1665014
         3092011	1664965
         3091722	1664965
         3091383	1664965
         3091045	1664965
         3090513	1664868
         3090369	1664820
         3090224	1664577
         3089982	1664335
         3089934	1664335
         3089596	1664093
         3089258	1663996
         3085973	1663947
         3085924	1663947
         3085683	1663947
         3085393	1663850
         3085393	1663802
         3085103	1663753
         3084813	1663753
         3084475	1663753
         3084282	1663753
         3083219	1663753
         3082929	1663753
         3082591	1663753
         3082495	1663753
         3082060	1663608
         3081722	1663414
         3081238	1663221
         3081238	1663172
         3080852	1662881
         3080466	1662736
         3080417	1662687
         3079838	1662299
         3079547	1662009
         3079500	1661912
         3079354	1661621
         3079258	1661185
         3079258	1660991
         3079354	1660991
         3079500	1661088
         3079741	1661088
         3079982	1661282
         3081818	1662590
         3081818	1662736
         3081914	1662833
         3082253	1662833
         3082495	1662833
         3082495	1662736
         3082398	1662299
         3082253	1661863
         3082060	1661767
         3082060	1661427
         3082011	1661282
         3081914	1661427
         3081914	1661524
         3081576	1661524
         3081480	1661427
         3081238	1661282
         3080997	1661040
         3080659	1660943
         3080466	1660943
         3080176	1660991
         3079934	1660943
         3079838	1660846
         3079838	1660797
         3079692	1660604
         3079596	1660604
         3079354	1660507
         3079258	1660410
         3079065	1660313
         3078919	1660313
         3078581	1660313
         3078581	1660410
         3078919	1660652
         3078919	1660749
         3078678	1660652
         3078389	1660604
         3078050	1660507
         3077616	1660410
         3077181	1660313
         3076843	1660168
         3076505	1660168
         3076118	1660168
         3076021	1660265
         3075780	1660361
         3075152	1660507
         3075056	1660555
         3074910	1660555
         3074668	1660555
         3073413	1660168
         3072350	1659441
         3072253	1659343
         3072108	1659247
         3071722	1658762
         3071529	1658520
         3071480	1658326
         3071480	1658278
         3071287	1657987
         3071142	1657841
         3070949	1657745
         3070611	1657648
         3070176	1657599
         3069839	1657599
         3069645	1657599
         3069404	1657648
         3069258	1657648
         3069162	1657502
         3068969	1657405
         3068727	1657212
         3068631	1657212
         3068437	1657309
         3068389	1657405
         3067374	1657502
         3066988	1657405
         3066312	1657212
         3066167	1657163
         3065925	1657066
         3065200	1656824
         3065104	1656776
         3064717	1656630
         3064283	1656485
         3063848	1656291
         3063413	1656194
         3063075	1656000
         3062785	1655952
         3062350	1655807
         3062061	1655758
         3061384	1655758
         3060901	1655710
         3060418	1655613
         3060177	1655516
         3060080	1655419
         3059742	1655177
         3059307	1654935
         3059210	1654838
         3058969	1654741
         3058631	1654595
         3058196	1654499
         3058003	1654401
         3057520	1653965
         3057471	1653917
         3057326	1653820
         3055394	1653093
         3055056	1652900
         3050757	1649218
         3050660	1649170
         3049887	1648782
         3049452	1648637
         3048486	1648007
         3048438	1647959
         3048341	1647862
         3048100	1647619
         3047858	1647377
         3047520	1646845
         3047375	1646506
         3046748	1645391
         3046505	1645101
         3045443	1644278
         3045346	1644181
         3045249	1644084
         3045008	1643648
         3044814	1643357
         3044670	1643164
         3044380	1643018
         3044332	1642970
         3044138	1642825
         3044138	1642728
         3044138	1642631
         3044041	1642534
         3043994	1642486
         3043897	1642389
         3043800	1642243
         3043800	1642098
         3043897	1641808
         3042303	1640355
         3042061	1640161
         3042013	1640161
         3042013	1639967
         3042109	1639919
         3042206	1639725
         3042206	1639629
         3042206	1639532
         3042206	1639483
         3042206	1639386
         3042254	1639386
         3042882	1639386
         3042979	1639289
         3043027	1639144
         3043124	1638853
         3043124	1638805
         3043124	1638708
         3043124	1638612
         3042979	1638224
         3042834	1638031
         3042641	1637837
         3042351	1637837
         3042013	1637837
         3041916	1637837
         3041868	1637837
         3041819	1637837
         3041723	1637837
         3041627	1637934
         3041384	1638031
         3041240	1638031
         3041240	1638176
         3041337	1638272
         3041337	1638418
         3041337	1638708
         3041241	1638708
         3041240	1638805
         3041192	1638853
         3040999	1638950
         3040902	1638950
         3040805	1639048
         3040805	1639144
         3040805	1639193
         3040467	1639289
         3040370	1639289
         3040322	1639289
         3040225	1639289
         3040129	1639289
         3040081	1639289
         3039984	1639241
         3037521	1638079
         3037424	1637982
         3033463	1635513
         3031337	1634883
         3027086	1632608
         3027038	1632608
         3026941	1632511
         3026168	1631833
         3025347	1630962
         3025250	1630913
         3024478	1630042
         3021483	1626799
         3021434	1626750
         3021386	1626702
         3021386	1626556
         3021386	1626411
         3021386	1626315
         3021289	1626169
         3021192	1626073
         3021000	1626073
         3020903	1626121
         3020806	1626073
         3020709	1625976
         3020565	1625927
         3020468	1625830
         3020324	1625685
         3020178	1625540
         3020227	1625443
         3020516	1625637
         3020565	1625637
         3020613	1625589
         3020709	1625492
         3020758	1625540
         3020854	1625589
         3020903	1625589
         3020951	1625492
         3020951	1625395
         3021000	1625298
         3021096	1625298
         3021289	1625298
         3021386	1625395
         3021483	1625540
         3021531	1625637
         3021579	1625782
         3021627	1625879
         3021724	1625927
         3021821	1625927
         3021918	1625879
         3021918	1625734
         3021965	1625685
         3022062	1625637
         3022159	1625637
         3022352	1625637
         3022497	1625637
         3022497	1625540
         3022400	1625492
         3022304	1625443
         3022256	1625395
         3022208	1625346
         3022111	1625249
         3022062	1625201
         3021965	1625201
         3021918	1625249
         3021918	1625346
         3021869	1625395
         3021821	1625346
         3021676	1625298
         3021531	1625249
         3021434	1625249
         3021386	1625201
         3021386	1625056
         3021338	1624960
         3021289	1624911
         3021192	1624814
         3021096	1624862
         3021000	1624960
         3020709	1625153
         3020662	1625153
         3020613	1625105
         3020613	1625008
         3020709	1624960
         3020903	1624814
         3020854	1624620
         3020758	1624427
         3020709	1624379
         3020806	1624379
         3020903	1624524
         3021144	1624524
         3021144	1624475
         3021096	1624427
         3021000	1624379
         3021000	1624282
         3020951	1624233
         3020854	1624088
         3020662	1623894
         3020516	1623798
         3020371	1623798
         3020275	1623701
         3020275	1623507
         3020275	1623313
         3020324	1623217
         3020420	1623217
         3020468	1623265
         3020516	1623362
         3020662	1623410
         3020709	1623265
         3020806	1623168
         3020903	1623023
         3020903	1622927
         3020903	1622733
         3020903	1622588
         3020903	1622443
         3020951	1622394
         3021000	1622249
         3021000	1622200
         3020951	1622104
         3020951	1622007
         3021000	1621910
         3021096	1621813
         3021144	1621717
         3021241	1621668
         3021289	1621572
         3021289	1621523
         3021241	1621475
         3021096	1621426
         3020951	1621426
         3020903	1621426
         3020806	1621426
         3020806	1621329
         3020758	1621232
         3020468	1621039
         3020324	1620894
         3020227	1620845
         3020033	1620845
         3019937	1620894
         3019889	1621039
         3019840	1621281
         3019840	1621378
         3019743	1621378
         3019695	1621329
         3019599	1621232
         3019502	1621184
         3019454	1621232
         3019357	1621329
         3019261	1621668
         3019261	1621862
         3019212	1621959
         3019212	1622055
         3019261	1622200
         3019212	1622297
         3019164	1622394
         3019067	1622491
         3019019	1622491
         3018874	1622539
         3018729	1622588
         3018584	1622636
         3018391	1622684
         3018149	1622733
         3018149	1622684
         3018246	1622636
         3018294	1622588
         3018391	1622588
         3018440	1622539
         3018487	1622491
         3018487	1622346
         3018487	1622297
         3018487	1622200
         3018487	1622152
         3018440	1622104
         3018391	1622104
         3018294	1622104
         3018246	1622152
         3018198	1622200
         3018101	1622297
         3018005	1622346
         3017908	1622443
         3017859	1622491
         3017811	1622539
         3017667	1622588
         3017618	1622636
         3017521	1622684
         3017425	1622781
         3017376	1622927
         3017473	1623023
         3017521	1623072
         3017714	1623265
         3017811	1623410
         3017859	1623556
         3017859	1623653
         3017859	1623749
         3017763	1623749
         3017714	1623798
         3017714	1623894
         3017811	1623943
         3018053	1624040
         3018681	1624330
         3019309	1624620
         3019599	1624814
         3019792	1624960
         3019840	1625056
         3019840	1625153
         3019792	1625153
         3019695	1625105
         3019599	1624960
         3019405	1624862
         3019309	1624814
         3019212	1624814
         3019164	1624814
         3019067	1624717
         3019067	1624620
         3018970	1624572
         3018294	1624282
         3017618	1624088
         3016555	1623798
         3014719	1623265
         3014623	1623168
         3014623	1623120
         3014672	1623023
         3014816	1622975
         3014913	1622975
         3015010	1623023
         3015057	1623023
         3015154	1623072
         3015203	1623072
         3015299	1622975
         3015348	1622781
         3015396	1622684
         3015492	1622588
         3015686	1622539
         3015783	1622539
         3015879	1622539
         3015927	1622491
         3016024	1622394
         3016072	1622394
         3016169	1622443
         3016217	1622491
         3016362	1622491
         3016459	1622443
         3016555	1622346
         3016700	1622249
         3016845	1622200
         3016845	1622055
         3016748	1622055
         3016555	1622152
         3016459	1622200
         3016362	1622200
         3016314	1622104
         3016555	1621959
         3016604	1621862
         3016604	1621717
         3016555	1621668
         3016555	1621572
         3016604	1621475
         3016604	1621378
         3016459	1621426
         3016362	1621572
         3016362	1621717
         3016410	1621813
         3016410	1621910
         3016362	1621910
         3016314	1621862
         3016265	1621813
         3016217	1621668
         3016169	1621620
         3015734	1621620
         3015541	1621620
         3015348	1621523
         3015299	1621378
         3015348	1621329
         3015396	1621378
         3015445	1621426
         3015445	1621378
         3015541	1621281
         3015541	1621232
         3015445	1621184
         3015348	1621184
         3015057	1621184
         3014672	1621184
         3014575	1621136
         3014526	1621136
         3014478	1620991
         3014526	1620942
         3014719	1620942
         3015203	1620749
         3015348	1620652
         3015348	1620555
         3015396	1620458
         3015492	1620361
         3015734	1620265
         3015830	1620265
         3015927	1620361
         3016024	1620458
         3016072	1620458
         3016121	1620361
         3016169	1620265
         3016217	1620265
         3016314	1620265
         3016362	1620217
         3016410	1620168
         3016555	1620120
         3016748	1620023
         3016990	1619877
         3017135	1619732
         3017183	1619636
         3017183	1619539
         3017135	1619491
         3017086	1619394
         3017038	1619297
         3017280	1619200
         3017329	1619248
         3017473	1619297
         3017618	1619248
         3017618	1619200
         3017618	1619055
         3017618	1618813
         3017521	1618716
         3017473	1618668
         3017376	1618571
         3017280	1618523
         3017086	1618474
         3016990	1618474
         3016797	1618523
         3016748	1618619
         3016748	1618765
         3016604	1619006
         3016459	1619103
         3016217	1619151
         3016024	1619248
         3015830	1619248
         3015734	1619200
         3015589	1619200
         3015445	1619151
         3015348	1619055
         3015251	1618958
         3015251	1618861
         3015251	1618765
         3015251	1618619
         3015203	1618571
         3015107	1618523
         3015057	1618571
         3015010	1618619
         3014961	1618716
         3014961	1618765
         3014961	1618910
         3014961	1619006
         3014913	1619103
         3014913	1619200
         3014816	1619248
         3014719	1619297
         3014623	1619297
         3014430	1619297
         3014333	1619248
         3014285	1619248
         3014237	1619200
         3014188	1619151
         3014140	1619055
         3014140	1618958
         3014140	1618910
         3014140	1618813
         3014091	1618765
         3014091	1618668
         3014043	1618571
         3014043	1618377
         3014043	1618280
         3014043	1618232
         3014043	1618135
         3013995	1618087
         3013947	1618087
         3013850	1618087
         3013608	1618135
         3013464	1618135
         3013270	1618135
         3013077	1618135
         3012835	1618184
         3012739	1618184
         3012691	1618280
         3012594	1618523
         3012594	1619587
         3012546	1619829
         3012594	1619974
         3012642	1620265
         3012739	1620458
         3012884	1620603
         3013415	1621136
         3013802	1621523
         3014140	1621910
         3014188	1622055
         3014188	1622200
         3014188	1622443
         3014237	1622588
         3014333	1622636
         3014526	1622781
         3014575	1622878
         3014575	1623023
         3014526	1623072
         3014478	1623023
         3014381	1622927
         3014285	1622781
         3014140	1622636
         3014140	1622443
         3014140	1622200
         3014091	1622055
         3013947	1621910
         3013512	1621378
         3012304	1620361
         3012159	1620265
         3009937	1618716
         3009743	1618426
         3009743	1618377
         3009743	1618280
         3009743	1618184
         3009743	1618135
         3009743	1618039
         3009743	1617942
         3009696	1617894
         3009309	1616974
         3009261	1616926
         3009261	1616829
         3009261	1616732
         3009261	1616635
         3009067	1616394
         3007086	1614894
         3005831	1613926
         3005396	1613636
         3005203	1613587
         3003415	1612523
         3003319	1612474
         3003126	1612233
         3002112	1611362
         3002063	1611362
         3001966	1611362
         3001869	1611265
         3001773	1611168
         3001773	1611071
         3001773	1611023
         3001773	1610926
         3001773	1610878
         3001628	1610684
         3001483	1610539
         3000228	1609862
         2996894	1608846
         2995879	1608701
         2994914	1608604
         2994865	1608604
         2994768	1608507
         2994334	1608411
         2994286	1608411
         2994189	1608411
         2994092	1608411
         2993996	1608411
         2993899	1608362
         2993851	1608265
         2993754	1608169
         2993706	1608120
         2992981	1607830
         2992450	1607733
         2992160	1607637
         2992112	1607637
         2992015	1607637
         2991966	1607637
         2991870	1607588
         2991773	1607588
         2991629	1607588
         2991532	1607588
         2991435	1607588
         2987087	1607491
         2986991	1607491
         2986895	1607491
         2986749	1607491
         2986653	1607491
         2986556	1607491
         2986411	1607491
         2986315	1607491
         2986122	1607491
         2986073	1607491
         2984430	1607153
         2984334	1607153
         2984189	1607153
         2984141	1607153
         2983996	1607056
         2983900	1607056
         2983803	1607056
         2983754	1606959
         2983658	1606959
         2983561	1606959
         2983465	1606959
         2983416	1606959
         2983320	1606959
         2983223	1606959
         2983030	1606959
         2982981	1606959
         2982885	1606959
         2982789	1606959
         2982692	1606959
         2982643	1606959
         2982546	1606959
         2982402	1606959
         2982354	1606959
         2982208	1606959
         2982112	1606959
         2982016	1606959
         2979262	1607491
         2979213	1607491
         2979069	1607491
         2979021	1607491
         2978924	1607491
         2978875	1607491
         2978683	1607491
         2978586	1607491
         2978537	1607491
         2978440	1607491
         2978344	1607491
         2978248	1607491
         2978151	1607491
         2978054	1607491
         2977764	1607395
         2977667	1607298
         2977571	1607153
         2977475	1607056
         2977426	1607056
         2977329	1607056
         2977137	1607153
         2977088	1607153
         2977040	1607153
         2976991	1607153
         2976799	1607153
         2976702	1607153
         2976653	1607153
         2976509	1607153
         2976460	1607153
         2976364	1607153
         2976315	1607153
         2974769	1606476
         2974673	1606476
         2974624	1606476
         2973707	1606476
         2972693	1606330
         2969698	1606959
         2969407	1607008
         2966991	1607491
         2966944	1607491
         2966895	1607491
         2966122	1607491
         2965688	1607491
         2965494	1607491
         2965349	1607395
         2965204	1607250
         2964142	1607056
         2963949	1607056
         2963466	1607056
         2963127	1607056
         2962789	1607056
         2962547	1607056
         2961292	1606717
         2961050	1606621
         2960953	1606572
         2960374	1606427
         2960036	1606379
         2958973	1606379
         2958393	1606427
         2956509	1606814
         2956171	1606862
         2955736	1607056
         2955398	1607153
         2955205	1607153
         2954963	1606959
         2954963	1606862
         2955060	1606814
         2955253	1606524
         2955446	1606330
         2955591	1606282
         2955591	1606185
         2955591	1606040
         2955495	1605750
         2955398	1605605
         2955398	1605508
         2955398	1605169
         2955157	1605024
         2955060	1605024
         2955060	1605073
         2955060	1605412
         2954963	1605750
         2954963	1605943
         2954963	1606137
         2954915	1606185
         2954722	1606476
         2954625	1606621
         2954625	1606814
         2954625	1606959
         2954625	1607153
         2954481	1607056
         2954287	1606959
         2954191	1606621
         2954142	1606476
         2953949	1606476
         2953611	1606476
         2953466	1606572
         2952065	1606814
         2951824	1606814
         2951774	1606814
         2950664	1607008
         2950374	1607153
         2950036	1607250
         2949602	1607491
         2949505	1607491
         2949263	1607491
         2948925	1607588
         2948345	1607637
         2948297	1607637
         2948345	1607491
         2948345	1607056
         2948297	1606717
         2948297	1606476
         2948200	1606717
         2947959	1607056
         2947862	1607395
         2947862	1607491
         2947814	1607491
         2947524	1607491
         2947186	1607491
         2946848	1607491
         2946751	1607395
         2946703	1607153
         2946751	1607153
         2946848	1607153
         2947186	1607056
         2947379	1607056
         2947379	1606862
         2947283	1606862
         2947089	1606814
         2946703	1606717
         2946316	1606621
         2945978	1606621
         2945737	1606621
         2941727	1607830
         2941534	1607927
         2941196	1608072
         2941099	1608072
         2941099	1607927
         2941099	1607830
         2941196	1607830
         2941292	1607637
         2941389	1607491
         2941631	1607491
         2941631	1607250
         2941534	1607153
         2941437	1607056
         2941292	1606959
         2941292	1607153
         2941196	1607395
         2941099	1607491
         2940761	1607830
         2940616	1607830
         2940519	1608023
         2940519	1608072
         2940423	1608169
         2940375	1608265
         2939264	1608604
         2939215	1608604
         2938877	1608604
         2938539	1608846
         2938201	1608701
         2937862	1608604
         2937669	1608604
         2937331	1608894
         2937283	1609136
         2937186	1609136
         2936945	1609136
         2936558	1609281
         2936317	1609427
         2934432	1610829
         2932210	1611797
         2931196	1612136
         2927911	1613393
         2927138	1614071
         2926799	1614603
         2926752	1614748
         2926655	1614748
         2926558	1614603
         2926461	1614603
         2926414	1614748
         2926220	1615135
         2926172	1615135
         2926123	1615135
         2926076	1615039
         2925979	1614845
         2925882	1614845
         2925544	1614748
         2925447	1614748
         2925302	1615039
         2925302	1615280
         2925254	1615280
         2925206	1615329
         2925206	1615377
         2925254	1615474
         2925302	1615571
         2925302	1615619
         2925302	1615861
         2925254	1615909
         2925109	1615909
         2925061	1615909
         2924868	1615909
         2924723	1615909
         2924626	1615861
         2924577	1615764
         2924385	1615668
         2924192	1615619
         2923804	1615619
         2923757	1615619
         2923708	1615668
         2923660	1615861
         2923612	1615909
         2923563	1615909
         2923322	1615909
         2922935	1615958
         2922887	1615958
         2922790	1616006
         2922549	1616151
         2922307	1616248
         2922163	1616248
         2922066	1616200
         2921920	1616151
         2921873	1616103
         2921824	1616006
         2921776	1615909
         2921776	1615861
         2921728	1615813
         2921679	1615813
         2921438	1615909
         2921390	1615909
         2921341	1616006
         2921341	1616103
         2921293	1616151
         2921148	1616297
         2921003	1616297
         2920906	1616297
         2920520	1616394
         2920279	1616442
         2920133	1616490
         2919216	1616490
         2919022	1616442
         2918925	1616394
         2918925	1616297
         2918925	1616248
         2918878	1616006
         2918878	1615958
         2918781	1615909
         2918733	1615909
         2918684	1615909
         2918443	1615909
         2918395	1615909
         2918298	1616006
         2918249	1616151
         2918201	1616297
         2918153	1616539
         2918105	1616587
         2918008	1616635
         2917911	1616684
         2917766	1616732
         2917525	1616780
         2917284	1616684
         2917138	1616587
         2917090	1616490
         2916849	1616151
         2916703	1615958
         2916703	1615909
         2916752	1615861
         2916946	1615571
         2916993	1615377
         2916993	1615135
         2916993	1614845
         2916849	1614748
         2916511	1614748
         2916076	1615135
         2915883	1615668
         2915883	1615716
         2915738	1615861
         2915641	1615909
         2915544	1615909
         2915496	1615909
         2915496	1615958
         2915592	1616055
         2915786	1616200
         2915786	1616248
         2915786	1616345
         2915738	1616394
         2915689	1616394
         2915592	1616394
         2914723	1616151
         2914627	1616103
         2914433	1615958
         2914289	1615813
         2914143	1615619
         2914047	1615523
         2914192	1614119
         2914240	1614071
         2914240	1613926
         2914143	1613732
         2913902	1613636
         2913999	1613490
         2914143	1613393
         2914240	1613393
         2914240	1613297
         2913999	1613297
         2913708	1613297
         2913370	1613393
         2913322	1613490
         2913322	1613732
         2913322	1613877
         2913322	1613926
         2913081	1613926
         2912936	1613877
         2912840	1613829
         2912791	1613732
         2912743	1613684
         2912694	1613684
         2912597	1613684
         2912549	1613684
         2912452	1613829
         2912259	1613974
         2912114	1614119
         2912114	1614216
         2912114	1614313
         2912114	1614361
         2912211	1614361
         2912211	1614409
         2912211	1614506
         2912211	1614555
         2912211	1614652
         2912163	1614748
         2912114	1614748
         2911921	1614845
         2912017	1614942
         2912114	1614942
         2912163	1614942
         2912259	1614942
         2912259	1614990
         2912259	1615135
         2912211	1615232
         2912114	1615280
         2912114	1615377
         2912211	1615474
         2912259	1615571
         2912259	1615716
         2912114	1615861
         2911680	1615909
         2911583	1615909
         2911342	1615909
         2911245	1615958
         2911342	1616151
         2911342	1616297
         2911294	1616394
         2911245	1616394
         2911197	1616394
         2911148	1616442
         2911148	1616490
         2911245	1616587
         2911486	1616635
         2911486	1616732
         2911438	1616732
         2911100	1616732
         2910955	1616635
         2910569	1616345
         2910472	1616200
         2910569	1615764
         2910713	1615619
         2911004	1615280
         2911052	1615039
         2911052	1614845
         2911052	1614603
         2911052	1614168
         2911052	1613926
         2911052	1613877
         2911052	1613829
         2911004	1613781
         2910907	1613732
         2910810	1613732
         2910665	1613732
         2910617	1613781
         2910569	1613829
         2910569	1613926
         2910569	1614023
         2910520	1614119
         2910472	1614119
         2909892	1614506
         2909892	1614603
         2909941	1614748
         2909892	1614845
         2909845	1614894
         2909264	1615135
         2909023	1615184
         2908975	1615184
         2908878	1615135
         2908830	1614748
         2908830	1614652
         2908878	1614603
         2908975	1614652
         2909023	1614603
         2909023	1614506
         2909023	1614458
         2908975	1614361
         2908878	1614313
         2908830	1614216
         2908830	1614168
         2908781	1613684
         2908781	1613636
         2908781	1613587
         2908491	1613490
         2908250	1613490
         2908153	1613490
         2908008	1613636
         2908008	1613732
         2908057	1614023
         2908008	1614071
         2908008	1614168
         2908008	1614264
         2907912	1614361
         2907573	1614409
         2907332	1614506
         2907332	1614603
         2907235	1614942
         2907235	1615280
         2907235	1615329
         2907188	1615377
         2907139	1615426
         2907139	1615474
         2907139	1615523
         2907042	1615668
         2906994	1615668
         2906897	1615523
         2906704	1615184
         2906607	1615087
         2906559	1615039
         2906462	1615039
         2906269	1614942
         2906269	1614748
         2906221	1614506
         2905835	1614264
         2905593	1614264
         2905496	1614264
         2905255	1614168
         2905255	1614071
         2905255	1614023
         2905351	1613829
         2905351	1613684
         2906415	1611797
         2906559	1611700
         2906559	1611603
         2906462	1611458
         2906221	1611313
         2906028	1611265
         2905786	1611265
         2905496	1611362
         2905255	1611362
         2904916	1611265
         2904820	1611168
         2904627	1611168
         2904434	1611265
         2904337	1611410
         2904337	1611652
         2904337	1611748
         2904385	1611797
         2904482	1612039
         2904385	1612378
         2904385	1612474
         2903951	1612571
         2903902	1612571
         2903805	1612523
         2903805	1612474
         2903661	1612087
         2903612	1611990
         2903564	1611942
         2903274	1611845
         2902936	1611700
         2902791	1611603
         2902598	1611603
         2902163	1611845
         2902067	1611845
         2901921	1611748
         2901729	1611603
         2901729	1611362
         2901825	1611362
         2901921	1611265
         2901921	1611071
         2901825	1610926
         2902018	1610829
         2901921	1610636
         2901680	1610491
         2901583	1610491
         2901583	1610249
         2901583	1610152
         2901486	1609813
         2901342	1609523
         2901245	1609281
         2901052	1609136
         2900956	1609136
         2900810	1609088
         2900617	1608991
         2900569	1608701
         2900472	1608507
         2900472	1608362
         2900569	1608265
         2900714	1608265
         2900810	1608169
         2900907	1608072
         2901052	1608072
         2901486	1608169
         2901680	1607975
         2901680	1607927
         2901680	1607733
         2901583	1607637
         2901486	1607491
         2901342	1607491
         2901052	1607491
         2901052	1607395
         2900956	1607250
         2900907	1607250
         2900810	1607056
         2900617	1606959
         2900472	1606959
         2900037	1606959
         2899941	1606862
         2899941	1606814
         2899845	1606717
         2899699	1606717
         2899699	1606862
         2899603	1606862
         2899361	1606621
         2899023	1606379
         2898830	1606185
         2898830	1606040
         2898926	1605943
         2899023	1606040
         2899168	1606137
         2899361	1606185
         2899458	1606185
         2899506	1606040
         2899458	1605750
         2899361	1605508
         2899264	1605169
         2899023	1604686
         2898734	1604396
         2898588	1604202
         2898540	1604154
         2898540	1604105
         2898491	1604057
         2898491	1603960
         2898491	1603863
         2898395	1603815
         2898347	1603767
         2898202	1603718
         2898057	1603718
         2897623	1603718
         2897477	1603622
         2897381	1603573
         2897332	1603476
         2897188	1603187
         2897139	1603138
         2896850	1602848
         2896946	1602606
         2897139	1602606
         2897139	1602509
         2897139	1602267
         2897139	1602122
         2897284	1602122
         2897284	1602074
         2897139	1601832
         2897139	1601639
         2897188	1601348
         2897284	1601300
         2897574	1601300
         2897719	1601300
         2897719	1600962
         2897719	1600623
         2897719	1600381
         2897623	1600043
         2897574	1599849
         2897381	1599559
         2897188	1599076
         2897042	1598737
         2896607	1598398
         2896607	1598302
         2896607	1597963
         2896607	1597867
         2896801	1597818
         2896946	1597818
         2897042	1597625
         2897139	1597528
         2897188	1597528
         2897284	1597722
         2897381	1597625
         2897623	1597625
         2897719	1597528
         2897719	1597383
         2897623	1597286
         2897477	1597286
         2897477	1597189
         2897623	1596851
         2897719	1596802
         2897912	1596416
         2897912	1596222
         2897912	1595836
         2897961	1595400
         2897961	1595062
         2897961	1594627
         2897961	1594433
         2897574	1592838
         2897574	1592741
         2897574	1592499
         2897574	1592306
         2897477	1592257
         2897381	1592064
         2897381	1591871
         2897381	1591532
         2897477	1591484
         2897623	1591097
         2897719	1590759
         2897815	1590710
         2898057	1590614
         2898250	1590614
         2898395	1590420
         2898685	1590179
         2898685	1590082
         2898830	1589647
         2898926	1589308
         2899168	1588969
         2899264	1588728
         2899264	1588535
         2899264	1588293
         2899361	1588051
         2899361	1587713
         2899458	1587374
         2899458	1586939
         2899458	1586842
         2899458	1586649
         2899361	1586504
         2899361	1586456
         2898347	1585392
         2898250	1585199
         2898250	1585054
         2898250	1584861
         2898153	1584619
         2898153	1584522
         2898057	1584087
         2897912	1583846
         2897574	1583507
         2897139	1583169
         2896801	1582879
         2896607	1582734
         2896607	1582540
         2896511	1582105
         2896511	1581767
         2896463	1581380
         2896173	1580994
         2896125	1580994
         2894096	1579689
         2894047	1579640
         2893709	1579302
         2893274	1579061
         2893178	1578964
         2892840	1578867
         2892405	1578529
         2892260	1578432
         2892163	1578432
         2891971	1578384
         2891584	1577949
         2891487	1577852
         2891390	1577611
         2891052	1577611
         2890859	1577611
         2890618	1577514
         2890376	1577417
         2890279	1577417
         2885111	1576258
         2884289	1576113
         2883420	1576113
         2883275	1576209
         2882985	1576209
         2882405	1576113
         2882067	1575871
         2881536	1575968
         2881198	1575968
         2880860	1575968
         2880425	1575968
         2879990	1575968
         2879652	1575968
         2874483	1576499
         2869315	1577079
         2869218	1577127
         2868976	1577176
         2868542	1577224
         2868203	1577321
         2867817	1577369
         2863034	1578577
         2857865	1580365
         2855305	1581284
         2855209	1581284
         2854436	1581525
         2853855	1581719
         2853469	1581864
         2853131	1581960
         2851441	1582830
         2846271	1584522
         2845692	1584764
         2840957	1586504
         2840281	1586794
         2840088	1586891
         2840040	1586939
         2839943	1586939
         2839605	1587084
         2839170	1587374
         2838688	1587520
         2838494	1587568
         2838300	1587664
         2838253	1587761
         2838156	1587858
         2838059	1587858
         2838011	1587858
         2837914	1587858
         2837866	1587906
         2837624	1588003
         2837479	1588003
         2837335	1588051
         2836997	1588100
         2836706	1588148
         2836513	1588148
         2836416	1588148
         2836272	1588148
         2836127	1588196
         2835982	1588196
         2835886	1588196
         2835596	1588341
         2835402	1588438
         2835354	1588390
         2835305	1588390
         2835257	1588390
         2835161	1588438
         2835064	1588438
         2834871	1588535
         2834436	1588825
         2834098	1589018
         2833470	1589405
         2833229	1589550
         2833132	1589598
         2833083	1589598
         2833035	1589550
         2832987	1589550
         2832890	1589598
         2832745	1589695
         2832504	1589840
         2832310	1589937
         2832166	1590082
         2832021	1590179
         2831924	1590227
         2831827	1590275
         2831731	1590323
         2831683	1590323
         2831683	1590372
         2831683	1590420
         2831634	1590420
         2831634	1590372
         2831634	1590323
         2831634	1590275
         2831634	1590227
         2831634	1590179
         2831634	1590130
         2831683	1590130
         2831683	1590082
         2831683	1589985
         2831683	1589937
         2831634	1589937
         2831586	1589985
         2831537	1590033
         2831489	1590130
         2831489	1590227
         2831489	1590275
         2831489	1590372
         2831489	1590420
         2831537	1590469
         2831489	1590469
         2831441	1590517
         2831393	1590469
         2831345	1590420
         2831345	1590469
         2831296	1590469
         2831296	1590372
         2830813	1590372
         2830717	1590372
         2831489	1586746
         2831537	1586649
         2831489	1586649
         2831441	1586504
         2831345	1586311
         2831248	1586166
         2831103	1586021
         2830910	1585876
         2830717	1585731
         2830572	1585682
         2830378	1585634
         2830088	1585489
         2829847	1585392
         2829605	1585296
         2829315	1585199
         2829123	1585102
         2829074	1585102
         2829026	1585054
         2829026	1584957
         2829026	1584909
         2829074	1584861
         2829123	1584861
         2829170	1584909
         2829123	1584909
         2829123	1584957
         2829170	1585006
         2829219	1585006
         2829267	1585006
         2829412	1584957
         2829509	1584957
         2829557	1584957
         2829605	1584957
         2829605	1584909
         2829702	1584909
         2829750	1584861
         2829799	1584861
         2829847	1584861
         2829895	1584861
         2829847	1584909
         2829847	1585006
         2829799	1585054
         2829750	1585102
         2829799	1585151
         2829847	1585151
         2829896	1585199
         2829944	1585247
         2829992	1585199
         2830040	1585247
         2830040	1585296
         2830040	1585344
         2830088	1585344
         2830137	1585344
         2830234	1585296
         2830234	1585344
         2830234	1585392
         2830282	1585441
         2830330	1585489
         2830378	1585489
         2830426	1585537
         2830475	1585537
         2830523	1585537
         2830620	1585537
         2830668	1585537
         2830764	1585586
         2830813	1585634
         2830813	1585682
         2830861	1585682
         2830910	1585682
         2830958	1585682
         2830958	1585779
         2831007	1585827
         2831103	1585876
         2831151	1585972
         2831248	1586069
         2831345	1586166
         2831441	1586262
         2831489	1586359
         2831537	1586359
         2831586	1586262
         2831586	1586117
         2831586	1586021
         2831586	1585972
         2831537	1585924
         2831489	1585924
         2831441	1585924
         2831441	1585876
         2831441	1585779
         2831489	1585731
         2831489	1585779
         2831586	1585779
         2831634	1585779
         2831731	1585731
         2831827	1585682
         2831972	1585489
         2832069	1585344
         2832166	1585199
         2832310	1585054
         2832456	1584861
         2832600	1584667
         2832697	1584522
         2832745	1584474
         2832842	1584329
         2832890	1584281
         2832890	1584232
         2832890	1584184
         2832842	1584136
         2832842	1584087
         2832842	1584039
         2832842	1583991
         2832794	1583991
         2832745	1583942
         2832745	1583894
         2832794	1583846
         2832842	1583846
         2832890	1583846
         2832890	1583797
         2832939	1583749
         2832987	1583749
         2833035	1583749
         2833083	1583797
         2833083	1583894
         2833132	1583942
         2833180	1583991
         2833229	1583942
         2833277	1583942
         2833325	1583846
         2833374	1583749
         2833470	1583652
         2833518	1583604
         2833567	1583556
         2833518	1583507
         2833518	1583459
         2833518	1583411
         2833518	1583314
         2833567	1583217
         2833567	1583169
         2833518	1583120
         2833470	1583120
         2833421	1583120
         2833374	1583169
         2833325	1583169
         2833277	1583169
         2833229	1583120
         2833180	1583120
         2833083	1583072
         2833035	1582975
         2832987	1582927
         2832939	1582830
         2832939	1582734
         2832890	1582685
         2832842	1582734
         2832794	1582734
         2832745	1582782
         2832697	1582782
         2832648	1582782
         2832600	1582782
         2832552	1582734
         2832552	1582685
         2832456	1582589
         2832407	1582540
         2832359	1582492
         2832310	1582444
         2832262	1582444
         2832214	1582395
         2832118	1582395
         2832069	1582347
         2831972	1582395
         2831924	1582395
         2831876	1582395
         2831827	1582395
         2831779	1582347
         2831634	1582347
         2831586	1582347
         2831537	1582347
         2831489	1582347
         2831441	1582347
         2831393	1582299
         2831345	1582299
         2831345	1582347
         2831345	1582395
         2831345	1582444
         2831393	1582492
         2831441	1582540
         2831537	1582589
         2831586	1582685
         2831683	1582782
         2831683	1582879
         2831683	1582975
         2831731	1583120
         2831731	1583217
         2831731	1583265
         2831731	1583314
         2831779	1583362
         2831779	1583411
         2831779	1583459
         2831779	1583507
         2831731	1583556
         2831731	1583507
         2831683	1583459
         2831683	1583411
         2831683	1583314
         2831634	1583217
         2831634	1583120
         2831586	1583072
         2831537	1583024
         2831441	1583024
         2831393	1583024
         2831345	1583024
         2831393	1582975
         2831393	1582927
         2831393	1582830
         2831393	1582734
         2831345	1582685
         2831296	1582637
         2831248	1582637
         2831199	1582589
         2831199	1582540
         2831151	1582540
         2831103	1582540
         2831055	1582540
         2831007	1582540
         2831007	1582492
         2830958	1582492
         2830910	1582492
         2830813	1582492
         2830764	1582540
         2830717	1582540
         2830620	1582734
         2830523	1582830
         2830475	1582879
         2830426	1582879
         2830378	1582879
         2830330	1582879
         2830282	1582879
         2830234	1582830
         2830234	1582782
         2830234	1582734
         2830185	1582734
         2830185	1582782
         2830137	1582782
         2829992	1582782
         2829896	1582830
         2829847	1582879
         2829702	1582975
         2829557	1583120
         2829509	1583265
         2829412	1583411
         2829315	1583507
         2829219	1583604
         2829170	1583700
         2829123	1583749
         2829123	1583797
         2829170	1583846
         2829170	1583894
         2829170	1583942
         2829123	1583991
         2829026	1584087
         2829026	1584136
         2829026	1584232
         2829074	1584281
         2829074	1584329
         2829074	1584377
         2829074	1584474
         2829074	1584522
         2829026	1584571
         2828929	1584619
         2828832	1584619
         2828785	1584667
         2828785	1584716
         2828832	1584764
         2828881	1584812
         2828881	1584861
         2828832	1584861
         2828785	1584812
         2828736	1584764
         2828736	1584716
         2828156	1584281
         2827625	1583942
         2827093	1583942
         2826175	1583652
         2825306	1583652
         2824533	1583604
         2823518	1583507
         2823422	1582395
         2823084	1581960
         2822504	1581525
         2822069	1581187
         2821393	1580849
         2821296	1580607
         2820765	1580075
         2820282	1579834
         2820282	1579640
         2819992	1579061
         2819751	1578529
         2819412	1578287
         2818881	1578094
         2818108	1577852
         2817528	1577321
         2816755	1577079
         2816224	1577176
         2815547	1577079
         2814775	1576838
         2814195	1576548
         2813422	1575871
         2812843	1575388
         2812505	1574614
         2812311	1573986
         2812408	1573310
         2812408	1572536
         2811973	1571860
         2811538	1571329
         2811345	1570894
         2811345	1570507
         2811345	1569783
         2811345	1569106
         2811103	1568671
         2810669	1568188
         2810089	1567415
         2809316	1566980
         2808881	1566787
         2808446	1566546
         2808012	1566352
         2807529	1566352
         2807094	1566449
         2806659	1566352
         2806563	1565966
         2806321	1565338
         2805790	1565096
         2805017	1564999
         2804727	1564903
         2804679	1564806
         2804679	1564613
         2804583	1564468
         2804437	1564371
         2804292	1564275
         2803906	1564130
         2802987	1563985
         2802360	1563792
         2801538	1563309
         2801345	1563116
         2800911	1562922
         2800234	1562198
         2800090	1562004
         2799800	1561666
         2799316	1560990
         2798785	1560555
         2798108	1560314
         2797433	1560314
         2796901	1560314
         2796128	1560362
         2795886	1560217
         2794583	1559010
         2793568	1559010
         2793037	1558913
         2792699	1558575
         2792264	1558140
         2792119	1557802
         2792215	1557320
         2792022	1556885
         2791588	1556643
         2791346	1556643
         2790669	1556643
         2790138	1556691
         2789462	1556788
         2788882	1556885
         2788496	1556981
         2788109	1557030
         2787578	1557126
         2787239	1557030
         2787046	1556643
         2787046	1556450
         2786901	1556015
         2786709	1555436
         2786467	1555001
         2786225	1554760
         2786274	1553697
         2786274	1553214
         2786274	1552780
         2786371	1552103
         2786709	1551814
         2786805	1552248
         2786901	1552442
         2786901	1552732
         2786998	1553166
         2787046	1553262
         2787143	1553456
         2787385	1554035
         2787481	1553456
         2787481	1553021
         2787385	1552587
         2787191	1552200
         2787143	1551621
         2786901	1551138
         2786901	1550800
         2786901	1550607
         2786901	1550559
         2786901	1550462
         2786901	1550414
         2786709	1549882
         2786274	1549496
         2785936	1549158
         2786032	1548820
         2786032	1548482
         2786032	1548241
         2785887	1547710
         2785452	1547275
         2784776	1546937
         2783906	1546502
         2782941	1546116
         2781829	1545682
         2781684	1545585
         2780815	1545344
         2780042	1545054
         2778689	1544813
         2778400	1544716
         2777723	1544620
         2776805	1544571
         2775936	1544475
         2775163	1544282
         2774245	1544233
         2773520	1543944
         2773376	1543944
         2773134	1543944
         2773182	1543461
         2773182	1543268
         2773520	1543027
         2773376	1542834
         2773037	1542399
         2772506	1542013
         2771926	1541578
         2771298	1541240
         2770719	1540613
         2770381	1540034
         2769608	1539503
         2769027	1539068
         2768497	1539020
         2768303	1539020
         2767627	1539020
         2767047	1538634
         2766516	1538392
         2766275	1538054
         2766178	1537475
         2766033	1537137
         2765840	1536413
         2765936	1535931
         2766081	1535496
         2766081	1535158
         2766081	1534724
         2765936	1534290
         2765646	1533952
         2764874	1533614
         2764053	1533276
         2762941	1532938
         2762072	1532938
         2761588	1532842
         2760429	1532745
         2759753	1532263
         2759656	1531539
         2759608	1530960
         2759753	1530767
         2760284	1530380
         2761058	1529753
         2761540	1529753
         2761975	1529319
         2761878	1528885
         2761975	1527775
         2761637	1526954
         2761299	1526279
         2761058	1525555
         2761058	1524638
         2761299	1524059
         2761830	1523866
         2762168	1523432
         2762168	1523287
         2762168	1522998
         2762168	1522853
         2762072	1522515
         2761830	1522178
         2762168	1522081
         2762313	1522178
         2762506	1522226
         2762651	1522419
         2762748	1522853
         2762845	1522902
         2763280	1523094
         2763183	1523287
         2762989	1523529
         2762941	1523625
         2762892	1523673
         2762699	1523673
         2762506	1523625
         2762265	1523963
         2761878	1524204
         2761637	1524735
         2761637	1524976
         2761830	1525169
         2762072	1524880
         2762168	1524445
         2762410	1524204
         2762845	1524059
         2763376	1523336
         2763424	1523287
         2763521	1523094
         2763618	1522564
         2763521	1521985
         2762989	1521454
         2762941	1519235
         2763521	1518897
         2763521	1518656
         2762845	1518125
         2764053	1516244
         2763424	1515472
         2763424	1515231
         2763618	1514990
         2763859	1515038
         2764149	1514797
         2763956	1514701
         2763859	1514701
         2763424	1514797
         2763280	1514797
         2763183	1515038
         2763280	1515327
         2762989	1515424
         2762410	1515327
         2761878	1515327
         2761733	1515327
         2760864	1515327
         2760091	1515327
         2759608	1515569
         2759511	1515906
         2759656	1516437
         2759994	1516534
         2760091	1516871
         2760091	1517305
         2760091	1517788
         2760429	1517980
         2760381	1518319
         2760188	1518753
         2760526	1519090
         2760719	1519187
         2760767	1519910
         2760961	1520200
         2761347	1520344
         2761637	1520007
         2761830	1519862
         2762072	1520200
         2761733	1520634
         2761492	1520972
         2761733	1521117
         2761830	1521406
         2762072	1521985
         2761782	1522081
         2761733	1521985
         2760864	1520779
         2760091	1519862
         2759511	1519235
         2759076	1518897
         2758497	1518415
         2757289	1517691
         2756420	1517209
         2755744	1516871
         2755309	1516534
         2755309	1516196
         2755550	1515569
         2755647	1515038
         2755647	1514701
         2755502	1514218
         2754874	1513881
         2754391	1513543
         2754197	1513205
         2754536	1512819
         2754777	1512819
         2754632	1513350
         2755164	1513109
         2755647	1512819
         2756082	1512675
         2756516	1512675
         2756275	1513013
         2755744	1513253
         2755744	1513784
         2755840	1514314
         2756275	1514893
         2755840	1515424
         2755744	1515665
         2755840	1515762
         2756275	1515569
         2756613	1515569
         2756613	1515472
         2756516	1515327
         2756516	1515038
         2756854	1514893
         2757193	1514652
         2757193	1514314
         2757531	1514025
         2757869	1514122
         2758207	1514218
         2758642	1514025
         2758739	1513543
         2758545	1513253
         2758401	1513447
         2758159	1513253
         2757869	1512916
         2757434	1513013
         2757096	1513013
         2757386	1512675
         2757966	1512337
         2758159	1512048
         2758304	1511710
         2758642	1511710
         2758642	1511903
         2758497	1512240
         2758980	1512240
         2759318	1512144
         2759946	1511710
         2760091	1511131
         2760091	1510697
         2760091	1510601
         2760091	1510263
         2760091	1510022
         2760091	1509588
         2760091	1509347
         2760091	1509058
         2759994	1508768
         2759898	1508672
         2759801	1508093
         2760188	1507707
         2760284	1507514
         2760236	1507129
         2760091	1507032
         2760091	1506453
         2760091	1505778
         2760188	1504573
         2760526	1504188
         2760767	1503705
         2760719	1503367
         2760864	1503175
         2760719	1502933
         2760526	1502741
         2760188	1502741
         2759511	1502403
         2758835	1502259
         2758642	1502259
         2758497	1502259
         2758207	1502066
         2757628	1501583
         2756951	1501198
         2756516	1500957
         2755985	1500475
         2755309	1500041
         2754777	1499607
         2754777	1499270
         2754536	1499317
         2754004	1499510
         2753425	1499703
         2752893	1500185
         2752555	1500812
         2752410	1501150
         2752749	1501632
         2752845	1502259
         2752314	1502403
         2751782	1502355
         2751444	1501969
         2751009	1501391
         2750864	1500523
         2750864	1500475
         2751250	1499317
         2751396	1498932
         2752072	1498594
         2751637	1498642
         2750671	1498594
         2749850	1498305
         2749560	1498305
         2749077	1498402
         2748739	1498305
         2748545	1497968
         2748449	1497726
         2748111	1497292
         2748545	1497100
         2748739	1496859
         2749077	1497052
         2749560	1496714
         2750092	1496184
         2750430	1496280
         2750768	1496184
         2751202	1496087
         2751782	1495846
         2751975	1495605
         2751975	1495171
         2751879	1494834
         2751782	1494978
         2751637	1495412
         2751106	1495605
         2750623	1495605
         2750188	1495750
         2749995	1495220
         2749898	1494834
         2749512	1494304
         2749125	1494063
         2748787	1493629
         2748449	1493291
         2748449	1493002
         2748255	1492568
         2747676	1492086
         2747338	1491315
         2747000	1490785
         2746517	1490737
         2746082	1490351
         2745647	1489966
         2745309	1489435
         2744681	1489194
         2744536	1488857
         2744004	1488568
         2743522	1488568
         2742990	1488471
         2743087	1488134
         2743422	1488228
         2744343	1488471
         2744633	1488471
         2744874	1488664
         2745019	1488905
         2745116	1488664
         2745019	1488230
         2744633	1487989
         2744004	1487748
         2743328	1487556
         2742652	1487459
         2742024	1487459
         2741686	1487459
         2741347	1487026
         2741347	1486640
         2740865	1486254
         2740865	1485917
         2740527	1485917
         2740574	1486206
         2740236	1486254
         2739754	1486110
         2739367	1485676
         2739367	1485531
         2739560	1485098
         2740092	1484664
         2740865	1484471
         2741444	1484664
         2741541	1484760
         2741879	1485001
         2742217	1485290
         2742411	1485290
         2742603	1485194
         2742700	1485146
         2743135	1485339
         2743569	1485772
         2744004	1486206
         2744439	1486688
         2744971	1487218
         2745212	1487893
         2745647	1488568
         2746130	1489098
         2746226	1489676
         2746420	1490014
         2746661	1490110
         2746855	1490014
         2747096	1489966
         2747435	1490014
         2747435	1490544
         2747628	1490785
         2747966	1491411
         2748545	1491653
         2749512	1491749
         2749995	1491990
         2750285	1492183
         2750961	1492616
         2751637	1493339
         2752314	1493966
         2753087	1494496
         2753762	1494834
         2755067	1494882
         2755164	1494978
         2755550	1495412
         2756082	1496087
         2756420	1496714
         2756951	1496714
         2757434	1496425
         2758062	1496184
         2758545	1495750
         2758159	1495605
         2757724	1495412
         2757096	1495220
         2756516	1494978
         2756323	1494834
         2756661	1494641
         2757386	1494834
         2757869	1494882
         2758304	1494545
         2758545	1494063
         2758401	1493533
         2758207	1493002
         2758642	1492616
         2758835	1492183
         2758883	1491508
         2758980	1490881
         2758980	1490206
         2758980	1489773
         2758883	1489339
         2758980	1489098
         2758304	1489098
         2757869	1489339
         2757434	1489435
         2757096	1489435
         2756854	1489339
         2756758	1488857
         2756516	1488423
         2756275	1487797
         2756082	1487459
         2756420	1487459
         2756854	1487893
         2757289	1488230
         2757531	1487797
         2756951	1487315
         2756323	1486784
         2756275	1486447
         2756178	1486110
         2755647	1485676
         2755164	1485435
         2754971	1484760
         2754971	1484568
         2754294	1483989
         2753521	1484037
         2752555	1484471
         2752555	1483556
         2752845	1482351
         2753087	1481387
         2753425	1480568
         2753425	1479508
         2753618	1478592
         2753762	1477725
         2753521	1476713
         2753521	1476280
         2753618	1475797
         2753762	1475171
         2753762	1474063
         2753762	1473148
         2753425	1472184
         2753328	1471414
         2753280	1470739
         2753425	1470546
         2753425	1470305
         2753425	1470209
         2753521	1469535
         2753425	1468523
         2753328	1467560
         2753183	1466645
         2752990	1465778
         2752410	1464573
         2751782	1463899
         2751106	1463658
         2751106	1463321
         2751299	1462647
         2751299	1462117
         2751202	1461346
         2751106	1461251
         2751106	1460480
         2750864	1459902
         2750285	1459035
         2749995	1458554
         2749077	1458024
         2748787	1457253
         2748401	1456676
         2748401	1455809
         2748642	1455231
         2748980	1454846
         2748980	1454605
         2749125	1454364
         2748883	1453401
         2748642	1452968
         2748449	1452390
         2748304	1451620
         2748449	1451476
         2748545	1451187
         2748449	1450512
         2748207	1449983
         2748111	1449598
         2747966	1449068
         2747869	1448490
         2747676	1448201
         2747869	1448105
         2747338	1447287
         2746855	1446950
         2746323	1446276
         2745888	1445842
         2745985	1445554
         2746130	1445313
         2746226	1444447
         2745744	1443965
         2745116	1443291
         2744439	1442906
         2743908	1442762
         2743231	1442136
         2742990	1442088
         2742652	1441799
         2742411	1441558
         2742217	1441029
         2742121	1440788
         2741976	1440644
         2741782	1440548
         2741203	1440114
         2741203	1439585
         2740912	1439104
         2740527	1438671
         2739995	1438430
         2739464	1438045
         2739464	1437804
         2739754	1437900
         2740333	1438333
         2741638	1438430
         2742314	1438333
         2743087	1438430
         2743908	1438478
         2744874	1438478
         2745647	1438238
         2746323	1437660
         2746855	1437130
         2747338	1436938
         2748304	1437275
         2748883	1437275
         2749560	1437130
         2749898	1436264
         2750333	1435591
         2750623	1435013
         2750961	1433569
         2751444	1432944
         2752314	1432366
         2752893	1431500
         2753328	1430056
         2753521	1428517
         2753666	1426881
         2753762	1425871
         2753666	1424523
         2753328	1422887
         2752990	1421781
         2752555	1420579
         2752314	1419665
         2752120	1419135
         2751782	1418366
         2751540	1417259
         2751299	1416249
         2750961	1415287
         2750671	1414518
         2750188	1413700
         2749560	1412642
         2748980	1411391
         2748401	1410430
         2747628	1409516
         2747096	1408746
         2746323	1408170
         2745309	1407737
         2744971	1407544
         2744198	1406871
         2743666	1406534
         2742893	1406005
         2742411	1406005
         2742121	1406005
         2741638	1406294
         2740865	1406678
         2740236	1406775
         2740092	1406775
         2739222	1406871
         2738981	1406967
         2738643	1406967
         2738449	1406871
         2738014	1406775
         2737338	1407063
         2737097	1407304
         2736807	1407640
         2736324	1407785
         2736033	1407544
         2734778	1407737
         2734585	1407448
         2734150	1406967
         2733811	1406534
         2733135	1406101
         2732265	1405765
         2731783	1405669
         2731589	1405861
         2731251	1405669
         2731686	1405428
         2731348	1405188
         2731010	1404899
         2730381	1404755
         2729996	1404803
         2729657	1404322
         2729561	1404563
         2729561	1404899
         2729367	1405188
         2728932	1405236
         2728546	1405525
         2728353	1405765
         2728256	1406101
         2727821	1406198
         2727821	1405958
         2728159	1405669
         2727821	1405332
         2727483	1405332
         2727145	1405332
         2726710	1405332
         2726372	1405332
         2726372	1405236
         2726276	1405092
         2725455	1405188
         2725020	1405525
         2725502	1406150
         2725551	1406294
         2725599	1406631
         2726131	1406967
         2726469	1407304
         2726904	1407400
         2727242	1407448
         2727580	1407544
         2728305	1407304
         2728740	1407063
         2729271	1406775
         2729464	1406775
         2729802	1406871
         2729802	1406631
         2730043	1406631
         2730140	1407111
         2729996	1407785
         2729705	1408410
         2729271	1408987
         2728546	1409179
         2727821	1409083
         2727000	1408987
         2726276	1408939
         2725358	1408650
         2724247	1408554
         2723135	1408410
         2722025	1408218
         2721058	1408170
         2719803	1408073
         2718933	1407977
         2717821	1408314
         2717146	1408554
         2716373	1409083
         2716131	1409853
         2716034	1409949
         2715696	1410382
         2715261	1410382
         2714392	1410045
         2713474	1409612
         2713377	1409420
         2712846	1408987
         2712464	1408188
         2712363	1407977
         2712266	1407640
         2712073	1407400
         2712508	1406967
         2712363	1405525
         2712025	1404755
         2711155	1403986
         2710044	1403217
         2709030	1402543
         2708160	1402110
         2707822	1402015
         2707533	1401774
         2706180	1401101
         2704972	1400572
         2703861	1400139
         2702846	1399899
         2701832	1399707
         2700721	1399370
         2699513	1399033
         2698982	1398841
         2698934	1398841
         2698499	1398697
         2698402	1398361
         2698306	1397928
         2697967	1397736
         2697871	1397687
         2697387	1396966
         2696663	1396293
         2696277	1395861
         2695987	1395813
         2695649	1395187
         2695552	1394611
         2695938	1394418
         2696518	1393938
         2696856	1393409
         2696953	1392544
         2696663	1392207
         2696083	1391294
         2695311	1390525
         2694392	1389900
         2693281	1389323
         2692558	1388891
         2691881	1388458
         2691108	1388218
         2690432	1388026
         2689659	1387785
         2689224	1387449
         2689224	1387305
         2689224	1387208
         2689224	1387016
         2689321	1386776
         2689417	1386343
         2689417	1386007
         2689417	1385766
         2689417	1385671
         2689417	1385430
         2688886	1384805
         2688789	1384661
         2688741	1384229
         2688982	1383892
         2688789	1383460
         2688789	1383027
         2688451	1382595
         2688306	1382162
         2688451	1382018
         2688789	1381489
         2688741	1380576
         2688451	1379808
         2688402	1379471
         2688548	1379087
         2688548	1379039
         2688692	1378798
         2687919	1376444
         2686518	1374138
         2683378	1370967
         2680383	1367988
         2680239	1367796
         2680190	1367604
         2680190	1367460
         2680190	1367124
         2679755	1366499
         2679659	1366499
         2679417	1366163
         2679563	1365731
         2679901	1365250
         2679417	1364626
         2679224	1363953
         2679417	1363377
         2679466	1362416
         2679417	1362416
         2678790	1361936
         2677920	1361312
         2677195	1360831
         2676906	1360207
         2676422	1359727
         2675215	1359006
         2674345	1358574
         2673331	1357998
         2673041	1357662
         2673234	1357229
         2673234	1356557
         2672800	1355549
         2672316	1354588
         2671253	1354012
         2670432	1353388
         2669659	1353051
         2668935	1352715
         2668693	1352715
         2667437	1352283
         2666230	1351947
         2665022	1351803
         2663814	1351467
         2662897	1351371
         2662462	1351179
         2661785	1351035
         2661495	1350699
         2662124	1350746
         2662703	1350507
         2662800	1349834
         2663041	1348970
         2662462	1347866
         2661447	1346953
         2660675	1346329
         2659611	1345849
         2658790	1345321
         2657824	1344793
         2656616	1344217
         2655457	1343112
         2654732	1342585
         2653960	1342200
         2653139	1341768
         2652704	1341480
         2652462	1340809
         2652462	1339896
         2652462	1339560
         2652366	1339224
         2651496	1338456
         2650578	1337736
         2649515	1337064
         2648259	1336584
         2647148	1336152
         2646182	1335816
         2645070	1335384
         2644153	1335096
         2643187	1334856
         2642510	1334520
         2641641	1333992
         2640868	1333752
         2640095	1333656
         2639612	1333321
         2640047	1333080
         2640047	1332504
         2639322	1331784
         2638839	1331449
         2638501	1331209
         2638984	1330633
         2639274	1330105
         2639322	1329433
         2638839	1328761
         2638308	1327897
         2637631	1327033
         2636859	1326890
         2635989	1326601
         2634830	1325930
         2633622	1325594
         2632559	1325354
         2630627	1325066
         2629033	1324682
         2626762	1323962
         2623670	1323339
         2620869	1322811
         2618357	1322523
         2615023	1322043
         2613236	1321947
         2612994	1321947
         2612560	1321947
         2612463	1321947
         2612367	1321947
         2612318	1321851
         2612221	1321755
         2612125	1321611
         2612028	1320891
         2612028	1320844
         2612028	1320651
         2612028	1320412
         2612028	1320076
         2612028	1319884
         2612125	1319836
         2612221	1319740
         2612221	1319548
         2612174	1319452
         2612028	1319212
         2611980	1318972
         2611836	1318684
         2611448	1318300
         2611256	1317965
         2610821	1317533
         2610483	1317197
         2610241	1317005
         2609999	1316765
         2609710	1316574
         2609323	1316430
         2608937	1316093
         2608116	1315470
         2607439	1314894
         2607150	1314798
         2607101	1314750
         2606860	1314511
         2606811	1314462
         2606763	1314415
         2606666	1314223
         2606715	1313599
         2606715	1313455
         2606763	1313311
         2606957	1313023
         2607101	1312640
         2607342	1312160
         2607488	1311920
         2607777	1311680
         2607922	1311584
         2608261	1311488
         2608695	1311728
         2609130	1312064
         2609226	1312160
         2609226	1312352
         2609130	1312256
         2608792	1312064
         2608357	1311728
         2608212	1311680
         2608019	1311824
         2607681	1312160
         2607488	1312448
         2607342	1312688
         2607150	1313023
         2607101	1313119
         2607004	1313263
         2607004	1313359
         2607004	1313503
         2607004	1313695
         2607246	1313599
         2607342	1313503
         2607488	1313263
         2607584	1313167
         2607681	1313167
         2608212	1313167
         2608261	1313167
         2608454	1313263
         2608502	1313359
         2608599	1313455
         2608840	1313599
         2608937	1313599
         2609034	1313551
         2609034	1313263
         2608937	1313023
         2608888	1312831
         2608937	1312735
         2609226	1312640
         2609517	1312496
         2609661	1312400
         2609710	1312400
         2609903	1312256
         2610338	1312064
         2610821	1311680
         2611352	1311488
         2611594	1311392
         2612028	1311248
         2612560	1311153
         2613091	1310960
         2614251	1310529
         2614927	1310337
         2616231	1309857
         2617488	1309186
         2617535	1309186
         2617680	1309042
         2618018	1308754
         2618067	1308754
         2619951	1307028
         2619999	1306979
         2620096	1306835
         2620241	1306644
         2620434	1306212
         2621352	1304533
         2621642	1304006
         2621786	1303670
         2621883	1302807
         2621980	1302135
         2621980	1301991
         2621980	1301704
         2622124	1301560
         2622318	1301272
         2622463	1301128
         2622559	1300936
         2622559	1300601
         2622656	1300457
         2622849	1300361
         2623091	1300265
         2623236	1300361
         2623284	1300361
         2623670	1300457
         2623961	1300457
         2624105	1300361
         2624202	1300361
         2624347	1300265
         2624637	1300025
         2624685	1299929
         2624975	1299258
         2625216	1298634
         2625313	1298490
         2625458	1298155
         2625748	1297819
         2625748	1297723
         2625844	1297388
         2625893	1297052
         2625893	1296189
         2625893	1295422
         2625844	1294894
         2625844	1294559
         2625748	1294415
         2625748	1294079
         2625700	1293696
         2625700	1293599
         2625700	1293408
         2625700	1293216
         2625700	1293168
         2625700	1293120
         2625700	1293024
         2625700	1292976
         2625700	1292880
         2625748	1292785
         2625748	1292736
         2625796	1292641
         2625893	1292545
         2626086	1292401
         2626134	1292401
         2626279	1292113
         2626327	1292017
         2626376	1291873
         2626424	1291778
         2626521	1291346
         2626521	1291154
         2626569	1291010
         2626569	1290723
         2626521	1290531
         2626473	1290291
         2626424	1289955
         2626424	1289620
         2626327	1289141
         2626230	1288805
         2626038	1288134
         2625893	1287558
         2625651	1286983
         2625409	1286456
         2625362	1286408
         2625168	1286024
         2625119	1285976
         2624927	1285641
         2624781	1285353
         2624637	1284969
         2624589	1284874
         2624492	1284634
         2624396	1284442
         2624299	1284155
         2624251	1283915
         2624251	1283819
         2624251	1283771
         2624251	1283675
         2624251	1283532
         2624251	1283483
         2624299	1283436
         2624347	1283436
         2624637	1282764
         2625458	1281566
         2626279	1279170
         2627149	1276054
         2627825	1274185
         2627970	1273753
         2628018	1273562
         2628066	1273274
         2628066	1273034
         2628066	1272987
         2628066	1272939
         2628018	1272651
         2628018	1272603
         2628018	1272555
         2628018	1272507
         2628018	1272459
         2627970	1272124
         2627922	1271980
         2627873	1271789
         2627825	1271645
         2627776	1271453
         2627584	1271022
         2627584	1270878
         2627584	1270830
         2627584	1270782
         2627584	1270734
         2627584	1270686
         2627584	1270638
         2627535	1270590
         2627535	1270543
         2627535	1270495
         2627535	1270446
         2627535	1270399
         2627535	1270303
         2627535	1270255
         2627535	1270207
         2627535	1270159
         2627535	1270111
         2627535	1270063
         2627535	1270015
         2627535	1269967
         2627535	1269920
         2627487	1269680
         2627487	1269632
         2627294	1269344
         2626859	1268722
         2626811	1268673
         2626762	1268626
         2626714	1268578
         2626665	1268530
         2626618	1268482
         2626569	1268434
         2626521	1268386
         2626521	1268338
         2626521	1268290
         2626521	1268194
         2626424	1268146
         2626376	1268098
         2626327	1268050
         2626327	1267954
         2626279	1267859
         2626327	1267859
         2626424	1267811
         2626473	1267763
         2626521	1267763
         2626473	1267811
         2626424	1267859
         2626424	1267907
         2626521	1267954
         2626569	1268003
         2626569	1267954
         2626569	1267907
         2626569	1267859
         2626618	1267811
         2626665	1267811
         2626859	1267523
         2626956	1267140
         2626956	1267092
         2626956	1266996
         2626956	1266900
         2626956	1266853
         2626956	1266805
         2626956	1266757
         2627053	1266565
         2627149	1266421
         2627246	1266374
         2627342	1266374
         2627390	1266374
         2627438	1266374
         2627487	1266421
         2627390	1266469
         2627342	1266469
         2627149	1266709
         2627149	1266757
         2627149	1266805
         2627149	1266853
         2627149	1266900
         2627246	1266996
         2627294	1267044
         2627294	1267092
         2627294	1267140
         2627294	1267236
         2627294	1267284
         2627342	1267475
         2627438	1267572
         2627487	1267572
         2627535	1267572
         2627584	1267572
         2627632	1267572
         2627776	1267523
         2627776	1267475
         2627776	1267428
         2627776	1267379
         2627873	1266949
         2627922	1266421
         2627728	1265271
         2627728	1265223
         2627728	1265127
         2627728	1265080
         2627728	1265032
         2627728	1264984
         2627728	1264936
         2627680	1264169
         2627632	1263642
         2627632	1263498
         2627535	1262827
         2627535	1262780
         2627535	1262732
         2627535	1262684
         2627535	1262636
         2627535	1262588
         2627535	1262540
         2627680	1262252
         2627873	1262109
         2627970	1262061
         2628018	1262061
         2628066	1262109
         2628066	1262157
         2628066	1262205
         2628066	1262252
         2628115	1262301
         2628163	1262348
         2628211	1262348
         2628260	1262348
         2628308	1262301
         2628357	1262252
         2628405	1262205
         2628453	1262205
         2628453	1262252
         2628453	1262301
         2628453	1262348
         2628453	1262396
         2628501	1262444
         2628550	1262492
         2628550	1262540
         2628550	1262588
         2628550	1262636
         2628501	1262684
         2628405	1262684
         2628405	1262732
         2628405	1262780
         2628453	1262780
         2628501	1262780
         2628550	1262780
         2628598	1262780
         2628598	1262732
         2628646	1262684
         2628695	1262684
         2628695	1262732
         2628695	1262780
         2628695	1262827
         2628695	1262876
         2628695	1262923
         2628695	1262971
         2628646	1263019
         2628598	1263067
         2628598	1263115
         2628598	1263259
         2628598	1263307
         2628646	1263355
         2628646	1263402
         2628598	1263451
         2628550	1263498
         2628550	1263546
         2628550	1263834
         2628550	1263882
         2628550	1263930
         2628308	1264361
         2628260	1264409
         2628211	1264409
         2628211	1264457
         2628260	1264505
         2628308	1264552
         2628355	1264639
         2628357	1264840
         2628357	1264888
         2628357	1264936
         2628357	1264984
         2628357	1265080
         2628405	1265127
         2628550	1265175
         2628598	1265175
         2628646	1265175
         2628695	1265223
         2628743	1265271
         2628791	1265367
         2628840	1265367
         2628887	1265367
         2628887	1265319
         2628840	1265319
         2628791	1265175
         2628743	1265127
         2628695	1265080
         2628646	1265080
         2628550	1265080
         2628501	1265080
         2628501	1265032
         2628501	1264984
         2628501	1264936
         2628598	1264792
         2628646	1264792
         2628887	1264888
         2628887	1264840
         2628840	1264792
         2628743	1264744
         2628695	1264696
         2628791	1264552
         2628887	1264457
         2628936	1264361
         2628936	1264313
         2628936	1264265
         2628984	1264265
         2628984	1264313
         2628984	1264361
         2628984	1264409
         2628984	1264457
         2628984	1264505
         2628984	1264552
         2628984	1264601
         2629033	1264601
         2629081	1264601
         2629129	1264552
         2629322	1264409
         2629468	1264265
         2629419	1264217
         2629371	1264169
         2629419	1264121
         2629516	1264073
         2629564	1264073
         2629564	1264121
         2629613	1264121
         2629951	1263211
         2629951	1263163
         2630530	1263642
         2630579	1263690
         2630482	1263882
         2630482	1263930
         2630385	1263930
         2630385	1263977
         2630530	1263930
         2630627	1263738
         2630627	1263690
         2630192	1263307
         2629998	1263115
         2629951	1263067
         2629902	1263019
         2629902	1262971
         2629902	1262588
         2629951	1262540
         2630240	1262396
         2630385	1262157
         2630385	1262109
         2630385	1262061
         2630385	1262013
         2630385	1261965
         2630385	1261917
         2630385	1261869
         2630385	1261822
         2630289	1261294
         2630048	1260288
         2629998	1259953
         2629806	1259474
         2629564	1258947
         2629516	1258947
         2629468	1258947
         2629419	1258947
         2629371	1258947
         2629322	1258947
         2629275	1258947
         2629225	1258947
         2629178	1258994
         2629129	1258994
         2629081	1258994
         2629033	1258994
         2628984	1258994
         2628936	1258994
         2628887	1258994
         2628840	1258994
         2628791	1258994
         2628501	1259234
         2628453	1259234
         2628405	1259138
         2628453	1259043
         2628550	1258899
         2628695	1258803
         2628887	1258755
         2628936	1258707
         2628984	1258707
         2629129	1258563
         2629178	1258516
         2629178	1258468
         2629033	1258228
         2628357	1257653
         2628211	1257509
         2628163	1257366
         2628115	1257366
         2627776	1257941
         2627776	1257797
         2627825	1257653
         2627825	1257605
         2627825	1257557
         2627825	1257509
         2627825	1257414
         2627825	1257366
         2627776	1257318
         2627728	1257318
         2627680	1257318
         2627632	1257318
         2627487	1257270
         2627390	1257222
         2627342	1257174
         2627390	1257126
         2627438	1257126
         2627535	1257126
         2627728	1257078
         2627776	1257078
         2627825	1257078
         2627922	1257030
         2627970	1256935
         2627922	1256887
         2627873	1256887
         2627825	1256887
         2627776	1256935
         2627776	1256887
         2627776	1256791
         2627776	1256743
         2627825	1256743
         2627873	1256695
         2627970	1256647
         2627970	1256599
         2627970	1256551
         2627970	1256503
         2628115	1256408
         2628115	1256360
         2628115	1256120
         2628115	1256072
         2628115	1256024
         2628066	1256024
         2628018	1256024
         2628018	1255977
         2628018	1255928
         2628018	1255881
         2628066	1255833
         2628066	1255785
         2628066	1255737
         2628066	1255689
         2628066	1255402
         2628066	1255353
         2628066	1255306
         2628115	1255258
         2628211	1255162
         2628357	1255114
         2628405	1255114
         2628453	1255114
         2628501	1255114
         2628598	1255114
         2628598	1255066
         2628646	1255018
         2628695	1254970
         2628743	1254827
         2628743	1254683
         2628743	1254539
         2628743	1254443
         2628791	1254300
         2628887	1253917
         2628887	1253868
         2628887	1253725
         2628936	1253677
         2628984	1253677
         2628984	1253629
         2628984	1253581
         2628887	1253342
         2628695	1253102
         2628646	1253006
         2628550	1252815
         2628453	1252719
         2628357	1252527
         2628163	1252384
         2628018	1252240
         2627922	1252096
         2627825	1252000
         2627680	1251905
         2627584	1251809
         2627487	1251665
         2627438	1251665
         2627294	1251617
         2627100	1251426
         2627053	1251330
         2627003	1251186
         2626956	1251138
         2626956	1251042
         2627053	1250803
         2627294	1250515
         2627487	1250324
         2627535	1250324
         2627584	1250324
         2627632	1250324
         2627680	1250276
         2627728	1250228
         2627728	1250180
         2627680	1250228
         2627632	1250276
         2627535	1250276
         2627535	1250228
         2627535	1250132
         2627632	1249989
         2627728	1249701
         2627728	1249653
         2627728	1249557
         2627728	1249510
         2627728	1249461
         2627728	1249366
         2627584	1248839
         2627584	1248791
         2627584	1248743
         2627584	1248695
         2627584	1248647
         2627535	1248599
         2627487	1248599
         2627438	1248599
         2627294	1248456
         2627246	1248360
         2627342	1248120
         2627487	1247785
         2627632	1247402
         2627728	1247019
         2628018	1246683
         2627970	1246636
         2627922	1246588
         2627728	1246875
         2627584	1247115
         2627535	1247402
         2627535	1247450
         2627535	1247498
         2627342	1247785
         2627294	1247738
         2627003	1247546
         2626956	1247163
         2626956	1247115
         2626956	1246779
         2626859	1246588
         2626424	1246205
         2626134	1246061
         2625168	1245630
         2624299	1245295
         2624251	1245295
         2623622	1245151
         2623284	1245103
         2623236	1245103
         2622801	1245055
         2622705	1245055
         2620821	1244768
         2620772	1244768
         2620724	1244768
         2620675	1244768
         2620627	1244768
         2620530	1244768
         2620483	1244768
         2620386	1244768
         2620289	1244768
         2620145	1244768
         2620048	1244768
         2619951	1244768
         2619806	1244768
         2619757	1244768
         2619710	1244768
         2619661	1244768
         2619564	1244768
         2619516	1244768
         2619468	1244768
         2619419	1244768
         2619372	1244768
         2619275	1244768
         2619178	1244768
         2619081	1244768
         2618985	1244768
         2618888	1244768
         2618791	1244768
         2618695	1244768
         2618550	1244768
         2618453	1244768
         2618357	1244768
         2618260	1244768
         2618164	1244816
         2618067	1244816
         2618018	1244816
         2617970	1244816
         2615507	1244911
         2615458	1244911
         2615410	1244911
         2615362	1244911
         2615313	1244911
         2615266	1244911
         2615217	1244911
         2615169	1244911
         2615120	1244911
         2615072	1244911
         2614975	1244864
         2614878	1244768
         2614782	1244672
         2614782	1244624
         2614782	1244576
         2614831	1244576
         2614878	1244528
         2614927	1244528
         2614975	1244576
         2615023	1244576
         2615023	1244528
         2614975	1244480
         2614927	1244480
         2614878	1244480
         2614831	1244480
         2614734	1244528
         2614685	1244576
         2614637	1244624
         2614589	1244672
         2614540	1244720
         2614493	1244768
         2614396	1244864
         2614299	1244911
         2614154	1244960
         2611594	1245342
         2609613	1245917
         2608405	1246683
         2608164	1246827
         2607488	1248024
         2607342	1249126
         2607536	1250228
         2607777	1251809
         2607777	1251905
         2607729	1252144
         2607729	1252192
         2607729	1252240
         2607777	1252336
         2607826	1252479
         2607826	1252527
         2607826	1252575
         2607826	1252623
         2607826	1252671
         2607826	1252719
         2607729	1253006
         2607681	1253054
         2607681	1253102
         2607681	1253150
         2607681	1253198
         2607681	1253246
         2607777	1253725
         2607777	1253773
         2607826	1254012
         2607826	1254060
         2607826	1254108
         2607826	1254156
         2607826	1254204
         2607826	1254252
         2607826	1254300
         2607874	1254348
         2607874	1254396
         2607922	1254443
         2607971	1254492
         2608019	1254539
         2608067	1254587
         2608550	1254970
         2608550	1255018
         2608550	1255066
         2608550	1255114
         2608550	1255162
         2608550	1255210
         2608502	1255210
         2608502	1255162
         2608454	1255066
         2608405	1255066
         2608357	1255114
         2608357	1255162
         2608357	1255210
         2608357	1255258
         2608357	1255306
         2608357	1255353
         2608357	1255402
         2608309	1255545
         2608067	1255785
         2607826	1255785
         2607633	1255641
         2607633	1255593
         2607633	1255545
         2607584	1255449
         2607536	1255402
         2607439	1255402
         2607295	1255402
         2607198	1255402
         2607150	1255497
         2607150	1255593
         2607150	1255737
         2607295	1255833
         2607488	1255833
         2607536	1255833
         2607971	1256120
         2608164	1256360
         2608164	1256408
         2608164	1256455
         2608164	1256503
         2608164	1256743
         2608116	1256743
         2608067	1256695
         2608019	1256647
         2607971	1256695
         2607874	1256791
         2608019	1257414
         2608067	1257557
         2608067	1257701
         2608164	1257941
         2608212	1258132
         2608309	1258228
         2608454	1258228
         2608550	1258276
         2608599	1258276
         2608647	1258228
         2608695	1258132
         2608792	1258084
         2608840	1258084
         2608840	1258132
         2608840	1258180
         2608840	1258276
         2608792	1258372
         2608792	1258420
         2608792	1258516
         2608840	1258611
         2608985	1258755
         2609130	1259043
         2609323	1259378
         2609564	1259618
         2609903	1259809
         2610145	1259905
         2610579	1259953
         2611062	1260048
         2611497	1260001
         2611836	1259953
         2612221	1259857
         2612512	1259713
         2612850	1259378
         2613188	1258851
         2613429	1258420
         2613526	1258132
         2613478	1257845
         2613429	1257605
         2613478	1257509
         2613526	1257462
         2613671	1257509
         2613816	1257509
         2613912	1257557
         2614009	1257653
         2614154	1257845
         2614251	1257988
         2614347	1258036
         2614396	1258036
         2614637	1257893
         2614734	1257845
         2614734	1257797
         2614637	1257701
         2614589	1257605
         2614493	1257462
         2614493	1257366
         2614589	1257318
         2614734	1257318
         2614878	1257414
         2614975	1257509
         2615023	1257605
         2615217	1257653
         2615362	1257701
         2615555	1257701
         2615845	1257701
         2615990	1257701
         2616038	1257653
         2616183	1257605
         2616328	1257557
         2616473	1257509
         2616521	1257462
         2616521	1257414
         2616569	1257366
         2616569	1257318
         2616618	1257318
         2616666	1257318
         2616666	1257270
         2616666	1257222
         2616666	1257174
         2616666	1257126
         2616715	1257126
         2616762	1257126
         2616907	1257126
         2616956	1257126
         2617004	1257126
         2617004	1257222
         2617004	1257270
         2617053	1257318
         2617053	1257366
         2617004	1257414
         2616956	1257414
         2616956	1257462
         2616907	1257462
         2616907	1257509
         2616956	1257509
         2617004	1257557
         2617100	1257557
         2617150	1257557
         2617197	1257509
         2617246	1257509
         2617294	1257509
         2617342	1257509
         2617391	1257462
         2617488	1257462
         2617488	1257509
         2617342	1257653
         2617294	1257701
         2617294	1257749
         2617294	1257797
         2617342	1257797
         2617391	1257797
         2617439	1257797
         2617439	1257845
         2617391	1257845
         2617342	1257845
         2617246	1257893
         2617150	1257893
         2617100	1257941
         2617053	1257941
         2617004	1257988
         2616956	1258036
         2616859	1258084
         2616762	1258084
         2616666	1258132
         2616569	1258132
         2616473	1258132
         2616376	1258132
         2616280	1258132
         2616231	1258180
         2616183	1258228
         2616183	1258276
         2616183	1258324
         2616183	1258372
         2616135	1258372
         2616135	1258420
         2616183	1258420
         2616280	1258420
         2616376	1258468
         2616425	1258468
         2616521	1258468
         2616569	1258516
         2616569	1258563
         2616618	1258563
         2616569	1258611
         2616473	1258611
         2616425	1258659
         2616328	1258659
         2616280	1258659
         2616231	1258659
         2616231	1258611
         2616183	1258611
         2616135	1258659
         2616086	1258707
         2615990	1258755
         2615941	1258755
         2615748	1258755
         2615700	1258755
         2615651	1258803
         2615603	1258851
         2615603	1258899
         2615555	1258947
         2615507	1258947
         2615458	1258899
         2615410	1258899
         2615313	1258899
         2615169	1258899
         2615120	1258947
         2615120	1258994
         2615023	1259043
         2614975	1259090
         2614927	1259090
         2614878	1259138
         2614878	1259186
         2614927	1259186
         2614975	1259186
         2614975	1259234
         2614975	1259282
         2614927	1259330
         2614878	1259330
         2614878	1259378
         2614878	1259426
         2614927	1259426
         2614975	1259426
         2615023	1259426
         2615023	1259378
         2615072	1259330
         2615120	1259330
         2615120	1259282
         2615169	1259282
         2615217	1259282
         2615266	1259282
         2615313	1259330
         2615313	1259426
         2615362	1259522
         2615362	1259569
         2615362	1259618
         2615313	1259713
         2615313	1259761
         2615266	1259809
         2615169	1259809
         2614975	1259809
         2614831	1259809
         2614782	1259809
         2614685	1259809
         2614589	1259857
         2614589	1259905
         2614589	1259953
         2614540	1260001
         2614589	1260048
         2614589	1260097
         2614589	1260192
         2614589	1260240
         2614540	1260576
         2614493	1260767
         2614347	1260815
         2614154	1260767
         2613864	1260672
         2613768	1260432
         2613623	1260384
         2613574	1260384
         2613526	1260623
         2613623	1260863
         2613719	1260959
         2613768	1261007
         2613816	1261007
         2613912	1261007
         2614105	1261055
         2614299	1261103
         2614493	1261103
         2614685	1261151
         2614831	1261151
         2614927	1261151
         2614975	1261198
         2615169	1261198
         2615266	1261198
         2615410	1261198
         2615507	1261198
         2615555	1261198
         2615603	1261198
         2615700	1261198
         2615845	1261151
         2615938	1261104
         2616038	1261055
         2616376	1260863
         2616425	1260815
         2616473	1260767
         2616569	1260719
         2616569	1260623
         2616521	1260576
         2616425	1260480
         2616425	1260432
         2616473	1260384
         2616762	1260240
         2617100	1260048
         2617150	1260048
         2617197	1260144
         2617150	1260288
         2617150	1260336
         2617197	1260336
         2617294	1260192
         2617294	1260048
         2617342	1259905
         2617439	1259809
         2617488	1259761
         2617535	1259713
         2617632	1259761
         2617680	1259761
         2617729	1259809
         2617826	1259905
         2617873	1259953
         2617970	1260097
         2618018	1260144
         2618018	1260192
         2618018	1260240
         2617970	1260384
         2618018	1260432
         2618067	1260432
         2618115	1260432
         2618164	1260336
         2618164	1260288
         2618164	1260192
         2618164	1260144
         2618212	1260097
         2618260	1260097
         2618308	1260192
         2618308	1260240
         2618308	1260288
         2618308	1260336
         2618308	1260384
         2618308	1260432
         2618212	1260623
         2618067	1260719
         2618018	1260719
         2617970	1260719
         2617922	1260767
         2617873	1260815
         2617873	1260863
         2617873	1260911
         2617729	1261103
         2617488	1261294
         2617488	1261342
         2617488	1261390
         2617488	1261438
         2617488	1261486
         2617439	1261534
         2617246	1261582
         2617197	1261582
         2617150	1261534
         2617100	1261534
         2617053	1261534
         2616907	1261534
         2616859	1261534
         2616618	1261534
         2616521	1261630
         2616425	1261630
         2616376	1261630
         2616328	1261582
         2616280	1261582
         2616038	1261534
         2615893	1261582
         2615845	1261630
         2615796	1261678
         2615796	1261726
         2615845	1261773
         2615845	1261822
         2615796	1261869
         2615748	1261869
         2615700	1261822
         2615651	1261822
         2615458	1261773
         2615410	1261773
         2615362	1261773
         2615217	1261917
         2615169	1261917
         2615169	1261869
         2615072	1261822
         2615023	1261822
         2614975	1261869
         2614927	1261869
         2614878	1261869
         2614831	1261869
         2614782	1261869
         2614782	1261822
         2614831	1261822
         2614831	1261773
         2614782	1261726
         2614685	1261678
         2614493	1261726
         2614443	1261773
         2614396	1261822
         2614347	1261869
         2614299	1261965
         2614299	1262013
         2614347	1262109
         2614396	1262157
         2614443	1262157
         2614443	1262205
         2614443	1262252
         2614443	1262301
         2614443	1262348
         2614396	1262492
         2614347	1262540
         2614299	1262540
         2614251	1262540
         2614251	1262492
         2614251	1262444
         2614202	1262396
         2614202	1262348
         2614009	1262205
         2613961	1262252
         2613864	1262301
         2613816	1262301
         2613768	1262301
         2613719	1262301
         2613671	1262396
         2613671	1262444
         2613671	1262492
         2613719	1262540
         2613864	1262684
         2613912	1262780
         2614009	1262827
         2614058	1262827
         2614105	1262827
         2614202	1262827
         2614299	1262876
         2614299	1263019
         2614347	1263067
         2614396	1263115
         2614493	1263115
         2614540	1263115
         2614975	1262923
         2615023	1262876
         2615072	1262876
         2615120	1262923
         2615072	1262971
         2615120	1263019
         2615169	1263019
         2615217	1263067
         2615217	1263115
         2615217	1263163
         2615266	1263211
         2615313	1263211
         2615362	1263211
         2615410	1263211
         2615458	1263211
         2615555	1263259
         2615651	1263307
         2615700	1263307
         2615748	1263307
         2615845	1263259
         2615893	1263211
         2615941	1263211
         2615990	1263259
         2616086	1263355
         2616183	1263402
         2616280	1263451
         2616811	1263546
         2616907	1263594
         2617004	1263738
         2617004	1263786
         2617004	1263834
         2617004	1263882
         2617053	1263930
         2617100	1263977
         2617197	1263977
         2617246	1263977
         2617439	1263977
         2617488	1263977
         2617535	1263977
         2617632	1263930
         2617680	1263930
         2617729	1263930
         2617826	1263977
         2617873	1264073
         2617826	1264121
         2618018	1264313
         2618115	1264505
         2618164	1264601
         2618212	1264648
         2618260	1264696
         2618260	1264744
         2618260	1264792
         2618212	1264792
         2618164	1264744
         2618164	1264696
         2618115	1264696
         2618067	1264744
         2618067	1264792
         2618115	1264840
         2618115	1264888
         2618115	1264984
         2618067	1265032
         2618018	1265080
         2617729	1265223
         2617439	1265463
         2617391	1265463
         2617391	1265415
         2617391	1265367
         2617439	1265271
         2617535	1265127
         2617632	1265032
         2617680	1264984
         2617680	1264936
         2617680	1264888
         2617680	1264840
         2617680	1264792
         2617632	1264744
         2617535	1264696
         2617488	1264648
         2617439	1264648
         2617391	1264648
         2617294	1264744
         2617246	1264792
         2617150	1264792
         2617100	1264792
         2617053	1264792
         2617004	1264792
         2616956	1264792
         2616907	1264792
         2616859	1264792
         2616811	1264792
         2616762	1264792
         2616762	1264744
         2616762	1264696
         2616762	1264648
         2616715	1264601
         2616666	1264601
         2616618	1264648
         2616569	1264696
         2616473	1264696
         2616425	1264696
         2616376	1264648
         2616328	1264601
         2616328	1264552
         2616280	1264552
         2616231	1264552
         2616086	1264601
         2615796	1264840
         2615507	1265175
         2615555	1265223
         2615603	1265319
         2615748	1265463
         2615893	1265607
         2615990	1265607
         2616038	1265607
         2616086	1265559
         2616135	1265463
         2616183	1265319
         2616231	1265319
         2616280	1265319
         2616328	1265367
         2616328	1265511
         2616328	1265559
         2616280	1265607
         2616280	1265655
         2616231	1265703
         2615990	1265894
         2615941	1265894
         2615893	1265846
         2615845	1265846
         2615845	1265894
         2615845	1265942
         2615845	1265990
         2616086	1266230
         2616086	1266278
         2615748	1266374
         2615700	1266374
         2615651	1266421
         2615700	1266469
         2615748	1266517
         2615796	1266565
         2615941	1266709
         2615941	1266757
         2615941	1266805
         2615700	1266996
         2615603	1267044
         2615555	1267188
         2615555	1267236
         2615651	1267379
         2615796	1267475
         2615845	1267475
         2615893	1267523
         2615941	1267572
         2615941	1267619
         2615893	1267667
         2615845	1267715
         2615748	1267859
         2615845	1268003
         2615990	1268098
         2616135	1268050
         2616183	1268050
         2616231	1268050
         2616280	1268050
         2616328	1268050
         2616473	1268098
         2616569	1268194
         2616569	1268242
         2616618	1268386
         2616666	1268386
         2616762	1268482
         2616859	1268482
         2617150	1268386
         2617197	1268338
         2617197	1268290
         2617246	1268290
         2617294	1268290
         2617439	1268290
         2617584	1268338
         2617680	1268434
         2617729	1268530
         2618018	1268578
         2618164	1268482
         2618212	1268434
         2618260	1268482
         2618260	1268530
         2618357	1268626
         2618405	1268673
         2618453	1268722
         2618791	1268865
         2619129	1269153
         2619178	1269201
         2619275	1269297
         2619323	1269297
         2619372	1269297
         2619564	1269344
         2619710	1269440
         2619757	1269488
         2619806	1269488
         2619951	1269344
         2620289	1269057
         2620530	1268865
         2620579	1268817
         2620627	1268769
         2620627	1268722
         2620675	1268722
         2620675	1268769
         2620675	1268817
         2620675	1268865
         2620579	1269057
         2620434	1269153
         2620289	1269297
         2620096	1269440
         2619999	1269488
         2619951	1269536
         2619854	1269632
         2619806	1269680
         2619757	1269728
         2619710	1269776
         2619372	1269871
         2619323	1269871
         2619226	1269871
         2619178	1269871
         2619129	1269871
         2619033	1269871
         2618985	1269871
         2618888	1269871
         2618840	1269871
         2618260	1269536
         2617632	1269344
         2617584	1269344
         2617535	1269392
         2617535	1269440
         2617584	1269536
         2617584	1269584
         2617584	1269632
         2617584	1269728
         2617680	1269824
         2617680	1269871
         2617680	1269920
         2617632	1269920
         2617584	1269920
         2617535	1269920
         2617488	1269920
         2617439	1269920
         2617342	1269920
         2617100	1269824
         2616859	1269776
         2616811	1269776
         2616762	1269776
         2616280	1269632
         2616231	1269632
         2615941	1269632
         2615893	1269632
         2615845	1269632
         2615796	1269632
         2615700	1269632
         2615603	1269680
         2615362	1269728
         2615266	1269728
         2615169	1269728
         2615023	1269680
         2614927	1269632
         2614831	1269584
         2614734	1269536
         2614685	1269536
         2614300	1269297
         2614299	1269297
         2614202	1269297
         2614154	1269249
         2614058	1269249
         2614009	1269249
         2613961	1269249
         2613912	1269297
         2613816	1269297
         2613719	1269249
         2613623	1269201
         2613429	1269105
         2613188	1269057
         2612994	1269009
         2612898	1269009
         2612753	1269009
         2612608	1269009
         2612463	1269009
         2612367	1269057
         2612271	1269105
         2612077	1269201
         2611932	1269249
         2611836	1269297
         2611642	1269440
         2611545	1269488
         2611448	1269488
         2611256	1269488
         2611159	1269488
         2611014	1269440
         2610869	1269392
         2610772	1269344
         2610724	1269297
         2610724	1269249
         2610772	1269201
         2610869	1269249
         2611014	1269297
         2611062	1269297
         2611159	1269297
         2611256	1269297
         2611401	1269249
         2611497	1269201
         2611545	1269105
         2611739	1268578
         2611836	1268434
         2611932	1268194
         2612028	1267954
         2612028	1267907
         2612028	1267811
         2612028	1267715
         2612028	1267667
         2611883	1267428
         2611739	1267284
         2611690	1267236
         2611497	1267188
         2611448	1267188
         2611401	1267188
         2611256	1267188
         2611014	1267044
         2610966	1266996
         2610917	1266949
         2610917	1266853
         2610966	1266805
         2610966	1266757
         2610772	1266565
         2610386	1266182
         2610048	1266086
         2609710	1265942
         2608792	1265367
         2608357	1265080
         2608261	1265032
         2608164	1264984
         2608067	1264984
         2607971	1264984
         2607922	1264984
         2607874	1264984
         2607826	1264984
         2607633	1264984
         2607584	1264984
         2607391	1265080
         2607246	1265319
         2607246	1265367
         2607246	1265415
         2607246	1265463
         2607198	1265559
         2607150	1265607
         2607150	1265703
         2607198	1265894
         2607150	1265942
         2607101	1265990
         2607053	1265990
         2607004	1265990
         2606860	1265942
         2606715	1265894
         2606666	1265846
         2606569	1265846
         2606522	1265846
         2606425	1265942
         2606377	1265990
         2606280	1266086
         2606280	1266182
         2606425	1266182
         2606569	1266134
         2606763	1266086
         2606811	1266086
         2606860	1266086
         2607053	1266230
         2607150	1266325
         2607150	1266374
         2607150	1266421
         2607150	1266469
         2607101	1266517
         2607053	1266421
         2607004	1266421
         2606907	1266613
         2606860	1266757
         2606860	1266805
         2606811	1266805
         2606763	1266805
         2606715	1266805
         2606522	1266805
         2606473	1266805
         2606425	1266900
         2606473	1266900
         2606522	1266900
         2606666	1266996
         2606715	1266996
         2606763	1266996
         2606860	1266949
         2606860	1266900
         2606907	1266900
         2606957	1266900
         2607004	1266900
         2607150	1266996
         2607246	1267092
         2607246	1267140
         2607004	1267332
         2606763	1267475
         2605845	1268050
         2605748	1268098
         2605652	1268146
         2605555	1268194
         2605314	1268434
         2605120	1268578
         2605072	1268722
         2605120	1268817
         2605169	1268865
         2605169	1269009
         2605169	1269105
         2605217	1269201
         2605410	1269536
         2605459	1269536
         2605555	1269680
         2605555	1269728
         2605555	1269824
         2605555	1269871
         2605555	1269920
         2605555	1269967
         2605555	1270015
         2605555	1270063
         2605555	1270111
         2605555	1270159
         2605555	1270207
         2605507	1270351
         2605459	1270686
         2605507	1270782
         2605555	1270878
         2606039	1271693
         2606087	1271693
         2606135	1271693
         2606183	1271740
         2606135	1271837
         2606087	1271884
         2606039	1271980
         2606039	1272028
         2606039	1272076
         2606039	1272124
         2606039	1272172
         2606039	1272220
         2606039	1272268
         2605893	1272507
         2605700	1272891
         2605748	1272939
         2605990	1272651
         2606183	1272316
         2606231	1272363
         2606231	1272412
         2606231	1272459
         2606231	1272507
         2606231	1272555
         2606183	1272651
         2606087	1272795
         2606087	1272939
         2606087	1272987
         2606087	1273034
         2606231	1273034
         2606377	1273034
         2606522	1273034
         2606618	1272987
         2606666	1272987
         2606811	1273034
         2606860	1273082
         2606907	1273082
         2606957	1273082
         2607004	1273034
         2607004	1272939
         2607004	1272795
         2607004	1272747
         2607004	1272651
         2607004	1272603
         2607004	1272555
         2606907	1272363
         2607004	1272172
         2607150	1272124
         2607198	1272124
         2607246	1272124
         2607342	1272220
         2607488	1272268
         2607633	1272316
         2607681	1272316
         2607826	1272363
         2607971	1272507
         2608019	1272651
         2607971	1272747
         2607488	1272987
         2607584	1272987
         2607633	1272987
         2607681	1272987
         2607729	1272987
         2607777	1272987
         2607777	1273034
         2607633	1273130
         2607488	1273130
         2607198	1273226
         2607150	1273274
         2607101	1273322
         2607101	1273370
         2607150	1273514
         2607439	1273706
         2607584	1273801
         2607729	1273801
         2607777	1273753
         2607874	1273706
         2608116	1273514
         2608164	1273466
         2608164	1273418
         2608261	1273322
         2608357	1273226
         2608405	1273226
         2608454	1273226
         2608550	1273274
         2608647	1273322
         2608695	1273418
         2608647	1273514
         2608599	1273610
         2608454	1273657
         2608309	1273801
         2608212	1273897
         2608212	1273993
         2608212	1274089
         2608212	1274137
         2608309	1274185
         2608454	1274185
         2608550	1274185
         2608695	1274137
         2608840	1274089
         2608888	1274137
         2608888	1274185
         2608937	1274280
         2609179	1274664
         2609323	1274760
         2609372	1274856
         2609130	1274999
         2608888	1275191
         2608840	1275239
         2608695	1275335
         2608550	1275431
         2608405	1275575
         2608261	1275623
         2608067	1275670
         2607874	1275670
         2607729	1275670
         2607681	1275527
         2607633	1275383
         2607391	1274568
         2607342	1274424
         2607295	1274329
         2607198	1274137
         2607150	1274137
         2607101	1274137
         2606957	1274089
         2606907	1273945
         2606907	1273897
         2606907	1273849
         2606860	1273849
         2606860	1273897
         2606860	1273945
         2606860	1273993
         2606811	1273993
         2606763	1273993
         2606618	1273897
         2606473	1273849
         2606425	1273849
         2606377	1273849
         2606377	1273897
         2606425	1273945
         2606473	1273993
         2606522	1274041
         2606473	1274089
         2606425	1274089
         2606280	1274041
         2606087	1273945
         2605748	1273801
         2605604	1273753
         2605507	1273610
         2605459	1273466
         2605459	1273418
         2605362	1272843
         2605314	1272651
         2605266	1272363
         2605266	1272220
         2605217	1271932
         2605120	1271740
         2605024	1271453
         2605024	1271213
         2605024	1271165
         2604975	1270543
         2604975	1270495
         2604975	1270303
         2604975	1270063
         2604975	1269824
         2604975	1269632
         2604975	1269488
         2604879	1268769
         2604831	1268626
         2604831	1268482
         2604831	1268338
         2604879	1267859
         2604975	1267619
         2605024	1267379
         2605120	1267188
         2605266	1266853
         2605314	1266805
         2605362	1266661
         2605410	1266565
         2605410	1266421
         2605362	1266278
         2605362	1266182
         2605362	1266086
         2605362	1265990
         2605362	1265942
         2605362	1265894
         2605362	1265846
         2605362	1265799
         2605507	1265607
         2605555	1265607
         2605604	1265559
         2605748	1265511
         2605990	1265415
         2606183	1265319
         2606377	1264984
         2606377	1264888
         2606425	1264552
         2606522	1264121
         2606522	1264026
         2606522	1263882
         2606522	1263690
         2606522	1263642
         2606522	1263546
         2606522	1263498
         2606522	1263355
         2606522	1263115
         2606569	1263067
         2606618	1262923
         2606666	1262827
         2606715	1262684
         2606763	1262492
         2606763	1262396
         2606763	1262348
         2606763	1262252
         2606763	1262205
         2606763	1262157
         2606763	1262109
         2606763	1262061
         2606763	1262013
         2606763	1261965
         2606763	1261917
         2606763	1261869
         2606715	1261726
         2606666	1261630
         2606715	1261630
         2607342	1261630
         2607391	1261630
         2607439	1261630
         2607488	1261630
         2607536	1261630
         2607633	1261630
         2607826	1261726
         2607971	1261917
         2608019	1261965
         2608067	1262013
         2608067	1262157
         2608116	1262348
         2608212	1262588
         2608261	1262684
         2608357	1262780
         2608405	1262827
         2608454	1262876
         2608502	1262876
         2608840	1263019
         2609372	1263115
         2609420	1263115
         2609517	1263115
         2609613	1263115
         2609710	1263115
         2609806	1263115
         2610048	1263067
         2610289	1262876
         2610338	1262827
         2610386	1262780
         2610531	1262732
         2610676	1262636
         2610724	1262636
         2610869	1262636
         2610917	1262636
         2611014	1262636
         2611110	1262684
         2611159	1262732
         2611207	1262780
         2611401	1263067
         2611642	1263307
         2611739	1263355
         2612077	1263402
         2612463	1263498
         2612850	1263690
         2612898	1263690
         2612994	1263738
         2613043	1263738
         2612801	1263594
         2612415	1263451
         2612028	1263259
         2611786	1263115
         2611739	1263115
         2611594	1262923
         2611352	1262636
         2611304	1262588
         2611256	1262492
         2611062	1262396
         2610917	1262396
         2610869	1262396
         2610724	1262396
         2610627	1262396
         2610434	1262540
         2610241	1262588
         2610145	1262684
         2610145	1262732
         2609951	1262827
         2609758	1262876
         2609710	1262876
         2609613	1262876
         2609517	1262876
         2609420	1262876
         2609372	1262876
         2608888	1262827
         2608599	1262684
         2608550	1262684
         2608502	1262636
         2608454	1262540
         2608405	1262492
         2608357	1262301
         2608309	1262109
         2608261	1261917
         2608212	1261869
         2608212	1261822
         2608116	1261726
         2607922	1261534
         2607729	1261438
         2607633	1261390
         2607536	1261390
         2607488	1261390
         2607439	1261390
         2607391	1261390
         2607342	1261390
         2606715	1261390
         2606618	1261390
         2606569	1261390
         2606473	1261342
         2606183	1260911
         2605748	1260288
         2605410	1260001
         2604879	1259474
         2604347	1258994
         2603768	1258611
         2603285	1258420
         2602609	1258372
         2602560	1258372
         2602125	1258372
         2601836	1258372
         2601546	1258276
         2601208	1258084
         2601063	1257988
         2600870	1257797
         2600773	1257653
         2600676	1257509
         2600435	1257078
         2600290	1256551
         2600241	1256312
         2600193	1256072
         2600096	1255881
         2600070	1255730
         2600047	1255638
         2600000	1255558
         2600000	1256755
         2600145	1257222
         2600387	1257701
         2600483	1257845
         2600628	1257988
         2600870	1258228
         2601014	1258372
         2601401	1258563
         2601787	1258707
         2602125	1258707
         2602560	1258707
         2602609	1258707
         2603188	1258755
         2603623	1258899
         2604155	1259234
         2604638	1259713
         2605169	1260240
         2605507	1260528
         2605893	1261103
         2606328	1261726
         2606377	1261822
         2606425	1261917
         2606425	1261965
         2606425	1262013
         2606425	1262061
         2606425	1262109
         2606425	1262157
         2606425	1262205
         2606425	1262252
         2606425	1262348
         2606425	1262396
         2606425	1262444
         2606377	1262588
         2606280	1262732
         2606280	1262780
         2606231	1262923
         2606183	1263067
         2606135	1263355
         2606183	1263498
         2606183	1263546
         2606183	1263642
         2606183	1263647
         2606183	1263690
         2606183	1263882
         2606183	1264026
         2606183	1264073
         2606087	1264505
         2606039	1264840
         2605942	1265032
         2605893	1265032
         2605845	1265080
         2605652	1265175
         2605507	1265223
         2605314	1265319
         2605266	1265367
         2605120	1265559
         2605072	1265607
         2605072	1265799
         2605072	1265894
         2605072	1265942
         2605072	1265990
         2605072	1266086
         2605072	1266182
         2605072	1266278
         2605072	1266421
         2605072	1266469
         2605072	1266517
         2605072	1266565
         2605024	1266661
         2604975	1266709
         2604831	1267044
         2604734	1267284
         2604685	1267523
         2604589	1267763
         2604493	1268338
         2604493	1268482
         2604493	1268673
         2604589	1268817
         2604685	1269488
         2604685	1269632
         2604685	1269824
         2604685	1270063
         2604685	1270303
         2604685	1270495
         2604685	1270543
         2604685	1271165
         2604685	1271213
         2604685	1271501
         2604831	1271884
         2604927	1272028
         2604927	1272220
         2604927	1272412
         2605024	1272699
         2605024	1272843
         2605072	1272939
         2605072	1273082
         2605120	1273274
         2605120	1273322
         2605072	1273418
         2605072	1273466
         2605024	1273562
         2605024	1273610
         2605024	1273657
         2605024	1273753
         2604975	1273849
         2604685	1274233
         2604589	1274329
         2604541	1274472
         2604444	1274568
         2604396	1274616
         2604251	1274760
         2604058	1274952
         2603961	1275047
         2603671	1275287
         2603526	1275431
         2603382	1275670
         2603333	1275766
         2603285	1275862
         2603285	1276054
         2603285	1276150
         2603285	1276246
         2603236	1276389
         2603188	1276581
         2603140	1276725
         2603092	1276821
         2602995	1277348
         2602753	1277971
         2602753	1278019
         2602705	1278115
         2602657	1278307
         2602609	1278354
         2602318	1279073
         2602271	1279265
         2602271	1279313
         2602222	1279601
         2602174	1279840
         2602174	1280128
         2602174	1280511
         2602222	1280943
         2602125	1281278
         2602029	1281806
         2601933	1282189
         2601836	1282525
         2601836	1282573
         2601836	1282620
         2601836	1282669
         2601884	1282669
         2601884	1282620
         2601933	1282620
         2601933	1282669
         2601933	1282717
         2601933	1282764
         2601787	1282860
         2601643	1282860
         2601449	1282860
         2601304	1282813
         2600966	1282669
         2600290	1282429
         2600000	1282429
         2596023	1280950
         2581841	1299755
         2569320	1310472
         2567675	1313699
         2554039	1328178
         2548623	1327604
         2537207	1332922
         2538254	1338322
         2528995	1344729
         2520279	1350599
         2513163	1359712
         2511491	1365631
         2502218	1372568
         2480367	1391258
         2419939	1413329
         2414530	1411658
         2397145	1414169
         2383074	1411323
         2372187	1414970
         2364608	1413807
         2361815	1420774
         2363384	1425638
         2371476	1429502
         2331243	1432711
         2324294	1433266
         2304290	1419698
         2276358	1402526
         2248427	1385355
         2218347	1372476
         2207605	1348865
         2174302	1335987
         2149594	1334913
         2114142	1330621
         2092787	1341828
         2084968	1342557
         2061869	1367352
         2055858	1371530
         2047058	1380479
         2039500	1380871
         2048351	1369246
         2055480	1362945
         2053412	1358082
         2037693	1362614
         2033485	1357175
         2028585	1359761
         2019458	1357980
         2014517	1362706
         2008011	1364723
         2000998	1365120
         2000048	1385455
         1987996	1394849
         1991105	1400803
         1986165	1404985
         1986511	1414095
         1956862	1438079
         1941711	1440413
         1932876	1449306
         1913961	1473462
         1910055	1478714
         1905717	1479678
         1888491	1499562
         1856493	1545739
         1845349	1576939
         1838546	1587959
         1833131	1588338
         1825256	1598785
         1817588	1619908
         1815506	1634788
         1820103	1643467
         1823330	1644099
         1826831	1653279
         1834728	1660459
         1840597	1663307
         1833175	1692446
         1837604	1706466
         1840794	1741810
         1845396	1750502
         1860034	1751500
         1859195	1760555
         1853901	1772673
         1854344	1791918
         1858098	1809670
         1854229	1827172
         1850499	1855893
         1854434	1883271
         1864408	1924758
         1875320	1940636
         1880458	1949901
         1893342	1972269
         1900706	1985051
         1918715	1998267
         1925364	2007127
         2453416	2383857
         2453422	2383760
         2453598	2383579
         2453598	2383481
         2453687	2383387
         2453687	2383291
         2454180	2382775
         2454362	2382779
         2454450	2382681
         2454542	2382677
         2454632	2382586
         2454901	2382590
         2454984	2382489
         2455172	2382496
         2455252	2382395
         2455524	2382398
         2455614	2382308
         2455703	2382304
         2455792	2382213
         2455972	2382210
         2456061	2382119
         2456243	2382116
         2456420	2381931
         2456602	2381931
         2456778	2381740
         2456867	2381746
         2456957	2381645
         2457138	2381648
         2457226	2381552
         2457674	2381552
         2457767	2381461
         2457851	2381457
         2457940	2381366
         2458121	2381363
         2458212	2381271
         2458301	2381268
         2458391	2381177
         2458569	2381174
         2458658	2381084
         2458749	2381080
         2458838	2380982
         2459020	2380986
         2459107	2380894
         2459289	2380891
         2459377	2380801
         2459557	2380798
         2459647	2380706
         2459909	2380706
         2460005	2380609
         2460361	2380609
         2460450	2380519
         2460539	2380519
         2460632	2380605
         2461253	2380609
         2461343	2380706
         2461439	2380703
         2461526	2380800
         2461704	2380796
         2461792	2380893
         2461880	2380890
         2461974	2380987
         2462245	2380981
         2462287	2380943
         2462287	2380846
         2462422	2380703
         2462693	2380706
         2462780	2380612
         2462963	2380609
         2463050	2380512
         2463315	2380522
         2463411	2380424
         2463946	2380421
         2464033	2380519
         2464261	2380280
         2464257	2380093
         2464347	2380002
         2464350	2379815
         2464440	2379717
         2464443	2379531
         2464622	2379346
         2464616	2379249
         2464798	2379068
         2464795	2378971
         2465025	2378733
         2465108	2378733
         2465204	2378639
         2465377	2378639
         2465563	2378455
         2465647	2378455
         2465743	2378361
         2465832	2378361
         2465877	2378314
         2465874	2378127
         2466098	2377892
         2466278	2377889
         2466366	2377799
         2466456	2377795
         2466545	2377704
         2466634	2377701
         2466724	2377610
         2467259	2377610
         2467352	2377703
         2467441	2377703
         2467534	2377791
         2467707	2377794
         2467800	2377891
         2467889	2377887
         2467982	2377984
         2468155	2377981
         2468248	2378078
         2468337	2378074
         2468429	2378171
         2468517	2378168
         2468607	2378266
         2468785	2378262
         2468971	2378452
         2469054	2378452
         2469144	2378540
         2469236	2378546
         2469327	2378634
         2469419	2378639
         2469502	2378727
         2469684	2378730
         2469774	2378827
         2469947	2378824
         2470040	2378920
         2470222	2378925
         2470315	2379012
         2470398	2379018
         2470488	2379106
         2470670	2379112
         2470763	2379200
         2470935	2379203
         2471025	2379300
         2471207	2379297
         2471291	2379390
         2471473	2379390
         2471565	2379483
         2471656	2379483
         2471738	2379577
         2472103	2379577
         2472184	2379668
         2473091	2379675
         2473173	2379573
         2473360	2379577
         2473623	2379859
         2473713	2379856
         2473801	2379952
         2474164	2379952
         2474251	2380044
         2474701	2380044
         2474789	2380137
         2475057	2380141
         2475193	2379997
         2475193	2379906
         2475279	2379815
         2475284	2379621
         2475372	2379527
         2475372	2379430
         2475418	2379386
         2475596	2379390
         2475686	2379290
         2475957	2379293
         2476047	2379390
         2476674	2379386
         2476764	2379480
         2477392	2379483
         2477480	2379392
         2477565	2379389
         2477617	2379339
         2477613	2379248
         2477657	2379201
         2477747	2379201
         2477837	2379101
         2477929	2379197
         2478019	2379194
         2478106	2379291
         2478285	2379294
         2478378	2379382
         2478643	2379385
         2478736	2379294
         2478912	2379291
         2479002	2379384
         2479455	2379384
         2479539	2379482
         2479632	2379479
         2479716	2379576
         2479903	2379572
         2479986	2379666
         2480349	2379669
         2480436	2379762
         2480708	2379766
         2480796	2379853
         2481514	2379857
         2481603	2379757
         2481783	2379760
         2481867	2379669
         2481959	2379669
         2482228	2379387
         2482321	2379384
         2482408	2379293
         2482497	2379290
         2482722	2379056
         2482719	2378964
         2482762	2378917
         2482945	2378914
         2482990	2378961
         2482990	2379339
         2482901	2379433
         2483038	2379570
         2483214	2379570
         2483304	2379663
         2483396	2379663
         2483486	2379758
         2483931	2379758
         2484020	2379663
         2484555	2379663
         2484651	2379570
         2484917	2379567
         2485012	2379482
         2485185	2379479
         2485282	2379378
         2485367	2379384
         2485551	2379194
         2485635	2379200
         2485817	2379009
         2486083	2379006
         2486170	2378913
         2486262	2378913
         2486438	2378728
         2486532	2378728
         2486708	2378537
         2486804	2378543
         2487073	2378252
         2487163	2378258
         2487560	2377833
         2487566	2377742
         2487700	2377599
         2487790	2377603
         2487924	2377459
         2487921	2377368
         2488097	2377181
         2488103	2376994
         2488193	2376901
         2488188	2376618
         2488283	2376525
         2488276	2376143
         2488373	2376054
         2488370	2375865
         2488459	2375774
         2488463	2375588
         2488550	2375496
         2488550	2375400
         2489001	2374927
         2488998	2374836
         2489086	2374736
         2489083	2374648
         2489180	2374555
         2489180	2374458
         2489268	2374367
         2489268	2373992
         2489356	2373894
         2489356	2373430
         2489225	2373282
         2489135	2373287
         2489043	2373189
         2488861	2373192
         2488822	2373148
         2488819	2372587
         2488908	2372490
         2488905	2372399
         2489180	2372117
         2489176	2372020
         2489266	2371929
         2489269	2371742
         2489532	2371461
         2489532	2371364
         2489624	2371270
         2489621	2371183
         2489532	2371085
         2489541	2370899
         2489448	2370805
         2489445	2370618
         2489490	2370571
         2489579	2370571
         2489624	2370524
         2489624	2370239
         2489532	2370146
         2489532	2369965
         2489583	2369912
         2489671	2369912
         2489762	2369819
         2489851	2369824
         2489896	2369771
         2489893	2369674
         2489938	2369630
         2490027	2369633
         2490114	2369536
         2490207	2369533
         2490297	2369449
         2490386	2369445
         2490475	2369349
         2490566	2369349
         2490654	2369255
         2490744	2369255
         2490833	2369162
         2491102	2369165
         2491191	2369069
         2491282	2369072
         2491371	2368975
         2491553	2368979
         2491640	2368887
         2491729	2368884
         2491995	2368602
         2492089	2368598
         2492134	2368555
         2492094	2368512
         2492001	2368505
         2491865	2368365
         2491861	2368178
         2491912	2368134
         2492085	2368130
         2492177	2368224
         2492360	2368220
         2492450	2368312
         2492892	2368124
         2492984	2368128
         2493209	2367893
         2493209	2367802
         2493248	2367758
         2493964	2367755
         2494058	2367661
         2494147	2367661
         2494283	2367521
         2494278	2367424
         2494463	2367243
         2494458	2367146
         2494643	2366955
         2494637	2366864
         2494819	2366680
         2494816	2366486
         2495002	2366302
         2494995	2366205
         2495226	2365970
         2495315	2365970
         2495360	2365927
         2495363	2365829
         2495402	2365786
         2495491	2365786
         2495677	2365596
         2495760	2365599
         2495990	2365365
         2495985	2365268
         2496167	2365084
         2496163	2364522
         2496118	2364469
         2496029	2364469
         2495984	2364422
         2495987	2364330
         2496163	2364139
         2496163	2364049
         2496387	2363814
         2496478	2363818
         2496835	2363443
         2496928	2363438
         2497059	2363296
         2497063	2363209
         2497376	2362878
         2497466	2362878
         2497553	2362784
         2497642	2362784
         2497684	2362735
         2497597	2362644
         2497603	2362456
         2497507	2362363
         2497510	2361804
         2497599	2361707
         2497596	2361519
         2498224	2360867
         2498224	2360771
         2498313	2360676
         2498317	2360399
         2498409	2360302
         2498404	2359931
         2498634	2359692
         2499072	2359696
         2499123	2359643
         2499115	2359464
         2499341	2359222
         2499431	2359225
         2499524	2359128
         2499706	2359131
         2499795	2359037
         2500240	2359037
         2500333	2358940
         2500685	2358947
         2500775	2359037
         2501671	2359041
         2501764	2358944
         2502215	2358947
         2502251	2358991
         2502254	2359179
         2502171	2359275
         2502260	2359366
         2502257	2359463
         2502303	2359510
         2502391	2359504
         2502657	2359791
         2502928	2359788
         2503016	2359881
         2503287	2359885
         2503380	2359791
         2503825	2359791
         2503918	2359695
         2504187	2359700
         2504411	2359456
         2504405	2359175
         2504456	2359128
         2504814	2359135
         2504854	2359182
         2504856	2359369
         2504946	2359460
         2504942	2359556
         2505077	2359694
         2505348	2359697
         2505615	2359414
         2505707	2359414
         2505794	2359319
         2505973	2359314
         2506062	2359226
         2506155	2359220
         2506245	2359133
         2506334	2359127
         2506382	2359083
         2506377	2358896
         2506424	2358853
         2506874	2358853
         2506968	2358758
         2507496	2358758
         2507585	2358665
         2507947	2358662
         2508035	2358568
         2508213	2358572
         2508306	2358475
         2508395	2358478
         2508664	2358197
         2508755	2358201
         2508840	2358104
         2508937	2358107
         2509113	2357916
         2509206	2357916
         2509738	2357358
         2509831	2357351
         2509878	2357308
         2509878	2357210
         2510054	2357026
         2510058	2356929
         2510141	2356842
         2510145	2356745
         2510237	2356648
         2510232	2356557
         2510324	2356464
         2510328	2356277
         2510504	2356092
         2510424	2355812
         2510423	2355810
         2510421	2355346
         2510328	2355250
         2510324	2355153
         2510237	2355062
         2510237	2354966
         2509695	2354410
         2509695	2354313
         2509743	2354263
         2510105	2354267
         2510195	2354360
         2510278	2354360
         2510374	2354451
         2510465	2354358
         2510547	2354358
         2510595	2354314
         2510593	2354031
         2510416	2353843
         2510416	2353752
         2510371	2353705
         2510107	2353701
         2510015	2353796
         2509919	2353796
         2509788	2353936
         2509791	2354033
         2509738	2354082
         2509656	2354079
         2509522	2353936
         2509522	2353652
         2509433	2353561
         2509433	2353464
         2509340	2353373
         2509340	2352811
         2509433	2352725
         2509427	2352627
         2509519	2352530
         2509519	2352068
         2509612	2351972
         2509615	2351784
         2509695	2351691
         2509702	2351594
         2509791	2351498
         2509788	2351316
         2509880	2351223
         2509875	2350284
         2509788	2350189
         2509784	2349906
         2509701	2349815
         2509788	2349722
         2509788	2349631
         2509919	2349491
         2510015	2349491
         2510102	2349397
         2510191	2349397
         2510278	2349304
         2510374	2349304
         2510467	2349210
         2510641	2349204
         2510733	2349116
         2510820	2349116
         2510999	2348927
         2511088	2348930
         2511488	2348502
         2511488	2348414
         2511536	2348367
         2511715	2348364
         2511808	2348277
         2511988	2348273
         2512073	2348176
         2512343	2348173
         2512436	2348085
         2512609	2348081
         2512701	2347985
         2512880	2347988
         2513418	2347430
         2513596	2347433
         2513689	2347337
         2513779	2347340
         2514000	2347096
         2514000	2346725
         2514092	2346634
         2514087	2346538
         2514006	2346447
         2513997	2346072
         2513917	2345975
         2513913	2345697
         2513997	2345601
         2514000	2345510
         2514093	2345417
         2514087	2345319
         2514270	2345135
         2514273	2345038
         2514362	2344950
         2514359	2344854
         2514541	2344661
         2514535	2344573
         2514942	2344151
         2515029	2344147
         2515477	2343677
         2515659	2343680
         2515748	2343583
         2515838	2343587
         2515930	2343490
         2516019	2343493
         2516283	2343211
         2516468	2343215
         2516647	2343025
         2516730	2343025
         2516913	2342841
         2517091	2342837
         2517184	2342750
         2517447	2342747
         2517493	2342697
         2517493	2342606
         2517676	2342416
         2517673	2342325
         2517894	2342087
         2517990	2342091
         2518170	2341901
         2518258	2341901
         2518348	2341807
         2518440	2341807
         2518661	2341574
         2518655	2341483
         2518748	2341385
         2518703	2341342
         2518614	2341339
         2518568	2341295
         2518614	2341248
         2518706	2341245
         2518795	2341154
         2518879	2341150
         2518976	2341247
         2519062	2341150
         2519153	2341154
         2519245	2341057
         2519514	2341063
         2519597	2340966
         2519776	2340963
         2519871	2340872
         2520045	2340869
         2520136	2340781
         2520233	2340775
         2520359	2340634
         2520359	2340447
         2520182	2340261
         2520188	2339886
         2520092	2339795
         2520095	2339608
         2520232	2339468
         2520316	2339468
         2520406	2339375
         2520496	2339375
         2520584	2339468
         2520946	2339465
         2521036	2339558
         2521215	2339558
         2521304	2339658
         2521394	2339652
         2521483	2339743
         2521572	2339746
         2521659	2339843
         2521836	2339840
         2521931	2339936
         2522104	2339933
         2522201	2340024
         2522374	2340027
         2522470	2340121
         2522560	2340121
         2522647	2340024
         2522825	2340027
         2522914	2340127
         2523005	2340122
         2523094	2340034
         2523360	2340031
         2523456	2340122
         2523635	2340125
         2523724	2340216
         2524086	2340216
         2524166	2340307
         2524437	2340310
         2524525	2340404
         2524707	2340407
         2524795	2340504
         2525156	2340495
         2525245	2340594
         2525786	2340594
         2525962	2340405
         2526141	2340408
         2526235	2340311
         2526497	2340317
         2526589	2340221
         2526951	2340221
         2527038	2340124
         2528382	2340124
         2528469	2340036
         2528744	2340033
         2528833	2340124
         2529187	2340124
         2529282	2340221
         2529366	2340221
         2529462	2340314
         2529551	2340308
         2529635	2340405
         2529725	2340408
         2529821	2340499
         2529999	2340502
         2530089	2340593
         2530533	2340593
         2530630	2340687
         2531343	2340690
         2531432	2340781
         2531884	2340781
         2531968	2340688
         2532412	2340693
         2532509	2340784
         2532598	2340779
         2532688	2340879
         2533312	2340879
         2533405	2340785
         2533760	2340782
         2533849	2340694
         2534208	2340684
         2534301	2340598
         2534572	2340594
         2534750	2340410
         2534838	2340404
         2534923	2340316
         2535191	2340312
         2535284	2340410
         2535463	2340406
         2535559	2340504
         2536003	2340497
         2536090	2340598
         2536183	2340598
         2536270	2340688
         2536359	2340692
         2536449	2340782
         2536631	2340785
         2536719	2340876
         2537163	2340876
         2537259	2340974
         2537522	2340970
         2537617	2341064
         2538335	2341067
         2538421	2341158
         2538604	2341162
         2538687	2341064
         2539139	2341064
         2539231	2340971
         2540034	2340974
         2540128	2340881
         2540217	2340881
         2540309	2340784
         2540393	2340788
         2540575	2340598
         2540665	2340598
         2540758	2340504
         2540841	2340504
         2540932	2340413
         2541020	2340410
         2541113	2340319
         2541202	2340316
         2541465	2340034
         2541560	2340034
         2541737	2339844
         2541827	2339848
         2542006	2339661
         2542095	2339664
         2542455	2339289
         2542543	2339289
         2542636	2339193
         2542725	2339196
         2542812	2339100
         2542899	2339103
         2543173	2338822
         2543258	2338822
         2543350	2338729
         2543441	2338729
         2543533	2338631
         2543706	2338635
         2544071	2338261
         2544247	2338257
         2544336	2338161
         2545142	2338166
         2545230	2338263
         2545412	2338260
         2545501	2338351
         2545590	2338351
         2545678	2338444
         2545949	2338447
         2546135	2338628
         2546218	2338631
         2546308	2338729
         2546577	2338726
         2546664	2338826
         2546756	2338826
         2546847	2338910
         2547025	2338913
         2547114	2339010
         2547293	2339006
         2547383	2339103
         2547472	2339106
         2547562	2339197
         2547651	2339192
         2547740	2339292
         2547918	2339292
         2548009	2339385
         2548188	2339385
         2548277	2339478
         2548458	2339473
         2548546	2339572
         2548640	2339572
         2548725	2339663
         2548908	2339667
         2548995	2339758
         2549088	2339761
         2549175	2339852
         2549267	2339856
         2549354	2339946
         2549625	2339950
         2549716	2340041
         2549889	2340044
         2549985	2340135
         2550247	2340138
         2550343	2340232
         2550615	2340235
         2550694	2340319
         2551328	2340323
         2551416	2340419
         2551771	2340416
         2551867	2340509
         2552311	2340509
         2552408	2340606
         2552943	2340600
         2553030	2340697
         2554288	2340693
         2554377	2340793
         2554466	2340793
         2554550	2340697
         2554646	2340790
         2554817	2340793
         2554913	2340697
         2555185	2340700
         2555274	2340603
         2555536	2340609
         2555629	2340513
         2555895	2340509
         2555992	2340418
         2556084	2340422
         2556260	2340232
         2556350	2340232
         2556526	2340041
         2556705	2340044
         2556797	2339948
         2557061	2339951
         2557153	2339854
         2557329	2339858
         2557783	2339387
         2557870	2339391
         2558049	2339196
         2558136	2339200
         2558232	2339103
         2558321	2339106
         2558498	2338920
         2558586	2338923
         2558901	2338592
         2558904	2338501
         2559033	2338361
         2559122	2338361
         2559215	2338267
         2559304	2338267
         2559396	2338171
         2559576	2338174
         2559669	2338081
         2559752	2338081
         2559842	2337984
         2560383	2337984
         2560470	2337890
         2560739	2337895
         2560831	2337797
         2561101	2337800
         2561187	2337707
         2561277	2337707
         2561371	2337614
         2561459	2337614
         2561549	2337517
         2561632	2337521
         2561818	2337334
         2561907	2337330
         2561996	2337240
         2562080	2337233
         2562266	2337049
         2562355	2337052
         2562445	2336956
         2562528	2336956
         2562714	2336766
         2562802	2336769
         2562893	2336673
         2562976	2336673
         2563069	2336585
         2563158	2336579
         2563251	2336492
         2563341	2336492
         2563424	2336394
         2563511	2336398
         2563697	2336211
         2563789	2336215
         2563873	2336118
         2563962	2336122
         2564145	2335928
         2564237	2335932
         2564503	2335650
         2564592	2335650
         2564768	2335460
         2564859	2335460
         2565623	2334665
         2565627	2334574
         2565938	2334244
         2566027	2334248
         2566296	2333966
         2566385	2333966
         2566523	2333820
         2566523	2333729
         2566699	2333545
         2566702	2333448
         2567150	2332977
         2567146	2332886
         2567371	2332652
         2567464	2332652
         2567688	2332419
         2567688	2332328
         2567726	2332281
         2567822	2332284
         2568092	2331997
         2568181	2331997
         2568494	2331672
         2568489	2331576
         2568581	2331482
         2568581	2331391
         2568802	2331155
         2568982	2331158
         2569074	2331061
         2569163	2331065
         2569250	2330967
         2569436	2330971
         2569523	2330874
         2569882	2330877
         2569967	2330784
         2570064	2330784
         2570157	2330691
         2570330	2330691
         2570512	2330501
         2570685	2330505
         2570774	2330407
         2570868	2330407
         2570957	2330314
         2571050	2330314
         2571133	2330217
         2571223	2330220
         2571405	2330037
         2571494	2330037
         2571718	2329800
         2571718	2329616
         2571811	2329518
         2571808	2329241
         2571853	2329191
         2572124	2329195
         2572169	2329151
         2572164	2328770
         2572215	2328723
         2572305	2328728
         2572525	2328490
         2572525	2328399
         2572794	2328121
         2572794	2328025
         2573063	2327745
         2573063	2327654
         2572797	2327366
         2572794	2327089
         2572839	2327040
         2573200	2327043
         2573288	2327134
         2574095	2327131
         2574278	2326946
         2574360	2326950
         2574543	2326762
         2574632	2326766
         2574809	2326573
         2574905	2326576
         2574992	2326480
         2575081	2326480
         2575257	2326295
         2575354	2326289
         2575391	2326246
         2575394	2326155
         2575667	2325874
         2575664	2325780
         2576112	2325314
         2576112	2325216
         2576249	2325079
         2576332	2325079
         2576607	2324798
         2576780	2324802
         2576914	2324656
         2576914	2324565
         2576966	2324516
         2577055	2324516
         2577145	2324425
         2577228	2324421
         2577411	2324234
         2577497	2324237
         2577676	2324044
         2577766	2324048
         2577859	2323951
         2577948	2323951
         2578124	2323767
         2578312	2323770
         2578397	2323674
         2578847	2323674
         2578937	2323576
         2579203	2323581
         2579385	2323396
         2579474	2323390
         2579519	2323346
         2579514	2323255
         2579561	2323212
         2579651	2323206
         2579740	2323115
         2580005	2323112
         2580102	2323024
         2580195	2323019
         2580275	2322931
         2580457	2322925
         2580550	2322838
         2580909	2322835
         2580996	2322738
         2582608	2322738
         2582698	2322829
         2583149	2322835
         2583238	2322925
         2583418	2322929
         2583502	2323020
         2583770	2323023
         2583860	2323114
         2584132	2323117
         2584218	2323208
         2584312	2323212
         2584398	2323302
         2584497	2323302
         2584759	2323583
         2584846	2323583
         2585298	2324053
         2585390	2324053
         2585656	2324335
         2585746	2324335
         2585791	2324382
         2585791	2324472
         2586011	2324706
         2586102	2324706
         2586147	2324759
         2586147	2324850
         2586331	2325036
         2586326	2325404
         2586424	2325502
         2586418	2325785
         2586508	2325876
         2586514	2326062
         2586594	2326155
         2586597	2326437
         2586508	2326528
         2586505	2326721
         2586284	2326949
         2586195	2326949
         2586019	2327142
         2585929	2327138
         2585746	2327329
         2585654	2327329
         2585608	2327373
         2585614	2327463
         2585477	2327610
         2585389	2327610
         2585295	2327706
         2585206	2327703
         2585121	2327794
         2585033	2327800
         2584629	2328218
         2584626	2328399
         2584534	2328495
         2584536	2328876
         2584757	2329103
         2584850	2329103
         2584895	2329150
         2584891	2329247
         2584936	2329291
         2585026	2329295
         2585160	2329432
         2585164	2329712
         2585119	2329759
         2585026	2329756
         2584942	2329852
         2584853	2329852
         2584760	2329946
         2584582	2329946
         2584491	2330039
         2584402	2330039
         2584310	2330136
         2584047	2330133
         2583866	2330323
         2583148	2330319
         2583059	2330410
         2582607	2330416
         2582562	2330367
         2582565	2330276
         2582610	2330226
         2582879	2330229
         2582971	2330133
         2583241	2330136
         2583283	2330086
         2583283	2329995
         2583594	2329662
         2583693	2329665
         2583776	2329568
         2584048	2329572
         2584087	2329528
         2584087	2329432
         2584048	2329384
         2583951	2329384
         2583869	2329481
         2583597	2329484
         2583507	2329572
         2583423	2329577
         2583369	2329621
         2583369	2329712
         2583149	2329949
         2583059	2329849
         2582970	2329849
         2582880	2329765
         2582701	2329761
         2582613	2329665
         2582340	2329668
         2582075	2329949
         2581985	2329946
         2581851	2329811
         2581940	2329714
         2581943	2329618
         2582164	2329388
         2582967	2329384
         2583021	2329341
         2583016	2329153
         2582971	2329110
         2582077	2329104
         2581988	2329007
         2581898	2329104
         2581536	2329104
         2581443	2329200
         2581360	2329200
         2581309	2329153
         2581312	2328960
         2581402	2328873
         2581402	2328782
         2581354	2328729
         2581270	2328729
         2581088	2328919
         2580637	2328913
         2580553	2329009
         2580461	2329009
         2580195	2329293
         2580105	2329293
         2580058	2329337
         2580058	2329428
         2579926	2329574
         2579837	2329574
         2579655	2329758
         2579477	2329764
         2579382	2329851
         2579294	2329851
         2579209	2329945
         2578134	2329948
         2578042	2329848
         2577684	2329851
         2577593	2329948
         2577501	2329855
         2577414	2329855
         2577321	2329952
         2577148	2329948
         2576927	2330186
         2576919	2330551
         2577011	2330650
         2577014	2330835
         2577364	2331205
         2577370	2331303
         2577501	2331445
         2577684	2331442
         2577952	2331723
         2578042	2331723
         2578317	2332004
         2578399	2332004
         2578582	2332194
         2578759	2332188
         2578855	2332288
         2578938	2332288
         2579025	2332379
         2579477	2332379
         2579567	2332476
         2579748	2332473
         2579838	2332382
         2579921	2332378
         2580014	2332287
         2580104	2332287
         2580149	2332238
         2580152	2332052
         2580236	2331957
         2580239	2331771
         2580015	2331534
         2579926	2331534
         2579880	2331487
         2579877	2331122
         2579925	2331068
         2580014	2331072
         2580107	2330975
         2580195	2330975
         2580287	2330882
         2580552	2330885
         2580597	2330838
         2580600	2330557
         2580639	2330510
         2580910	2330507
         2580962	2330554
         2580957	2330650
         2581093	2330787
         2581130	2330740
         2581130	2330653
         2581045	2330553
         2581045	2330462
         2581181	2330322
         2581270	2330415
         2581354	2330415
         2581450	2330506
         2581489	2330462
         2581489	2330365
         2581402	2330274
         2581447	2330227
         2581536	2330231
         2581625	2330134
         2581897	2330131
         2582029	2330273
         2582029	2330364
         2581983	2330415
         2581894	2330415
         2581673	2330642
         2581667	2330836
         2581715	2330883
         2581805	2330877
         2581942	2330742
         2581942	2330646
         2581980	2330602
         2582079	2330606
         2582161	2330508
         2582341	2330508
         2582434	2330415
         2582479	2330462
         2582476	2330646
         2582344	2330786
         2582255	2330786
         2582073	2330977
         2581983	2330977
         2581938	2331021
         2581942	2331207
         2581759	2331397
         2581759	2331488
         2581536	2331726
         2581357	2331723
         2581311	2331679
         2581315	2331491
         2581270	2331444
         2581180	2331444
         2581043	2331585
         2581046	2331869
         2581085	2331912
         2581354	2331909
         2581443	2332006
         2581539	2332009
         2581627	2331912
         2581896	2331909
         2582165	2332190
         2582252	2332190
         2582299	2332237
         2582299	2332333
         2582350	2332377
         2582434	2332381
         2582521	2332471
         2582619	2332471
         2582658	2332519
         2582661	2332705
         2582616	2332755
         2582527	2332755
         2582434	2332849
         2582344	2332849
         2582168	2333033
         2581988	2333038
         2581896	2333126
         2581807	2333126
         2581670	2333266
         2581766	2333363
         2581766	2333454
         2581721	2333497
         2581628	2333503
         2581539	2333594
         2581448	2333597
         2581317	2333732
         2581315	2333829
         2581225	2333926
         2581229	2334113
         2581139	2334209
         2581136	2334388
         2581225	2334488
         2581222	2334674
         2581317	2334772
         2581317	2334862
         2581497	2335049
         2581494	2335140
         2581814	2335474
         2581987	2335468
         2582076	2335381
         2582438	2335377
         2582531	2335281
         2583156	2335284
         2583332	2335470
         2584317	2335470
         2584362	2335423
         2584365	2335237
         2584315	2335193
         2583690	2335184
         2583597	2335281
         2583514	2335281
         2583463	2335233
         2583466	2335142
         2583603	2334995
         2583693	2335000
         2583776	2334909
         2584317	2334909
         2584410	2334811
         2584499	2334816
         2584721	2335049
         2584721	2335236
         2584809	2335327
         2584806	2335423
         2584722	2335511
         2584719	2335607
         2584674	2335661
         2583960	2335657
         2583867	2335748
         2583332	2335748
         2583243	2335845
         2583154	2335842
         2583061	2335938
         2582792	2335935
         2582568	2336169
         2582613	2336216
         2582701	2336216
         2582792	2336316
         2583236	2336307
         2583286	2336360
         2583283	2336546
         2583238	2336590
         2582788	2336590
         2582659	2336730
         2582655	2336918
         2582563	2337014
         2582569	2337200
         2582476	2337298
         2582476	2337856
         2582655	2338041
         2582651	2338137
         2582741	2338228
         2582747	2338325
         2582971	2338559
         2583054	2338559
         2583191	2338696
         2583191	2338793
         2583281	2338884
         2583281	2338975
         2583371	2339075
         2583374	2339917
         2583463	2340008
         2583460	2340195
         2583645	2340384
         2583642	2340482
         2583725	2340565
         2583731	2341223
         2583908	2341411
         2583908	2341508
         2584493	2342112
         2584577	2342116
         2584628	2342159
         2584628	2342257
         2584804	2342447
         2584804	2342538
         2584850	2342581
         2584939	2342585
         2584984	2342628
         2584991	2342725
         2585256	2343006
         2585256	2343097
         2585301	2343150
         2585474	2343144
         2585528	2343100
         2585522	2343004
         2585610	2342907
         2585615	2342816
         2585654	2342772
         2585839	2342769
         2585884	2342813
         2585881	2343193
         2585836	2343239
         2585743	2343236
         2585614	2343378
         2585608	2343564
         2585746	2343707
         2586104	2343704
         2586150	2343757
         2586150	2343847
         2586559	2344263
         2586642	2344266
         2586732	2344363
         2586912	2344366
         2586997	2344457
         2587180	2344454
         2587273	2344363
         2587362	2344357
         2587446	2344270
         2587539	2344270
         2587626	2344361
         2587988	2344364
         2588077	2344271
         2588170	2344271
         2588346	2344080
         2588525	2344083
         2588570	2344127
         2588570	2344218
         2588662	2344315
         2588662	2344502
         2588971	2344836
         2589066	2344830
         2589156	2344921
         2589245	2344925
         2589422	2345111
         2589511	2345111
         2589601	2345211
         2589783	2345205
         2589818	2345162
         2589818	2345065
         2589870	2345021
         2590048	2345021
         2590138	2345114
         2590183	2345067
         2590186	2344971
         2590139	2344927
         2590049	2344923
         2589915	2344786
         2589918	2344596
         2589957	2344550
         2590496	2344550
         2590584	2344452
         2591036	2344458
         2591170	2344596
         2591174	2344879
         2591128	2344922
         2591036	2344922
         2590898	2345070
         2590903	2345435
         2591081	2345624
         2591087	2345721
         2591302	2345949
         2591574	2345953
         2591662	2345856
         2591755	2345859
         2591845	2345768
         2591934	2345763
         2592066	2345628
         2592068	2344876
         2592107	2344833
         2592196	2344833
         2592295	2344736
         2592648	2344741
         2592693	2344785
         2592693	2344876
         2592782	2344973
         2592779	2345154
         2592829	2345207
         2592914	2345207
         2593011	2345297
         2593099	2345301
         2593179	2345392
         2593368	2345395
         2593451	2345486
         2593541	2345486
         2593633	2345390
         2593720	2345393
         2593816	2345302
         2593995	2345299
         2594261	2345018
         2594443	2345018
         2594537	2344925
         2594619	2344925
         2594844	2344686
         2594844	2344600
         2595160	2344272
         2595334	2344269
         2595380	2344225
         2595380	2344134
         2595785	2343713
         2595878	2343707
         2595967	2343619
         2596056	2343619
         2596144	2343521
         2596233	2343521
         2596455	2343288
         2596457	2343102
         2596639	2342912
         2596639	2342821
         2596723	2342723
         2596726	2342536
         2596819	2342449
         2596813	2342256
         2596906	2342165
         2596906	2341978
         2596993	2341881
         2596996	2341510
         2596907	2341410
         2596910	2341319
         2596821	2341228
         2596821	2341131
         2596770	2341088
         2596549	2341321
         2596552	2341502
         2596415	2341649
         2596326	2341649
         2596281	2341595
         2596284	2340947
         2596367	2340856
         2596372	2340572
         2596326	2340526
         2596147	2340526
         2596016	2340666
         2596016	2340756
         2595787	2340991
         2595702	2340991
         2595613	2341088
         2595522	2341084
         2595434	2340987
         2595389	2341037
         2595385	2341223
         2595474	2341317
         2595472	2341411
         2595344	2341551
         2595250	2341551
         2595113	2341692
         2595113	2341789
         2594940	2341973
         2594936	2342064
         2594891	2342116
         2594802	2342113
         2594710	2342210
         2594626	2342210
         2594534	2342304
         2594443	2342304
         2594354	2342400
         2594261	2342397
         2594088	2342584
         2593999	2342580
         2593906	2342677
         2593816	2342677
         2593730	2342764
         2593639	2342770
         2593594	2342723
         2593594	2342626
         2593774	2342437
         2593770	2341971
         2593682	2341875
         2593684	2341784
         2593594	2341693
         2593594	2341596
         2593688	2341505
         2593679	2341038
         2594357	2340336
         2594440	2340336
         2594529	2340240
         2594712	2340243
         2594801	2340146
         2595159	2340517
         2595250	2340520
         2595384	2340663
         2595380	2340851
         2595431	2340894
         2595470	2340851
         2595473	2340663
         2595747	2340382
         2595742	2340196
         2595563	2340008
         2595567	2339918
         2595472	2339817
         2595474	2339537
         2595563	2339446
         2595567	2339349
         2595650	2339258
         2595654	2339074
         2595565	2338974
         2595565	2338877
         2595474	2338786
         2595477	2338599
         2595522	2338556
         2596148	2338556
         2596237	2338646
         2596420	2338649
         2596464	2338693
         2596460	2338791
         2596957	2339298
         2597040	2339298
         2597127	2339398
         2598388	2339398
         2598475	2339489
         2598750	2339493
         2598929	2339303
         2599105	2339303
         2599194	2339210
         2599284	2339210
         2599773	2338692
         2599773	2338604
         2599956	2338418
         2600000	2338365
         2600177	2338268
         2600266	2338271
         2600358	2338175
         2600449	2338175
         2600803	2338552
         2600896	2338549
         2600983	2338645
         2601338	2338642
         2601610	2338361
         2601972	2338365
         2602017	2338412
         2602017	2338598
         2601969	2338642
         2601880	2338642
         2601835	2338692
         2601838	2338970
         2601875	2339023
         2601973	2339023
         2602151	2339203
         2602242	2339207
         2602510	2339484
         2602952	2339484
         2603045	2339388
         2603134	2339388
         2603355	2339160
         2603361	2338598
         2603448	2338502
         2603448	2338405
         2603541	2338318
         2603541	2338227
         2603762	2337983
         2603940	2337987
         2604033	2337890
         2605109	2337896
         2605193	2337987
         2605551	2337983
         2605648	2338081
         2605731	2338084
         2606095	2338454
         2606185	2338454
         2606364	2338641
         2606537	2338644
         2606623	2338735
         2606988	2338732
         2607033	2338688
         2606988	2338641
         2606719	2338648
         2606674	2338594
         2606674	2338504
         2606719	2338453
         2606990	2338453
         2607080	2338554
         2607349	2338551
         2607388	2338594
         2607388	2338692
         2607349	2338735
         2607163	2338735
         2607122	2338785
         2607163	2338832
         2607256	2338832
         2607346	2338923
         2607525	2338926
         2607614	2339017
         2607796	2339021
         2607884	2339112
         2607976	2339112
         2608107	2339248
         2608107	2339345
         2608197	2339442
         2608197	2339533
         2608737	2340101
         2608734	2340375
         2608823	2340468
         2608823	2340565
         2608913	2340656
         2608910	2340752
         2608961	2340796
         2609044	2340800
         2609134	2340890
         2609585	2340887
         2609630	2340940
         2609630	2341031
         2609720	2341122
         2609716	2341218
         2609806	2341316
         2609809	2341876
         2609859	2341924
         2609944	2341924
         2610032	2342015
         2610122	2342015
         2610257	2342152
         2610257	2342533
         2610616	2342903
         2610619	2343187
         2611156	2343746
         2611151	2344030
         2611060	2344127
         2611064	2344307
         2611105	2344357
         2611465	2344353
         2611516	2344401
         2611510	2344962
         2611785	2345240
         2611785	2345336
         2611830	2345384
         2611919	2345384
         2611964	2345431
         2611964	2345527
         2612006	2345575
         2612100	2345575
         2612276	2345762
         2612368	2345765
         2612410	2345809
         2612410	2345900
         2612498	2345997
         2612498	2346088
         2612775	2346369
         2612772	2346465
         2612856	2346556
         2612856	2346647
         2612907	2346700
         2612990	2346700
         2613080	2346604
         2613172	2346607
         2613313	2346742
         2613308	2347310
         2613214	2347400
         2613220	2348243
         2613396	2348434
         2613396	2348525
         2613575	2348711
         2613579	2348898
         2613662	2348996
         2613662	2349085
         2613758	2349187
         2613758	2349273
         2613848	2349368
         2613844	2349554
         2613752	2349647
         2613757	2349925
         2613572	2350116
         2613572	2350213
         2613488	2350303
         2613488	2350400
         2613978	2350915
         2614068	2350915
         2614337	2351197
         2614426	2351190
         2614515	2351288
         2614606	2351291
         2614651	2351335
         2614656	2351425
         2614694	2351479
         2614784	2351479
         2614963	2351660
         2615052	2351663
         2615231	2351850
         2615410	2351853
         2615499	2351944
         2615771	2351948
         2615860	2352038
         2616123	2352042
         2616219	2352133
         2616392	2352136
         2616527	2352271
         2616527	2352368
         2616395	2352508
         2616306	2352508
         2616127	2352327
         2615947	2352324
         2615856	2352227
         2615497	2352231
         2615458	2352274
         2615458	2352366
         2615504	2352418
         2615677	2352418
         2615728	2352466
         2615591	2352606
         2615412	2352603
         2615316	2352699
         2615228	2352699
         2615146	2352608
         2615055	2352696
         2614963	2352702
         2614828	2352837
         2614833	2352933
         2614741	2353031
         2614741	2353208
         2614783	2353262
         2614876	2353262
         2614921	2353310
         2614918	2353496
         2615052	2353633
         2615143	2353633
         2615231	2353730
         2615321	2353733
         2615366	2353777
         2615366	2354339
         2615455	2354430
         2615455	2354617
         2615548	2354708
         2615548	2354804
         2615861	2355136
         2615951	2355133
         2616354	2355554
         2616351	2355645
         2616486	2355788
         2616573	2355697
         2616759	2355881
         2616937	2355881
         2617113	2355697
         2617384	2355693
         2617475	2355603
         2617740	2355599
         2617877	2355458
         2617872	2355272
         2617923	2355228
         2618006	2355228
         2618319	2354903
         2618322	2354619
         2618416	2354522
         2618413	2354058
         2618505	2353964
         2618505	2353777
         2618682	2353591
         2618682	2353494
         2618729	2353450
         2618907	2353447
         2618992	2353356
         2619175	2353349
         2619263	2353450
         2619308	2353403
         2619308	2353306
         2619217	2353215
         2619221	2352931
         2619260	2352887
         2619532	2352884
         2619624	2352793
         2619714	2352796
         2619803	2352887
         2620072	2352890
         2620114	2352838
         2620114	2352741
         2620159	2352697
         2620249	2352697
         2620603	2352318
         2620789	2352322
         2620879	2352225
         2621052	2352228
         2621145	2352132
         2621234	2352132
         2621328	2352044
         2621501	2352038
         2621590	2351951
         2621686	2351951
         2621773	2351854
         2622576	2351858
         2622669	2351949
         2622938	2351952
         2623030	2351855
         2623203	2351855
         2623300	2351955
         2623565	2351950
         2623611	2351906
         2623611	2351808
         2623656	2351765
         2623922	2351769
         2623972	2351813
         2623972	2351903
         2624187	2352138
         2624910	2352138
         2624999	2352231
         2625805	2352231
         2625938	2352374
         2625938	2352464
         2625982	2352508
         2626075	2352512
         2626121	2352464
         2626121	2352374
         2626167	2352324
         2626258	2352324
         2626348	2352415
         2626617	2352418
         2626701	2352515
         2626889	2352512
         2626973	2352421
         2627244	2352417
         2627333	2352326
         2627598	2352323
         2627689	2352226
         2628133	2352232
         2628226	2352135
         2628316	2352135
         2628809	2351621
         2628812	2351529
         2628857	2351482
         2628947	2351486
         2629078	2351335
         2629078	2351249
         2629436	2350870
         2629436	2350779
         2629529	2350682
         2629524	2350496
         2629616	2350408
         2629619	2350027
         2629569	2349980
         2629391	2349980
         2629299	2349887
         2628944	2349883
         2628855	2349792
         2628499	2349796
         2628410	2349699
         2627424	2349702
         2627328	2349793
         2627152	2349790
         2627063	2349887
         2626707	2349890
         2626615	2349978
         2625990	2349987
         2625894	2349887
         2625628	2349887
         2625541	2349793
         2625359	2349793
         2625269	2349702
         2625004	2349983
         2624281	2349983
         2624191	2349890
         2624018	2349890
         2623922	2349793
         2623749	2349797
         2623612	2349932
         2623612	2350028
         2623565	2350081
         2623475	2350078
         2623391	2350169
         2623299	2350174
         2623257	2350121
         2623257	2349844
         2623344	2349751
         2623344	2349650
         2623437	2349563
         2623437	2349465
         2623475	2349422
         2623654	2349422
         2623702	2349372
         2623657	2349325
         2623478	2349325
         2623439	2349278
         2623433	2349000
         2623388	2348956
         2623035	2348951
         2622936	2349047
         2622674	2349044
         2622578	2349141
         2622402	2349141
         2622315	2349234
         2622129	2349234
         2622042	2349328
         2621864	2349328
         2621771	2349422
         2621508	2349422
         2621463	2349374
         2621460	2349090
         2621415	2349046
         2620697	2349043
         2620339	2349415
         2620250	2349420
         2620166	2349511
         2619893	2349515
         2619805	2349602
         2619712	2349602
         2619625	2349511
         2619532	2349517
         2619443	2349605
         2618819	2349605
         2618682	2349745
         2618677	2349932
         2618503	2350126
         2618503	2350217
         2618458	2350261
         2618365	2350261
         2618282	2350354
         2618192	2350263
         2617827	2350260
         2617740	2350169
         2617472	2350165
         2617427	2350118
         2617430	2349934
         2617475	2349887
         2617558	2349887
         2617648	2349793
         2617740	2349793
         2617827	2349697
         2618192	2349693
         2618237	2349650
         2618102	2349506
         2617923	2349512
         2617827	2349599
         2617561	2349606
         2617472	2349512
         2617383	2349512
         2617204	2349325
         2617114	2349321
         2617076	2349278
         2617069	2349181
         2617024	2349134
         2616935	2349134
         2616846	2349043
         2616757	2349039
         2616353	2348618
         2616356	2348430
         2616395	2348388
         2616846	2348384
         2617069	2348618
         2617067	2348715
         2617387	2349039
         2618283	2349043
         2618366	2348946
         2618549	2348950
         2618637	2349040
         2618728	2349040
         2618820	2348947
         2619089	2348951
         2619173	2348854
         2619535	2348857
         2619628	2348760
         2619717	2348861
         2620430	2348854
         2620568	2348714
         2620568	2348623
         2620699	2348482
         2620878	2348482
         2621058	2348666
         2621323	2348670
         2621412	2348573
         2621683	2348576
         2621774	2348480
         2621863	2348480
         2621955	2348387
         2622036	2348387
         2622132	2348290
         2622221	2348290
         2622311	2348202
         2622404	2348202
         2622487	2348106
         2622673	2348109
         2622849	2347925
         2623393	2347915
         2623476	2347824
         2623656	2347827
         2623745	2347918
         2623835	2347918
         2624283	2348390
         2624372	2348390
         2624507	2348527
         2624507	2348624
         2624548	2348668
         2624641	2348668
         2624999	2349046
         2625089	2349049
         2625275	2349230
         2625358	2349230
         2625448	2349327
         2625537	2349324
         2625627	2349420
         2625717	2349420
         2625805	2349511
         2625895	2349515
         2625984	2349606
         2626698	2349606
         2626791	2349515
         2627057	2349511
         2627152	2349420
         2627325	2349417
         2627419	2349326
         2627508	2349320
         2627598	2349420
         2627690	2349324
         2628404	2349324
         2628494	2349415
         2628583	2349415
         2628672	2349515
         2628944	2349509
         2629034	2349609
         2629296	2349612
         2629385	2349704
         2629747	2349700
         2629837	2349797
         2630378	2349797
         2630416	2349841
         2630416	2349937
         2630467	2349984
         2630646	2349979
         2630738	2349888
         2630819	2349981
         2630911	2349981
         2631002	2350078
         2631180	2350074
         2631266	2350169
         2631449	2350171
         2631539	2350264
         2631721	2350259
         2632253	2349704
         2632434	2349704
         2632524	2349797
         2632570	2349744
         2632570	2349563
         2632617	2349512
         2633062	2349516
         2633244	2349326
         2633333	2349326
         2633378	2349282
         2633373	2349186
         2633417	2349142
         2634586	2349138
         2634676	2349235
         2635389	2349235
         2635482	2349138
         2635572	2349142
         2635661	2349233
         2635706	2349186
         2635709	2349094
         2635838	2348954
         2636016	2348957
         2636110	2348861
         2636203	2348861
         2636248	2348810
         2636243	2348533
         2636290	2348483
         2636379	2348483
         2636468	2348387
         2636920	2348392
         2637141	2348155
         2637144	2348064
         2637182	2348020
         2637278	2348015
         2637317	2347967
         2637320	2347783
         2637547	2347545
         2637721	2347545
         2637948	2347312
         2637945	2347220
         2638041	2347124
         2638037	2346846
         2638174	2346706
         2638263	2346699
         2638531	2346425
         2638619	2346425
         2638712	2346332
         2638801	2346332
         2638891	2346235
         2639067	2346239
         2639471	2345814
         2639471	2345717
         2639829	2345349
         2639829	2345258
         2640187	2344880
         2640187	2344783
         2640365	2344598
         2640365	2344509
         2640547	2344314
         2640547	2344223
         2640639	2344127
         2640639	2344033
         2640816	2343847
         2640816	2343756
         2640992	2343565
         2640995	2343287
         2641085	2343191
         2641087	2342913
         2641172	2342820
         2641175	2342633
         2641264	2342536
         2641269	2342350
         2641626	2341971
         2641626	2341880
         2641847	2341643
         2641937	2341646
         2642198	2341372
         2642295	2341372
         2642385	2341276
         2642829	2341272
         2642884	2341228
         2642877	2341132
         2643013	2340990
         2643102	2340990
         2643236	2341134
         2643236	2341225
         2643281	2341269
         2643371	2341272
         2643464	2341181
         2643732	2341178
         2643816	2341275
         2644178	2341271
         2644268	2341180
         2644450	2341177
         2644539	2341273
         2644718	2341273
         2644801	2341365
         2645878	2341368
         2646107	2341601
         2646107	2341692
         2646153	2341740
         2646326	2341740
         2646418	2341646
         2646508	2341646
         2646774	2341372
         2646870	2341367
         2646962	2341276
         2647407	2341272
         2647491	2341185
         2648031	2341181
         2648124	2341085
         2648214	2341088
         2648298	2340997
         2648393	2340990
         2648480	2340900
         2648570	2340904
         2648659	2340806
         2648752	2340806
         2648841	2340710
         2648922	2340713
         2649062	2340570
         2649065	2340290
         2648977	2340195
         2648970	2339921
         2649025	2339868
         2649198	2339872
         2649380	2339679
         2649469	2339679
         2649514	2339635
         2649509	2339544
         2649646	2339404
         2649735	2339404
         2649917	2339212
         2650000	2339212
         2650094	2339122
         2650363	2339118
         2650455	2339028
         2650545	2339022
         2650634	2339122
         2650988	2339125
         2651077	2339216
         2651259	2339210
         2651348	2339307
         2651528	2339310
         2651617	2339401
         2651795	2339401
         2651885	2339501
         2652241	2339498
         2652333	2339407
         2652429	2339498
         2652513	2339492
         2652602	2339589
         2652691	2339592
         2652823	2339727
         2652832	2339824
         2652868	2339871
         2652960	2339871
         2653501	2340430
         2653585	2340430
         2654039	2340897
         2654123	2340900
         2654212	2340998
         2655024	2340998
         2655108	2341088
         2655831	2341088
         2655920	2341186
         2656009	2341186
         2716595	2355710
         2771273	2355710
         2800498	2372977
         2844805	2380825
         2876312	2393861
         ];

      p1 = p1(1:end-1,:);
      
      hdata.hmax = min(max(p1)-min(p1))/250;
      
      options.dhmax = 0.1;

      mesh2d(p1);

end

end      % mesh_collection()

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function p = move(p,xm,ym)

% Move a node set p by [xm,ym]

n = size(p,1);
p = p + [xm*ones(n,1), ym*ones(n,1)];

end      % move()

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function p = rotate(p,A)

% Rotate a node set p by A degrees.

A = A*pi/180;
T = [ cos(A), sin(A)
   -sin(A), cos(A)];
p = (T*p')';

end      % rotate()

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function h = const_h(x,y,x1,x2,y1,y2,h0)

% User defined size function specifying a constant size of h0 within the
% rectangle bounded by [x1,y1] & [x2,y2].

h = inf*ones(size(x,1),1);

in = (x>=x1)&(x<=x2)&(y>=y1)&(y<=y2);
h(in) = h0;

end      % const_h()
